/* StarStore.c generated by valac 0.56.17, the Vala compiler
 * generated from StarStore.vala, do not modify */

/**
 * SPDX-FileCopyrightText: Copyright © 2020-2024 Louis Brauer <louis@brauer.family>
 * SPDX-FileCopyrightText: Copyright © 2024 technosf <https://github.com/technosf>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @file StarStore.vala
 *
 * @brief Store and retrieve a collection of starred stations.
 * 
 * Manages a collection of stations stored in a JSON file.
 * Provides methods to add, remove, and persist stations.
 * The JSON file store a subset of station data - the minimum
 * to be able to play a station without retrieving its information]
 * from radio-browser
 */

#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <json-glib/json-glib.h>
#include <gtk/gtk.h>

#define TUNER_STAR_STORE_FAVORITES_PROPERTY_APP "app"
#define TUNER_STAR_STORE_FAVORITES_PROPERTY_FILE "file"
#define TUNER_STAR_STORE_FAVORITES_PROPERTY_SCHEMA "schema"
#define TUNER_STAR_STORE_FAVORITES_PROPERTY_STATIONS "stations"
#define TUNER_STAR_STORE_FAVORITES_PROPERTY_SEARCHES "searches"
#define TUNER_STAR_STORE_FAVORITES_SCHEMA_VERSION "2.0"
#define TUNER_STAR_STORE_M3U8 "#EXTM3U\n#EXTENC:UTF-8\n#PLAYLIST:Tuner\n"
#define TUNER_STAR_STORE_M3U8_UUID "STATIONUUID"
#define TUNER_STAR_STORE_UUID_REGEX "([a-fA-Z0-9]{8}-[a-fA-Z0-9]{4}-[a-fA-Z0-9]{4}-[a-fA-Z0-9]{4}-[a-fA-Z0-" \
"9]{12})"
#define TUNER_APPLICATION_APP_ID "com.github.louis77.tuner"
#define TUNER_APPLICATION_STARRED "starred.json"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUNER_TYPE_STAR_STORE (tuner_star_store_get_type ())
#define TUNER_STAR_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STAR_STORE, TunerStarStore))
#define TUNER_STAR_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_STAR_STORE, TunerStarStoreClass))
#define TUNER_IS_STAR_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STAR_STORE))
#define TUNER_IS_STAR_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_STAR_STORE))
#define TUNER_STAR_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_STAR_STORE, TunerStarStoreClass))

typedef struct _TunerStarStore TunerStarStore;
typedef struct _TunerStarStoreClass TunerStarStoreClass;
typedef struct _TunerStarStorePrivate TunerStarStorePrivate;

#define TUNER_MODEL_TYPE_FAVICON (tuner_model_favicon_get_type ())
#define TUNER_MODEL_FAVICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_MODEL_TYPE_FAVICON, TunerModelFavicon))
#define TUNER_MODEL_FAVICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_MODEL_TYPE_FAVICON, TunerModelFaviconClass))
#define TUNER_MODEL_IS_FAVICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_MODEL_TYPE_FAVICON))
#define TUNER_MODEL_IS_FAVICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_MODEL_TYPE_FAVICON))
#define TUNER_MODEL_FAVICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_MODEL_TYPE_FAVICON, TunerModelFaviconClass))

typedef struct _TunerModelFavicon TunerModelFavicon;
typedef struct _TunerModelFaviconClass TunerModelFaviconClass;

#define TUNER_MODEL_TYPE_STATION (tuner_model_station_get_type ())
#define TUNER_MODEL_STATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_MODEL_TYPE_STATION, TunerModelStation))
#define TUNER_MODEL_STATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_MODEL_TYPE_STATION, TunerModelStationClass))
#define TUNER_MODEL_IS_STATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_MODEL_TYPE_STATION))
#define TUNER_MODEL_IS_STATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_MODEL_TYPE_STATION))
#define TUNER_MODEL_STATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_MODEL_TYPE_STATION, TunerModelStationClass))

typedef struct _TunerModelStation TunerModelStation;
typedef struct _TunerModelStationClass TunerModelStationClass;
enum  {
	TUNER_STAR_STORE_0_PROPERTY,
	TUNER_STAR_STORE_NUM_PROPERTIES
};
static GParamSpec* tuner_star_store_properties[TUNER_STAR_STORE_NUM_PROPERTIES];
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _json_array_unref0(var) ((var == NULL) ? NULL : (var = (json_array_unref (var), NULL)))
typedef struct _Block7Data Block7Data;

#define TUNER_TYPE_APPLICATION (tuner_application_get_type ())
#define TUNER_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_APPLICATION, TunerApplication))
#define TUNER_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_APPLICATION, TunerApplicationClass))
#define TUNER_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_APPLICATION))
#define TUNER_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_APPLICATION))
#define TUNER_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_APPLICATION, TunerApplicationClass))

typedef struct _TunerApplication TunerApplication;
typedef struct _TunerApplicationClass TunerApplicationClass;

#define TUNER_DATA_PROVIDER_TYPE_API (tuner_data_provider_api_get_type ())
#define TUNER_DATA_PROVIDER_API(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_DATA_PROVIDER_TYPE_API, TunerDataProviderAPI))
#define TUNER_DATA_PROVIDER_IS_API(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_DATA_PROVIDER_TYPE_API))
#define TUNER_DATA_PROVIDER_API_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUNER_DATA_PROVIDER_TYPE_API, TunerDataProviderAPIIface))

typedef struct _TunerDataProviderAPI TunerDataProviderAPI;
typedef struct _TunerDataProviderAPIIface TunerDataProviderAPIIface;

#define TUNER_DATA_PROVIDER_TYPE_TAG (tuner_data_provider_tag_get_type ())
#define TUNER_DATA_PROVIDER_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_DATA_PROVIDER_TYPE_TAG, TunerDataProviderTag))
#define TUNER_DATA_PROVIDER_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_DATA_PROVIDER_TYPE_TAG, TunerDataProviderTagClass))
#define TUNER_DATA_PROVIDER_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_DATA_PROVIDER_TYPE_TAG))
#define TUNER_DATA_PROVIDER_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_DATA_PROVIDER_TYPE_TAG))
#define TUNER_DATA_PROVIDER_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_DATA_PROVIDER_TYPE_TAG, TunerDataProviderTagClass))

typedef struct _TunerDataProviderTag TunerDataProviderTag;
typedef struct _TunerDataProviderTagClass TunerDataProviderTagClass;

#define TUNER_DATA_PROVIDER_TYPE_DATA_ERROR (tuner_data_provider_data_error_get_type ())

#define TUNER_DATA_PROVIDER_TYPE_SEARCH_PARAMS (tuner_data_provider_search_params_get_type ())
typedef struct _TunerDataProviderSearchParams TunerDataProviderSearchParams;
typedef enum  {
	TUNER_DATA_PROVIDER_SORT_ORDER_NAME,
	TUNER_DATA_PROVIDER_SORT_ORDER_URL,
	TUNER_DATA_PROVIDER_SORT_ORDER_HOMEPAGE,
	TUNER_DATA_PROVIDER_SORT_ORDER_FAVICON,
	TUNER_DATA_PROVIDER_SORT_ORDER_TAGS,
	TUNER_DATA_PROVIDER_SORT_ORDER_COUNTRY,
	TUNER_DATA_PROVIDER_SORT_ORDER_STATE,
	TUNER_DATA_PROVIDER_SORT_ORDER_LANGUAGE,
	TUNER_DATA_PROVIDER_SORT_ORDER_VOTES,
	TUNER_DATA_PROVIDER_SORT_ORDER_CODEC,
	TUNER_DATA_PROVIDER_SORT_ORDER_BITRATE,
	TUNER_DATA_PROVIDER_SORT_ORDER_LASTCHECKOK,
	TUNER_DATA_PROVIDER_SORT_ORDER_LASTCHECKTIME,
	TUNER_DATA_PROVIDER_SORT_ORDER_CLICKTIMESTAMP,
	TUNER_DATA_PROVIDER_SORT_ORDER_CLICKCOUNT,
	TUNER_DATA_PROVIDER_SORT_ORDER_CLICKTREND,
	TUNER_DATA_PROVIDER_SORT_ORDER_RANDOM
} TunerDataProviderSortOrder;

#define TUNER_DATA_PROVIDER_TYPE_SORT_ORDER (tuner_data_provider_sort_order_get_type ())
typedef enum  {
	TUNER_DATA_PROVIDER_API_STATUS_OK,
	TUNER_DATA_PROVIDER_API_STATUS_NO_SERVER_LIST,
	TUNER_DATA_PROVIDER_API_STATUS_NO_SERVERS_PRESENTED,
	TUNER_DATA_PROVIDER_API_STATUS_NOT_AVAILABLE,
	TUNER_DATA_PROVIDER_API_STATUS_UNKNOW_ERROR
} TunerDataProviderAPIStatus;

#define TUNER_DATA_PROVIDER_API_TYPE_STATUS (tuner_data_provider_api_status_get_type ())
typedef struct _TunerModelFaviconPrivate TunerModelFaviconPrivate;
typedef struct _TunerModelStationPrivate TunerModelStationPrivate;
typedef struct _TunerStarStoreLoadData TunerStarStoreLoadData;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _g_match_info_unref0(var) ((var == NULL) ? NULL : (var = (g_match_info_unref (var), NULL)))

#define TUNER_TYPE_DIRECTORY_CONTROLLER (tuner_directory_controller_get_type ())
#define TUNER_DIRECTORY_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_DIRECTORY_CONTROLLER, TunerDirectoryController))
#define TUNER_DIRECTORY_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_DIRECTORY_CONTROLLER, TunerDirectoryControllerClass))
#define TUNER_IS_DIRECTORY_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_DIRECTORY_CONTROLLER))
#define TUNER_IS_DIRECTORY_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_DIRECTORY_CONTROLLER))
#define TUNER_DIRECTORY_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_DIRECTORY_CONTROLLER, TunerDirectoryControllerClass))

typedef struct _TunerDirectoryController TunerDirectoryController;
typedef struct _TunerDirectoryControllerClass TunerDirectoryControllerClass;
#define _json_object_unref0(var) ((var == NULL) ? NULL : (var = (json_object_unref (var), NULL)))
enum  {
	TUNER_STAR_STORE_STARRED_STATIONS_CHANGED_SIG_SIGNAL,
	TUNER_STAR_STORE_NUM_SIGNALS
};
static guint tuner_star_store_signals[TUNER_STAR_STORE_NUM_SIGNALS] = {0};

struct _TunerStarStore {
	GObject parent_instance;
	TunerStarStorePrivate * priv;
};

struct _TunerStarStoreClass {
	GObjectClass parent_class;
};

struct _TunerStarStorePrivate {
	GRegex* uuid_regex;
	GFile* _starred_file;
	GeeMap* _starred_station_map;
	GeeSet* _saved_searches;
	gboolean _loaded;
};

struct _Block7Data {
	int _ref_count_;
	TunerStarStore* self;
	TunerModelStation* station;
};

typedef enum  {
	TUNER_DATA_PROVIDER_DATA_ERROR_PARSE_DATA,
	TUNER_DATA_PROVIDER_DATA_ERROR_NO_CONNECTION
} TunerDataProviderDataError;
#define TUNER_DATA_PROVIDER_DATA_ERROR tuner_data_provider_data_error_quark ()

struct _TunerDataProviderSearchParams {
	gchar* text;
	GeeSet* tags;
	GeeSet* uuids;
	gchar* countrycode;
	TunerDataProviderSortOrder order;
	gboolean reverse;
};

struct _TunerDataProviderAPIIface {
	GTypeInterface parent_iface;
	void (*clear_last_error) (TunerDataProviderAPI* self);
	gchar* (*name) (TunerDataProviderAPI* self);
	gint (*available_stations) (TunerDataProviderAPI* self);
	gint (*available_tags) (TunerDataProviderAPI* self);
	gboolean (*initialize) (TunerDataProviderAPI* self);
	void (*click) (TunerDataProviderAPI* self, const gchar* stationuuid);
	void (*vote) (TunerDataProviderAPI* self, const gchar* stationuuid);
	GeeSet* (*get_tags) (TunerDataProviderAPI* self, gint offset, gint limit, GError** error);
	GeeSet* (*by_uuid) (TunerDataProviderAPI* self, const gchar* uuids, GError** error);
	GeeSet* (*by_uuids) (TunerDataProviderAPI* self, GeeCollection* uuids, GError** error);
	GeeSet* (*search) (TunerDataProviderAPI* self, TunerDataProviderSearchParams* params, guint rowcount, guint offset, GError** error);
	void (*search_async) (TunerDataProviderAPI* self, TunerDataProviderSearchParams* params, guint rowcount, guint offset, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GeeSet* (*search_finish) (TunerDataProviderAPI* self, GAsyncResult* _res_, GError** error);
	GError* (*get_last_data_error) (TunerDataProviderAPI* self);
	void (*set_last_data_error) (TunerDataProviderAPI* self, GError* value);
	TunerDataProviderAPIStatus (*get_status) (TunerDataProviderAPI* self);
	void (*set_status) (TunerDataProviderAPI* self, TunerDataProviderAPIStatus value);
};

struct _TunerModelFavicon {
	GObject parent_instance;
	TunerModelFaviconPrivate * priv;
};

struct _TunerModelFaviconClass {
	GObjectClass parent_class;
	gchar* (*favicon_cache_file) (TunerModelFavicon* self);
};

struct _TunerModelStation {
	TunerModelFavicon parent_instance;
	TunerModelStationPrivate * priv;
	gint votes;
	gchar* lastchangetime;
	gchar* lastchangetime_iso8601;
	gint lastcheckok;
	gchar* lastchecktime;
	gchar* lastchecktime_iso8601;
	gchar* lastcheckoktime;
	gchar* lastcheckoktime_iso8601;
	gchar* lastlocalchecktime;
	gchar* lastlocalchecktime_iso8601;
	gchar* clicktimestamp;
	gchar* clicktimestamp_iso8601;
	gint clickcount;
	gint clicktrend;
	gint ssl_error;
	gchar* geo_lat;
	gchar* geo_long;
	gboolean has_extended_info;
	gboolean is_in_index;
	gboolean is_up_to_date;
	gchar* up_to_date_difference;
};

struct _TunerModelStationClass {
	TunerModelFaviconClass parent_class;
};

struct _TunerStarStoreLoadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TunerStarStore* self;
	GFileOutputStream* _tmp0_;
	GFile* _tmp1_;
	GFileOutputStream* _tmp2_;
	JsonParser* parser;
	JsonParser* _tmp3_;
	GFileInputStream* stream;
	GFile* _tmp4_;
	GFileInputStream* _tmp5_;
	JsonParser* _tmp6_;
	GFileInputStream* _tmp7_;
	GFileInputStream* _tmp8_;
	GError* e;
	GError* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	JsonNode* root;
	JsonParser* _tmp14_;
	JsonNode* _tmp15_;
	JsonNode* _tmp16_;
	JsonNode* _tmp17_;
	JsonArray* jstarred;
	JsonArray* jsearches;
	JsonNode* _tmp18_;
	JsonNode* _tmp19_;
	JsonNode* _tmp20_;
	gboolean _tmp21_;
	JsonNode* _tmp22_;
	JsonArray* _tmp23_;
	JsonArray* _tmp24_;
	JsonNode* stations;
	JsonNode* _tmp25_;
	JsonNode* _tmp26_;
	JsonNode* _tmp27_;
	JsonArray* _tmp28_;
	JsonArray* _tmp29_;
	JsonNode* searches;
	JsonNode* _tmp30_;
	JsonNode* _tmp31_;
	JsonNode* _tmp32_;
	JsonArray* _tmp33_;
	JsonArray* _tmp34_;
	JsonArray* _tmp35_;
	GeeSet* provider_station;
	TunerApplication* _tmp36_;
	TunerApplication* _tmp37_;
	TunerDataProviderAPI* _tmp38_;
	TunerDataProviderAPI* _tmp39_;
	GeeMap* _tmp40_;
	GeeSet* _tmp41_;
	GeeSet* _tmp42_;
	GeeSet* _tmp43_;
	GeeSet* _tmp44_;
	GeeSet* _tmp45_;
	GeeIterator* _ps_it;
	GeeSet* _tmp46_;
	GeeIterator* _tmp47_;
	GeeIterator* _tmp48_;
	TunerModelStation* ps;
	GeeIterator* _tmp49_;
	gpointer _tmp50_;
	TunerModelStation* ss;
	GeeMap* _tmp51_;
	TunerModelStation* _tmp52_;
	const gchar* _tmp53_;
	const gchar* _tmp54_;
	gpointer _tmp55_;
	TunerModelStation* _tmp56_;
	TunerModelStation* _tmp57_;
	TunerModelStation* _tmp58_;
	TunerModelStation* _tmp59_;
	GError* _vala1_e;
	GError* _tmp60_;
	const gchar* _tmp61_;
	const gchar* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	JsonArray* _tmp65_;
	GError* _inner_error0_;
};

static gint TunerStarStore_private_offset;
static gpointer tuner_star_store_parent_class = NULL;

VALA_EXTERN GType tuner_star_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStarStore, g_object_unref)
VALA_EXTERN GType tuner_model_favicon_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerModelFavicon, g_object_unref)
VALA_EXTERN GType tuner_model_station_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerModelStation, g_object_unref)
VALA_EXTERN TunerStarStore* tuner_star_store_new (GFile* starred_file);
VALA_EXTERN TunerStarStore* tuner_star_store_construct (GType object_type,
                                            GFile* starred_file);
VALA_EXTERN void tuner_star_store_add_station (TunerStarStore* self,
                                   TunerModelStation* station);
VALA_EXTERN const gchar* tuner_model_station_get_stationuuid (TunerModelStation* self);
static void tuner_star_store_persist (TunerStarStore* self);
VALA_EXTERN void tuner_star_store_remove_station (TunerStarStore* self,
                                      TunerModelStation* station);
VALA_EXTERN void tuner_star_store_update_from_station (TunerStarStore* self,
                                           TunerModelStation* station);
VALA_EXTERN gboolean tuner_model_station_get_starred (TunerModelStation* self);
VALA_EXTERN void tuner_star_store_add_saved_search (TunerStarStore* self,
                                        const gchar* search_text);
VALA_EXTERN void tuner_star_store_remove_saved_search (TunerStarStore* self,
                                           const gchar* search_text);
VALA_EXTERN gchar* tuner_star_store_serialize (TunerStarStore* self);
static JsonNode* _vala_JsonNode_copy (JsonNode* self);
static void _vala_JsonNode_free (JsonNode* self);
VALA_EXTERN GeeCollection* tuner_star_store_get_all_stations (TunerStarStore* self);
VALA_EXTERN GeeSet* tuner_star_store_get_all_searches (TunerStarStore* self);
VALA_EXTERN gboolean tuner_star_store_contains (TunerStarStore* self,
                                    TunerModelStation* station);
VALA_EXTERN void tuner_star_store_update (TunerStarStore* self,
                              TunerModelStation* station);
VALA_EXTERN TunerModelStation* tuner_model_station_updated (TunerModelStation* self);
static void tuner_star_store_load_data_free (gpointer _data);
VALA_EXTERN void tuner_star_store_load (TunerStarStore* self,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN void tuner_star_store_load_finish (TunerStarStore* self,
                                   GAsyncResult* _res_);
static gboolean tuner_star_store_load_co (TunerStarStoreLoadData* _data_);
static JsonNode* tuner_star_store_get_member (JsonNode* node,
                                       const gchar* property_name);
static void __lambda31_ (TunerStarStore* self,
                  JsonArray* a,
                  guint i,
                  JsonNode* elem);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
VALA_EXTERN TunerModelStation* tuner_model_station_new_basic (JsonNode* json_node);
VALA_EXTERN TunerModelStation* tuner_model_station_construct_basic (GType object_type,
                                                        JsonNode* json_node);
VALA_EXTERN void tuner_model_station_set_starred (TunerModelStation* self,
                                      gboolean value);
static void __lambda34_ (Block7Data* _data7_,
                  gboolean starred);
static void ___lambda34__tuner_model_station_station_star_changed_sig (TunerModelStation* _sender,
                                                                gboolean starred,
                                                                gpointer self);
static void ___lambda31__json_array_foreach (JsonArray* array,
                                      guint index_,
                                      JsonNode* element_node,
                                      gpointer self);
VALA_EXTERN GType tuner_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerApplication, g_object_unref)
VALA_EXTERN TunerApplication* tuner_app (void);
VALA_EXTERN GType tuner_data_provider_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDataProviderTag, g_object_unref)
VALA_EXTERN GQuark tuner_data_provider_data_error_quark (void);
VALA_EXTERN GType tuner_data_provider_data_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuner_data_provider_search_params_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuner_data_provider_sort_order_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TunerDataProviderSearchParams* tuner_data_provider_search_params_dup (const TunerDataProviderSearchParams* self);
VALA_EXTERN void tuner_data_provider_search_params_free (TunerDataProviderSearchParams* self);
VALA_EXTERN void tuner_data_provider_search_params_copy (const TunerDataProviderSearchParams* self,
                                             TunerDataProviderSearchParams* dest);
VALA_EXTERN void tuner_data_provider_search_params_destroy (TunerDataProviderSearchParams* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TunerDataProviderSearchParams, tuner_data_provider_search_params_destroy)
VALA_EXTERN GType tuner_data_provider_api_status_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuner_data_provider_api_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDataProviderAPI, g_object_unref)
VALA_EXTERN TunerDataProviderAPI* tuner_application_get_provider (TunerApplication* self);
VALA_EXTERN GeeSet* tuner_data_provider_api_by_uuids (TunerDataProviderAPI* self,
                                          GeeCollection* uuids,
                                          GError** error);
VALA_EXTERN gboolean tuner_model_station_set_up_to_date_with (TunerModelStation* self,
                                                  TunerModelStation* p);
static void __lambda35_ (TunerStarStore* self,
                  JsonArray* a,
                  guint i,
                  JsonNode* elem);
static void ___lambda35__json_array_foreach (JsonArray* array,
                                      guint index_,
                                      JsonNode* element_node,
                                      gpointer self);
VALA_EXTERN gchar* tuner_star_store_export_m3u8 (TunerStarStore* self);
VALA_EXTERN const gchar* tuner_model_station_get_urlResolved (TunerModelStation* self);
VALA_EXTERN const gchar* tuner_model_station_get_url (TunerModelStation* self);
VALA_EXTERN const gchar* tuner_model_station_get_name (TunerModelStation* self);
VALA_EXTERN const gchar* tuner_model_favicon_get_favicon (TunerModelFavicon* self);
VALA_EXTERN void tuner_star_store_import_stationuuids (TunerStarStore* self,
                                           GDataInputStream* data_stream,
                                           GError** error);
VALA_EXTERN GType tuner_directory_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDirectoryController, g_object_unref)
VALA_EXTERN TunerDirectoryController* tuner_application_get_directory (TunerApplication* self);
VALA_EXTERN GeeSet* tuner_directory_controller_get_stations_by_uuid (TunerDirectoryController* self,
                                                         GeeCollection* uuids);
static GObject * tuner_star_store_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties);
static void tuner_star_store_finalize (GObject * obj);
static GType tuner_star_store_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static gssize _vala_array_length (gpointer array);

static inline gpointer
tuner_star_store_get_instance_private (TunerStarStore* self)
{
	return G_STRUCT_MEMBER_P (self, TunerStarStore_private_offset);
}

/**
     * @brief Constructor for StationStore.
     * @param favorites_path The path to the JSON file where favorites are stored.
     */
static gpointer
_g_object_ref0 (gpointer self)
{
#line 80 "../src/Services/StarStore.vala"
	return self ? g_object_ref (self) : NULL;
#line 511 "StarStore.c"
}

TunerStarStore*
tuner_star_store_construct (GType object_type,
                            GFile* starred_file)
{
	TunerStarStore * self = NULL;
	GFile* _tmp0_;
#line 77 "../src/Services/StarStore.vala"
	g_return_val_if_fail (starred_file != NULL, NULL);
#line 79 "../src/Services/StarStore.vala"
	self = (TunerStarStore*) g_object_new (object_type, NULL);
#line 80 "../src/Services/StarStore.vala"
	_tmp0_ = _g_object_ref0 (starred_file);
#line 80 "../src/Services/StarStore.vala"
	_g_object_unref0 (self->priv->_starred_file);
#line 80 "../src/Services/StarStore.vala"
	self->priv->_starred_file = _tmp0_;
#line 77 "../src/Services/StarStore.vala"
	return self;
#line 532 "StarStore.c"
}

TunerStarStore*
tuner_star_store_new (GFile* starred_file)
{
#line 77 "../src/Services/StarStore.vala"
	return tuner_star_store_construct (TUNER_TYPE_STAR_STORE, starred_file);
#line 540 "StarStore.c"
}

/**
     * @brief Adds a station to the favorites and persists the change.
     * @param station The station to be added.
     */
void
tuner_star_store_add_station (TunerStarStore* self,
                              TunerModelStation* station)
{
	GeeMap* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GeeMap* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
#line 89 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 89 "../src/Services/StarStore.vala"
	g_return_if_fail (station != NULL);
#line 90 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_starred_station_map;
#line 90 "../src/Services/StarStore.vala"
	_tmp1_ = tuner_model_station_get_stationuuid (station);
#line 90 "../src/Services/StarStore.vala"
	_tmp2_ = _tmp1_;
#line 90 "../src/Services/StarStore.vala"
	if (gee_map_has_key (_tmp0_, _tmp2_)) {
#line 90 "../src/Services/StarStore.vala"
		return;
#line 571 "StarStore.c"
	}
#line 91 "../src/Services/StarStore.vala"
	_tmp3_ = self->priv->_starred_station_map;
#line 91 "../src/Services/StarStore.vala"
	_tmp4_ = tuner_model_station_get_stationuuid (station);
#line 91 "../src/Services/StarStore.vala"
	_tmp5_ = _tmp4_;
#line 91 "../src/Services/StarStore.vala"
	gee_map_set (_tmp3_, _tmp5_, station);
#line 92 "../src/Services/StarStore.vala"
	tuner_star_store_persist (self);
#line 93 "../src/Services/StarStore.vala"
	g_signal_emit (self, tuner_star_store_signals[TUNER_STAR_STORE_STARRED_STATIONS_CHANGED_SIG_SIGNAL], 0, station);
#line 585 "StarStore.c"
}

/**
     * @brief Removes a station from the favorites and persists the change.
     *
     * @param station The station to be removed.
     */
void
tuner_star_store_remove_station (TunerStarStore* self,
                                 TunerModelStation* station)
{
	GeeMap* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
#line 102 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 102 "../src/Services/StarStore.vala"
	g_return_if_fail (station != NULL);
#line 103 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_starred_station_map;
#line 103 "../src/Services/StarStore.vala"
	_tmp1_ = tuner_model_station_get_stationuuid (station);
#line 103 "../src/Services/StarStore.vala"
	_tmp2_ = _tmp1_;
#line 103 "../src/Services/StarStore.vala"
	gee_map_unset (_tmp0_, _tmp2_, NULL);
#line 104 "../src/Services/StarStore.vala"
	tuner_star_store_persist (self);
#line 105 "../src/Services/StarStore.vala"
	g_signal_emit (self, tuner_star_store_signals[TUNER_STAR_STORE_STARRED_STATIONS_CHANGED_SIG_SIGNAL], 0, station);
#line 616 "StarStore.c"
}

/**
     * @brief Add or removes a station from the favorites and persists the change.
     *
     * @param station The station.
     */
void
tuner_star_store_update_from_station (TunerStarStore* self,
                                      TunerModelStation* station)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
#line 114 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 114 "../src/Services/StarStore.vala"
	g_return_if_fail (station != NULL);
#line 116 "../src/Services/StarStore.vala"
	_tmp0_ = tuner_model_station_get_starred (station);
#line 116 "../src/Services/StarStore.vala"
	_tmp1_ = _tmp0_;
#line 116 "../src/Services/StarStore.vala"
	if (_tmp1_) {
#line 118 "../src/Services/StarStore.vala"
		tuner_star_store_add_station (self, station);
#line 642 "StarStore.c"
	} else {
#line 122 "../src/Services/StarStore.vala"
		tuner_star_store_remove_station (self, station);
#line 646 "StarStore.c"
	}
}

/**
     * @brief Adds a saved search
     *
     * @param search_text The search term to save
     */
void
tuner_star_store_add_saved_search (TunerStarStore* self,
                                   const gchar* search_text)
{
	GeeSet* _tmp0_;
#line 132 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 132 "../src/Services/StarStore.vala"
	g_return_if_fail (search_text != NULL);
#line 134 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_saved_searches;
#line 134 "../src/Services/StarStore.vala"
	gee_collection_add ((GeeCollection*) _tmp0_, search_text);
#line 135 "../src/Services/StarStore.vala"
	tuner_star_store_persist (self);
#line 670 "StarStore.c"
}

/**
     * @brief Removes a saved search
     *
     * @param search_text The search term to remove
     */
void
tuner_star_store_remove_saved_search (TunerStarStore* self,
                                      const gchar* search_text)
{
	GeeSet* _tmp0_;
#line 144 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 144 "../src/Services/StarStore.vala"
	g_return_if_fail (search_text != NULL);
#line 146 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_saved_searches;
#line 146 "../src/Services/StarStore.vala"
	gee_collection_remove ((GeeCollection*) _tmp0_, search_text);
#line 147 "../src/Services/StarStore.vala"
	tuner_star_store_persist (self);
#line 693 "StarStore.c"
}

/**
     * @brief Serializes the current favorites to a JSON string.
     *
     * @return A JSON string representation of the favorites.
     */
static JsonNode*
_vala_JsonNode_copy (JsonNode* self)
{
#line 172 "../src/Services/StarStore.vala"
	return g_boxed_copy (json_node_get_type (), self);
#line 706 "StarStore.c"
}

static gpointer
__vala_JsonNode_copy0 (gpointer self)
{
#line 172 "../src/Services/StarStore.vala"
	return self ? _vala_JsonNode_copy (self) : NULL;
#line 714 "StarStore.c"
}

static void
_vala_JsonNode_free (JsonNode* self)
{
#line 170 "../src/Services/StarStore.vala"
	g_boxed_free (json_node_get_type (), self);
#line 722 "StarStore.c"
}

gchar*
tuner_star_store_serialize (TunerStarStore* self)
{
	JsonBuilder* builder = NULL;
	JsonBuilder* _tmp0_;
	JsonBuilder* _tmp1_;
	JsonBuilder* _tmp2_;
	JsonBuilder* _tmp3_;
	JsonBuilder* _tmp4_;
	JsonBuilder* _tmp5_;
	JsonBuilder* _tmp6_;
	JsonBuilder* _tmp7_;
	JsonBuilder* _tmp8_;
	JsonBuilder* _tmp9_;
	JsonBuilder* _tmp24_;
	JsonBuilder* _tmp25_;
	JsonBuilder* _tmp26_;
	JsonBuilder* _tmp34_;
	JsonBuilder* _tmp35_;
	JsonGenerator* generator = NULL;
	JsonGenerator* _tmp36_;
	JsonBuilder* _tmp37_;
	JsonNode* _tmp38_;
	JsonNode* _tmp39_;
	gchar* data = NULL;
	gchar* _tmp40_;
	gchar* result;
#line 156 "../src/Services/StarStore.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 158 "../src/Services/StarStore.vala"
	_tmp0_ = json_builder_new ();
#line 158 "../src/Services/StarStore.vala"
	builder = _tmp0_;
#line 159 "../src/Services/StarStore.vala"
	_tmp1_ = builder;
#line 159 "../src/Services/StarStore.vala"
	json_builder_begin_object (_tmp1_);
#line 160 "../src/Services/StarStore.vala"
	_tmp2_ = builder;
#line 160 "../src/Services/StarStore.vala"
	json_builder_set_member_name (_tmp2_, TUNER_STAR_STORE_FAVORITES_PROPERTY_APP);
#line 161 "../src/Services/StarStore.vala"
	_tmp3_ = builder;
#line 161 "../src/Services/StarStore.vala"
	json_builder_add_string_value (_tmp3_, TUNER_APPLICATION_APP_ID);
#line 162 "../src/Services/StarStore.vala"
	_tmp4_ = builder;
#line 162 "../src/Services/StarStore.vala"
	json_builder_set_member_name (_tmp4_, TUNER_STAR_STORE_FAVORITES_PROPERTY_FILE);
#line 163 "../src/Services/StarStore.vala"
	_tmp5_ = builder;
#line 163 "../src/Services/StarStore.vala"
	json_builder_add_string_value (_tmp5_, TUNER_APPLICATION_STARRED);
#line 164 "../src/Services/StarStore.vala"
	_tmp6_ = builder;
#line 164 "../src/Services/StarStore.vala"
	json_builder_set_member_name (_tmp6_, TUNER_STAR_STORE_FAVORITES_PROPERTY_SCHEMA);
#line 165 "../src/Services/StarStore.vala"
	_tmp7_ = builder;
#line 165 "../src/Services/StarStore.vala"
	json_builder_add_string_value (_tmp7_, TUNER_STAR_STORE_FAVORITES_SCHEMA_VERSION);
#line 168 "../src/Services/StarStore.vala"
	_tmp8_ = builder;
#line 168 "../src/Services/StarStore.vala"
	json_builder_set_member_name (_tmp8_, TUNER_STAR_STORE_FAVORITES_PROPERTY_STATIONS);
#line 169 "../src/Services/StarStore.vala"
	_tmp9_ = builder;
#line 169 "../src/Services/StarStore.vala"
	json_builder_begin_array (_tmp9_);
#line 794 "StarStore.c"
	{
		GeeIterator* _starred_it = NULL;
		GeeMap* _tmp10_;
		GeeCollection* _tmp11_;
		GeeCollection* _tmp12_;
		GeeCollection* _tmp13_;
		GeeIterator* _tmp14_;
		GeeIterator* _tmp15_;
#line 170 "../src/Services/StarStore.vala"
		_tmp10_ = self->priv->_starred_station_map;
#line 170 "../src/Services/StarStore.vala"
		_tmp11_ = gee_map_get_values (_tmp10_);
#line 170 "../src/Services/StarStore.vala"
		_tmp12_ = _tmp11_;
#line 170 "../src/Services/StarStore.vala"
		_tmp13_ = _tmp12_;
#line 170 "../src/Services/StarStore.vala"
		_tmp14_ = gee_iterable_iterator ((GeeIterable*) _tmp13_);
#line 170 "../src/Services/StarStore.vala"
		_tmp15_ = _tmp14_;
#line 170 "../src/Services/StarStore.vala"
		_g_object_unref0 (_tmp13_);
#line 170 "../src/Services/StarStore.vala"
		_starred_it = _tmp15_;
#line 170 "../src/Services/StarStore.vala"
		while (TRUE) {
#line 821 "StarStore.c"
			GeeIterator* _tmp16_;
			TunerModelStation* starred = NULL;
			GeeIterator* _tmp17_;
			gpointer _tmp18_;
			JsonNode* node = NULL;
			TunerModelStation* _tmp19_;
			JsonNode* _tmp20_;
			JsonBuilder* _tmp21_;
			JsonNode* _tmp22_;
			JsonNode* _tmp23_;
#line 170 "../src/Services/StarStore.vala"
			_tmp16_ = _starred_it;
#line 170 "../src/Services/StarStore.vala"
			if (!gee_iterator_next (_tmp16_)) {
#line 170 "../src/Services/StarStore.vala"
				break;
#line 838 "StarStore.c"
			}
#line 170 "../src/Services/StarStore.vala"
			_tmp17_ = _starred_it;
#line 170 "../src/Services/StarStore.vala"
			_tmp18_ = gee_iterator_get (_tmp17_);
#line 170 "../src/Services/StarStore.vala"
			starred = (TunerModelStation*) _tmp18_;
#line 171 "../src/Services/StarStore.vala"
			_tmp19_ = starred;
#line 171 "../src/Services/StarStore.vala"
			_tmp20_ = json_gobject_serialize ((GObject*) _tmp19_);
#line 171 "../src/Services/StarStore.vala"
			node = _tmp20_;
#line 172 "../src/Services/StarStore.vala"
			_tmp21_ = builder;
#line 172 "../src/Services/StarStore.vala"
			_tmp22_ = node;
#line 172 "../src/Services/StarStore.vala"
			_tmp23_ = __vala_JsonNode_copy0 (_tmp22_);
#line 172 "../src/Services/StarStore.vala"
			json_builder_add_value (_tmp21_, _tmp23_);
#line 170 "../src/Services/StarStore.vala"
			__vala_JsonNode_free0 (node);
#line 170 "../src/Services/StarStore.vala"
			_g_object_unref0 (starred);
#line 864 "StarStore.c"
		}
#line 170 "../src/Services/StarStore.vala"
		_g_object_unref0 (_starred_it);
#line 868 "StarStore.c"
	}
#line 174 "../src/Services/StarStore.vala"
	_tmp24_ = builder;
#line 174 "../src/Services/StarStore.vala"
	json_builder_end_array (_tmp24_);
#line 177 "../src/Services/StarStore.vala"
	_tmp25_ = builder;
#line 177 "../src/Services/StarStore.vala"
	json_builder_set_member_name (_tmp25_, TUNER_STAR_STORE_FAVORITES_PROPERTY_SEARCHES);
#line 178 "../src/Services/StarStore.vala"
	_tmp26_ = builder;
#line 178 "../src/Services/StarStore.vala"
	json_builder_begin_array (_tmp26_);
#line 882 "StarStore.c"
	{
		GeeIterator* _searched_it = NULL;
		GeeSet* _tmp27_;
		GeeIterator* _tmp28_;
#line 179 "../src/Services/StarStore.vala"
		_tmp27_ = self->priv->_saved_searches;
#line 179 "../src/Services/StarStore.vala"
		_tmp28_ = gee_iterable_iterator ((GeeIterable*) _tmp27_);
#line 179 "../src/Services/StarStore.vala"
		_searched_it = _tmp28_;
#line 179 "../src/Services/StarStore.vala"
		while (TRUE) {
#line 895 "StarStore.c"
			GeeIterator* _tmp29_;
			gchar* searched = NULL;
			GeeIterator* _tmp30_;
			gpointer _tmp31_;
			JsonBuilder* _tmp32_;
			const gchar* _tmp33_;
#line 179 "../src/Services/StarStore.vala"
			_tmp29_ = _searched_it;
#line 179 "../src/Services/StarStore.vala"
			if (!gee_iterator_next (_tmp29_)) {
#line 179 "../src/Services/StarStore.vala"
				break;
#line 908 "StarStore.c"
			}
#line 179 "../src/Services/StarStore.vala"
			_tmp30_ = _searched_it;
#line 179 "../src/Services/StarStore.vala"
			_tmp31_ = gee_iterator_get (_tmp30_);
#line 179 "../src/Services/StarStore.vala"
			searched = (gchar*) _tmp31_;
#line 180 "../src/Services/StarStore.vala"
			_tmp32_ = builder;
#line 180 "../src/Services/StarStore.vala"
			_tmp33_ = searched;
#line 180 "../src/Services/StarStore.vala"
			json_builder_add_string_value (_tmp32_, _tmp33_);
#line 179 "../src/Services/StarStore.vala"
			_g_free0 (searched);
#line 924 "StarStore.c"
		}
#line 179 "../src/Services/StarStore.vala"
		_g_object_unref0 (_searched_it);
#line 928 "StarStore.c"
	}
#line 182 "../src/Services/StarStore.vala"
	_tmp34_ = builder;
#line 182 "../src/Services/StarStore.vala"
	json_builder_end_array (_tmp34_);
#line 183 "../src/Services/StarStore.vala"
	_tmp35_ = builder;
#line 183 "../src/Services/StarStore.vala"
	json_builder_end_object (_tmp35_);
#line 185 "../src/Services/StarStore.vala"
	_tmp36_ = json_generator_new ();
#line 185 "../src/Services/StarStore.vala"
	generator = _tmp36_;
#line 186 "../src/Services/StarStore.vala"
	json_generator_set_pretty (generator, TRUE);
#line 187 "../src/Services/StarStore.vala"
	_tmp37_ = builder;
#line 187 "../src/Services/StarStore.vala"
	_tmp38_ = json_builder_get_root (_tmp37_);
#line 187 "../src/Services/StarStore.vala"
	_tmp39_ = _tmp38_;
#line 187 "../src/Services/StarStore.vala"
	json_generator_set_root (generator, _tmp39_);
#line 187 "../src/Services/StarStore.vala"
	__vala_JsonNode_free0 (_tmp39_);
#line 188 "../src/Services/StarStore.vala"
	_tmp40_ = json_generator_to_data (generator, NULL);
#line 188 "../src/Services/StarStore.vala"
	data = _tmp40_;
#line 189 "../src/Services/StarStore.vala"
	result = data;
#line 189 "../src/Services/StarStore.vala"
	_g_object_unref0 (generator);
#line 189 "../src/Services/StarStore.vala"
	_g_object_unref0 (builder);
#line 189 "../src/Services/StarStore.vala"
	return result;
#line 966 "StarStore.c"
}

/**
     * @brief Retrieves all favorite stations.
     *
     * @return An ArrayList of favorite stations.
     */
GeeCollection*
tuner_star_store_get_all_stations (TunerStarStore* self)
{
	GeeMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeCollection* _tmp2_;
	GeeCollection* result;
#line 198 "../src/Services/StarStore.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 199 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_starred_station_map;
#line 199 "../src/Services/StarStore.vala"
	_tmp1_ = gee_map_get_values (_tmp0_);
#line 199 "../src/Services/StarStore.vala"
	_tmp2_ = _tmp1_;
#line 199 "../src/Services/StarStore.vala"
	result = _tmp2_;
#line 199 "../src/Services/StarStore.vala"
	return result;
#line 993 "StarStore.c"
}

/**
     * @brief Retrieves all favorite stations.
     *
     * @return An ArrayList of favorite stations.
     */
GeeSet*
tuner_star_store_get_all_searches (TunerStarStore* self)
{
	GeeSet* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* result;
#line 208 "../src/Services/StarStore.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 209 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_saved_searches;
#line 209 "../src/Services/StarStore.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 209 "../src/Services/StarStore.vala"
	result = _tmp1_;
#line 209 "../src/Services/StarStore.vala"
	return result;
#line 1017 "StarStore.c"
}

/**
     * @brief Checks if a station is in the favorites.
     *
     * @param station The station to check.
     * @return True if the station is in favorites, false otherwise.
     */
gboolean
tuner_star_store_contains (TunerStarStore* self,
                           TunerModelStation* station)
{
	GeeMap* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gboolean result;
#line 219 "../src/Services/StarStore.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 219 "../src/Services/StarStore.vala"
	g_return_val_if_fail (station != NULL, FALSE);
#line 220 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_starred_station_map;
#line 220 "../src/Services/StarStore.vala"
	_tmp1_ = tuner_model_station_get_stationuuid (station);
#line 220 "../src/Services/StarStore.vala"
	_tmp2_ = _tmp1_;
#line 220 "../src/Services/StarStore.vala"
	result = gee_map_has_key (_tmp0_, _tmp2_);
#line 220 "../src/Services/StarStore.vala"
	return result;
#line 1048 "StarStore.c"
}

/**
     * @brief Updates a station in the favorites.
     *
     * @param station The station to update.
     */
void
tuner_star_store_update (TunerStarStore* self,
                         TunerModelStation* station)
{
	GeeMap* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
#line 229 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 229 "../src/Services/StarStore.vala"
	g_return_if_fail (station != NULL);
#line 231 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_starred_station_map;
#line 231 "../src/Services/StarStore.vala"
	_tmp1_ = tuner_model_station_get_stationuuid (station);
#line 231 "../src/Services/StarStore.vala"
	_tmp2_ = _tmp1_;
#line 231 "../src/Services/StarStore.vala"
	if (gee_map_has_key (_tmp0_, _tmp2_)) {
#line 1075 "StarStore.c"
		GeeMap* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		TunerModelStation* _tmp6_;
		TunerModelStation* _tmp7_;
#line 233 "../src/Services/StarStore.vala"
		_tmp3_ = self->priv->_starred_station_map;
#line 233 "../src/Services/StarStore.vala"
		_tmp4_ = tuner_model_station_get_stationuuid (station);
#line 233 "../src/Services/StarStore.vala"
		_tmp5_ = _tmp4_;
#line 233 "../src/Services/StarStore.vala"
		_tmp6_ = tuner_model_station_updated (station);
#line 233 "../src/Services/StarStore.vala"
		_tmp7_ = _tmp6_;
#line 233 "../src/Services/StarStore.vala"
		gee_map_set (_tmp3_, _tmp5_, _tmp7_);
#line 233 "../src/Services/StarStore.vala"
		_g_object_unref0 (_tmp7_);
#line 234 "../src/Services/StarStore.vala"
		tuner_star_store_persist (self);
#line 1097 "StarStore.c"
	}
}

static void
tuner_star_store_load_data_free (gpointer _data)
{
	TunerStarStoreLoadData* _data_;
	_data_ = _data;
#line 33 "../src/Services/StarStore.vala"
	_g_object_unref0 (_data_->self);
#line 33 "../src/Services/StarStore.vala"
	g_slice_free (TunerStarStoreLoadData, _data_);
#line 1110 "StarStore.c"
}

void
tuner_star_store_load (TunerStarStore* self,
                       GAsyncReadyCallback _callback_,
                       gpointer _user_data_)
{
	TunerStarStoreLoadData* _data_;
	TunerStarStore* _tmp0_;
#line 33 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 33 "../src/Services/StarStore.vala"
	_data_ = g_slice_new0 (TunerStarStoreLoadData);
#line 33 "../src/Services/StarStore.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 33 "../src/Services/StarStore.vala"
	g_task_set_task_data (_data_->_async_result, _data_, tuner_star_store_load_data_free);
#line 33 "../src/Services/StarStore.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "../src/Services/StarStore.vala"
	_data_->self = _tmp0_;
#line 33 "../src/Services/StarStore.vala"
	tuner_star_store_load_co (_data_);
#line 1134 "StarStore.c"
}

void
tuner_star_store_load_finish (TunerStarStore* self,
                              GAsyncResult* _res_)
{
	TunerStarStoreLoadData* _data_;
#line 33 "../src/Services/StarStore.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 1144 "StarStore.c"
}

/**
     * @brief Loads the favorites from the JSON file.
     *
     * Starred staions are defined by the file and do not load from the DataProvider
     * and so can deviate. If the station disapears from the DataProvider, a copy
     * of its info remain in the starred file.
     * Load needs to happen after Application creation. 
     * 
     * This method reads the JSON file and populates the _store with
     * the favorite stations.
     */
static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
#line 1624 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1625 "glib-2.0.vapi"
	result = self;
#line 1625 "glib-2.0.vapi"
	return result;
#line 1168 "StarStore.c"
}

static gpointer
_json_array_ref0 (gpointer self)
{
#line 289 "../src/Services/StarStore.vala"
	return self ? json_array_ref (self) : NULL;
#line 1176 "StarStore.c"
}

static Block7Data*
block7_data_ref (Block7Data* _data7_)
{
#line 306 "../src/Services/StarStore.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 306 "../src/Services/StarStore.vala"
	return _data7_;
#line 1186 "StarStore.c"
}

static void
block7_data_unref (void * _userdata_)
{
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 306 "../src/Services/StarStore.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 1196 "StarStore.c"
		TunerStarStore* self;
#line 306 "../src/Services/StarStore.vala"
		self = _data7_->self;
#line 306 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data7_->station);
#line 306 "../src/Services/StarStore.vala"
		_g_object_unref0 (self);
#line 306 "../src/Services/StarStore.vala"
		g_slice_free (Block7Data, _data7_);
#line 1206 "StarStore.c"
	}
}

static void
__lambda34_ (Block7Data* _data7_,
             gboolean starred)
{
	TunerStarStore* self;
#line 314 "../src/Services/StarStore.vala"
	self = _data7_->self;
#line 316 "../src/Services/StarStore.vala"
	tuner_star_store_update_from_station (self, _data7_->station);
#line 1219 "StarStore.c"
}

static void
___lambda34__tuner_model_station_station_star_changed_sig (TunerModelStation* _sender,
                                                           gboolean starred,
                                                           gpointer self)
{
#line 314 "../src/Services/StarStore.vala"
	__lambda34_ (self, starred);
#line 1229 "StarStore.c"
}

static void
__lambda31_ (TunerStarStore* self,
             JsonArray* a,
             guint i,
             JsonNode* elem)
{
	Block7Data* _data7_;
	TunerModelStation* _tmp0_;
	GeeMap* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
#line 306 "../src/Services/StarStore.vala"
	g_return_if_fail (a != NULL);
#line 306 "../src/Services/StarStore.vala"
	g_return_if_fail (elem != NULL);
#line 306 "../src/Services/StarStore.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 306 "../src/Services/StarStore.vala"
	_data7_->_ref_count_ = 1;
#line 306 "../src/Services/StarStore.vala"
	_data7_->self = g_object_ref (self);
#line 308 "../src/Services/StarStore.vala"
	_tmp0_ = tuner_model_station_new_basic (elem);
#line 308 "../src/Services/StarStore.vala"
	_data7_->station = _tmp0_;
#line 309 "../src/Services/StarStore.vala"
	_tmp1_ = self->priv->_starred_station_map;
#line 309 "../src/Services/StarStore.vala"
	_tmp2_ = tuner_model_station_get_stationuuid (_data7_->station);
#line 309 "../src/Services/StarStore.vala"
	_tmp3_ = _tmp2_;
#line 309 "../src/Services/StarStore.vala"
	gee_map_set (_tmp1_, _tmp3_, _data7_->station);
#line 311 "../src/Services/StarStore.vala"
	tuner_model_station_set_starred (_data7_->station, TRUE);
#line 314 "../src/Services/StarStore.vala"
	g_signal_connect_data (_data7_->station, "station-star-changed-sig", (GCallback) ___lambda34__tuner_model_station_station_star_changed_sig, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
#line 306 "../src/Services/StarStore.vala"
	block7_data_unref (_data7_);
#line 306 "../src/Services/StarStore.vala"
	_data7_ = NULL;
#line 1273 "StarStore.c"
}

static void
___lambda31__json_array_foreach (JsonArray* array,
                                 guint index_,
                                 JsonNode* element_node,
                                 gpointer self)
{
#line 306 "../src/Services/StarStore.vala"
	__lambda31_ ((TunerStarStore*) self, array, index_, element_node);
#line 1284 "StarStore.c"
}

static void
__lambda35_ (TunerStarStore* self,
             JsonArray* a,
             guint i,
             JsonNode* elem)
{
	GeeSet* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
#line 334 "../src/Services/StarStore.vala"
	g_return_if_fail (a != NULL);
#line 334 "../src/Services/StarStore.vala"
	g_return_if_fail (elem != NULL);
#line 335 "../src/Services/StarStore.vala"
	_tmp0_ = self->priv->_saved_searches;
#line 335 "../src/Services/StarStore.vala"
	_tmp1_ = json_node_get_string (elem);
#line 335 "../src/Services/StarStore.vala"
	gee_collection_add ((GeeCollection*) _tmp0_, _tmp1_);
#line 336 "../src/Services/StarStore.vala"
	_tmp2_ = json_node_get_string (elem);
#line 336 "../src/Services/StarStore.vala"
	_tmp3_ = string_to_string (_tmp2_);
#line 336 "../src/Services/StarStore.vala"
	_tmp4_ = g_strconcat ("Search:", _tmp3_, NULL);
#line 336 "../src/Services/StarStore.vala"
	_tmp5_ = _tmp4_;
#line 336 "../src/Services/StarStore.vala"
	g_debug ("StarStore.vala:336: %s", _tmp5_);
#line 336 "../src/Services/StarStore.vala"
	_g_free0 (_tmp5_);
#line 1321 "StarStore.c"
}

static void
___lambda35__json_array_foreach (JsonArray* array,
                                 guint index_,
                                 JsonNode* element_node,
                                 gpointer self)
{
#line 334 "../src/Services/StarStore.vala"
	__lambda35_ ((TunerStarStore*) self, array, index_, element_node);
#line 1332 "StarStore.c"
}

static gboolean
tuner_star_store_load_co (TunerStarStoreLoadData* _data_)
{
#line 250 "../src/Services/StarStore.vala"
	switch (_data_->_state_) {
#line 250 "../src/Services/StarStore.vala"
		case 0:
#line 1342 "StarStore.c"
		goto _state_0;
		default:
#line 250 "../src/Services/StarStore.vala"
		g_assert_not_reached ();
#line 1347 "StarStore.c"
	}
	_state_0:
#line 252 "../src/Services/StarStore.vala"
	if (_data_->self->priv->_loaded) {
#line 252 "../src/Services/StarStore.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 252 "../src/Services/StarStore.vala"
		if (_data_->_state_ != 0) {
#line 252 "../src/Services/StarStore.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 252 "../src/Services/StarStore.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1360 "StarStore.c"
			}
		}
#line 252 "../src/Services/StarStore.vala"
		g_object_unref (_data_->_async_result);
#line 252 "../src/Services/StarStore.vala"
		return FALSE;
#line 1367 "StarStore.c"
	}
#line 253 "../src/Services/StarStore.vala"
	_data_->self->priv->_loaded = TRUE;
#line 254 "../src/Services/StarStore.vala"
	g_debug ("StarStore.vala:254: store file initial creation");
#line 1373 "StarStore.c"
	{
#line 258 "../src/Services/StarStore.vala"
		_data_->_tmp1_ = _data_->self->priv->_starred_file;
#line 258 "../src/Services/StarStore.vala"
		_data_->_tmp2_ = g_file_create (_data_->_tmp1_, G_FILE_CREATE_PRIVATE, NULL, &_data_->_inner_error0_);
#line 258 "../src/Services/StarStore.vala"
		_data_->_tmp0_ = _data_->_tmp2_;
#line 258 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 1383 "StarStore.c"
			goto __catch0_g_error;
		}
#line 258 "../src/Services/StarStore.vala"
		g_output_stream_close ((GOutputStream*) _data_->_tmp0_, NULL, &_data_->_inner_error0_);
#line 258 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 258 "../src/Services/StarStore.vala"
			_g_object_unref0 (_data_->_tmp0_);
#line 1392 "StarStore.c"
			goto __catch0_g_error;
		}
#line 260 "../src/Services/StarStore.vala"
		g_debug ("StarStore.vala:260: %s", "store created");
#line 255 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->_tmp0_);
#line 1399 "StarStore.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 255 "../src/Services/StarStore.vala"
		g_clear_error (&_data_->_inner_error0_);
#line 1406 "StarStore.c"
	}
	__finally0:
#line 255 "../src/Services/StarStore.vala"
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 255 "../src/Services/StarStore.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 255 "../src/Services/StarStore.vala"
		g_clear_error (&_data_->_inner_error0_);
#line 255 "../src/Services/StarStore.vala"
		g_object_unref (_data_->_async_result);
#line 255 "../src/Services/StarStore.vala"
		return FALSE;
#line 1419 "StarStore.c"
	}
#line 265 "../src/Services/StarStore.vala"
	g_debug ("StarStore.vala:265: loading store");
#line 266 "../src/Services/StarStore.vala"
	_data_->_tmp3_ = json_parser_new_immutable ();
#line 266 "../src/Services/StarStore.vala"
	_data_->parser = _data_->_tmp3_;
#line 1427 "StarStore.c"
	{
#line 269 "../src/Services/StarStore.vala"
		_data_->_tmp4_ = _data_->self->priv->_starred_file;
#line 269 "../src/Services/StarStore.vala"
		_data_->_tmp5_ = g_file_read (_data_->_tmp4_, NULL, &_data_->_inner_error0_);
#line 269 "../src/Services/StarStore.vala"
		_data_->stream = _data_->_tmp5_;
#line 269 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 1437 "StarStore.c"
			goto __catch1_g_error;
		}
#line 270 "../src/Services/StarStore.vala"
		_data_->_tmp6_ = _data_->parser;
#line 270 "../src/Services/StarStore.vala"
		_data_->_tmp7_ = _data_->stream;
#line 270 "../src/Services/StarStore.vala"
		json_parser_load_from_stream (_data_->_tmp6_, (GInputStream*) _data_->_tmp7_, NULL, &_data_->_inner_error0_);
#line 270 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 270 "../src/Services/StarStore.vala"
			_g_object_unref0 (_data_->stream);
#line 1450 "StarStore.c"
			goto __catch1_g_error;
		}
#line 271 "../src/Services/StarStore.vala"
		_data_->_tmp8_ = _data_->stream;
#line 271 "../src/Services/StarStore.vala"
		g_input_stream_close ((GInputStream*) _data_->_tmp8_, NULL, &_data_->_inner_error0_);
#line 271 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 271 "../src/Services/StarStore.vala"
			_g_object_unref0 (_data_->stream);
#line 1461 "StarStore.c"
			goto __catch1_g_error;
		}
#line 268 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->stream);
#line 1466 "StarStore.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
#line 268 "../src/Services/StarStore.vala"
		_data_->e = _data_->_inner_error0_;
#line 268 "../src/Services/StarStore.vala"
		_data_->_inner_error0_ = NULL;
#line 273 "../src/Services/StarStore.vala"
		_data_->_tmp9_ = _data_->e;
#line 273 "../src/Services/StarStore.vala"
		_data_->_tmp10_ = _data_->_tmp9_->message;
#line 273 "../src/Services/StarStore.vala"
		_data_->_tmp11_ = string_to_string (_data_->_tmp10_);
#line 273 "../src/Services/StarStore.vala"
		_data_->_tmp12_ = g_strconcat ("Load failed with error: ", _data_->_tmp11_, NULL);
#line 273 "../src/Services/StarStore.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 273 "../src/Services/StarStore.vala"
		g_warning ("StarStore.vala:273: %s", _data_->_tmp13_);
#line 273 "../src/Services/StarStore.vala"
		_g_free0 (_data_->_tmp13_);
#line 268 "../src/Services/StarStore.vala"
		_g_error_free0 (_data_->e);
#line 1491 "StarStore.c"
	}
	__finally1:
#line 268 "../src/Services/StarStore.vala"
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 268 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->parser);
#line 268 "../src/Services/StarStore.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 268 "../src/Services/StarStore.vala"
		g_clear_error (&_data_->_inner_error0_);
#line 268 "../src/Services/StarStore.vala"
		g_object_unref (_data_->_async_result);
#line 268 "../src/Services/StarStore.vala"
		return FALSE;
#line 1506 "StarStore.c"
	}
#line 276 "../src/Services/StarStore.vala"
	_data_->_tmp14_ = _data_->parser;
#line 276 "../src/Services/StarStore.vala"
	_data_->_tmp15_ = json_parser_get_root (_data_->_tmp14_);
#line 276 "../src/Services/StarStore.vala"
	_data_->_tmp16_ = __vala_JsonNode_copy0 (_data_->_tmp15_);
#line 276 "../src/Services/StarStore.vala"
	_data_->root = _data_->_tmp16_;
#line 278 "../src/Services/StarStore.vala"
	_data_->_tmp17_ = _data_->root;
#line 278 "../src/Services/StarStore.vala"
	if (_data_->_tmp17_ == NULL) {
#line 278 "../src/Services/StarStore.vala"
		__vala_JsonNode_free0 (_data_->root);
#line 278 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->parser);
#line 278 "../src/Services/StarStore.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 278 "../src/Services/StarStore.vala"
		if (_data_->_state_ != 0) {
#line 278 "../src/Services/StarStore.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 278 "../src/Services/StarStore.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1532 "StarStore.c"
			}
		}
#line 278 "../src/Services/StarStore.vala"
		g_object_unref (_data_->_async_result);
#line 278 "../src/Services/StarStore.vala"
		return FALSE;
#line 1539 "StarStore.c"
	}
#line 284 "../src/Services/StarStore.vala"
	_data_->_tmp18_ = _data_->root;
#line 284 "../src/Services/StarStore.vala"
	_data_->_tmp19_ = tuner_star_store_get_member (_data_->_tmp18_, TUNER_STAR_STORE_FAVORITES_PROPERTY_SCHEMA);
#line 284 "../src/Services/StarStore.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 284 "../src/Services/StarStore.vala"
	_data_->_tmp21_ = _data_->_tmp20_ == NULL;
#line 284 "../src/Services/StarStore.vala"
	__vala_JsonNode_free0 (_data_->_tmp20_);
#line 284 "../src/Services/StarStore.vala"
	if (_data_->_tmp21_) {
#line 289 "../src/Services/StarStore.vala"
		_data_->_tmp22_ = _data_->root;
#line 289 "../src/Services/StarStore.vala"
		_data_->_tmp23_ = json_node_get_array (_data_->_tmp22_);
#line 289 "../src/Services/StarStore.vala"
		_data_->_tmp24_ = _json_array_ref0 (_data_->_tmp23_);
#line 289 "../src/Services/StarStore.vala"
		_json_array_unref0 (_data_->jstarred);
#line 289 "../src/Services/StarStore.vala"
		_data_->jstarred = _data_->_tmp24_;
#line 290 "../src/Services/StarStore.vala"
		_json_array_unref0 (_data_->jsearches);
#line 290 "../src/Services/StarStore.vala"
		_data_->jsearches = NULL;
#line 1567 "StarStore.c"
	} else {
#line 297 "../src/Services/StarStore.vala"
		_data_->_tmp25_ = _data_->root;
#line 297 "../src/Services/StarStore.vala"
		_data_->_tmp26_ = tuner_star_store_get_member (_data_->_tmp25_, TUNER_STAR_STORE_FAVORITES_PROPERTY_STATIONS);
#line 297 "../src/Services/StarStore.vala"
		_data_->stations = _data_->_tmp26_;
#line 298 "../src/Services/StarStore.vala"
		_data_->_tmp27_ = _data_->stations;
#line 298 "../src/Services/StarStore.vala"
		_data_->_tmp28_ = json_node_get_array (_data_->_tmp27_);
#line 298 "../src/Services/StarStore.vala"
		_data_->_tmp29_ = _json_array_ref0 (_data_->_tmp28_);
#line 298 "../src/Services/StarStore.vala"
		_json_array_unref0 (_data_->jstarred);
#line 298 "../src/Services/StarStore.vala"
		_data_->jstarred = _data_->_tmp29_;
#line 299 "../src/Services/StarStore.vala"
		_data_->_tmp30_ = _data_->root;
#line 299 "../src/Services/StarStore.vala"
		_data_->_tmp31_ = tuner_star_store_get_member (_data_->_tmp30_, TUNER_STAR_STORE_FAVORITES_PROPERTY_SEARCHES);
#line 299 "../src/Services/StarStore.vala"
		_data_->searches = _data_->_tmp31_;
#line 300 "../src/Services/StarStore.vala"
		_data_->_tmp32_ = _data_->searches;
#line 300 "../src/Services/StarStore.vala"
		_data_->_tmp33_ = json_node_get_array (_data_->_tmp32_);
#line 300 "../src/Services/StarStore.vala"
		_data_->_tmp34_ = _json_array_ref0 (_data_->_tmp33_);
#line 300 "../src/Services/StarStore.vala"
		_json_array_unref0 (_data_->jsearches);
#line 300 "../src/Services/StarStore.vala"
		_data_->jsearches = _data_->_tmp34_;
#line 284 "../src/Services/StarStore.vala"
		__vala_JsonNode_free0 (_data_->searches);
#line 284 "../src/Services/StarStore.vala"
		__vala_JsonNode_free0 (_data_->stations);
#line 1605 "StarStore.c"
	}
#line 306 "../src/Services/StarStore.vala"
	_data_->_tmp35_ = _data_->jstarred;
#line 306 "../src/Services/StarStore.vala"
	json_array_foreach_element (_data_->_tmp35_, ___lambda31__json_array_foreach, _data_->self);
#line 1611 "StarStore.c"
	{
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp36_ = tuner_app ();
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp37_ = _data_->_tmp36_;
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp38_ = tuner_application_get_provider (_data_->_tmp37_);
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp39_ = _data_->_tmp38_;
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp40_ = _data_->self->priv->_starred_station_map;
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp41_ = gee_map_get_keys (_data_->_tmp40_);
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp42_ = _data_->_tmp41_;
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp43_ = _data_->_tmp42_;
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp44_ = tuner_data_provider_api_by_uuids (_data_->_tmp39_, (GeeCollection*) _data_->_tmp43_, &_data_->_inner_error0_);
#line 322 "../src/Services/StarStore.vala"
		_data_->_tmp45_ = _data_->_tmp44_;
#line 322 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->_tmp43_);
#line 322 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->_tmp37_);
#line 322 "../src/Services/StarStore.vala"
		_data_->provider_station = _data_->_tmp45_;
#line 322 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 322 "../src/Services/StarStore.vala"
			if (_data_->_inner_error0_->domain == TUNER_DATA_PROVIDER_DATA_ERROR) {
#line 1643 "StarStore.c"
				goto __catch2_tuner_data_provider_data_error;
			}
#line 322 "../src/Services/StarStore.vala"
			_json_array_unref0 (_data_->jsearches);
#line 322 "../src/Services/StarStore.vala"
			_json_array_unref0 (_data_->jstarred);
#line 322 "../src/Services/StarStore.vala"
			__vala_JsonNode_free0 (_data_->root);
#line 322 "../src/Services/StarStore.vala"
			_g_object_unref0 (_data_->parser);
#line 322 "../src/Services/StarStore.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 322 "../src/Services/StarStore.vala"
			g_clear_error (&_data_->_inner_error0_);
#line 322 "../src/Services/StarStore.vala"
			g_object_unref (_data_->_async_result);
#line 322 "../src/Services/StarStore.vala"
			return FALSE;
#line 1662 "StarStore.c"
		}
		{
#line 323 "../src/Services/StarStore.vala"
			_data_->_tmp46_ = _data_->provider_station;
#line 323 "../src/Services/StarStore.vala"
			_data_->_tmp47_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp46_);
#line 323 "../src/Services/StarStore.vala"
			_data_->_ps_it = _data_->_tmp47_;
#line 323 "../src/Services/StarStore.vala"
			while (TRUE) {
#line 323 "../src/Services/StarStore.vala"
				_data_->_tmp48_ = _data_->_ps_it;
#line 323 "../src/Services/StarStore.vala"
				if (!gee_iterator_next (_data_->_tmp48_)) {
#line 323 "../src/Services/StarStore.vala"
					break;
#line 1679 "StarStore.c"
				}
#line 323 "../src/Services/StarStore.vala"
				_data_->_tmp49_ = _data_->_ps_it;
#line 323 "../src/Services/StarStore.vala"
				_data_->_tmp50_ = gee_iterator_get (_data_->_tmp49_);
#line 323 "../src/Services/StarStore.vala"
				_data_->ps = (TunerModelStation*) _data_->_tmp50_;
#line 325 "../src/Services/StarStore.vala"
				_data_->_tmp51_ = _data_->self->priv->_starred_station_map;
#line 325 "../src/Services/StarStore.vala"
				_data_->_tmp52_ = _data_->ps;
#line 325 "../src/Services/StarStore.vala"
				_data_->_tmp53_ = tuner_model_station_get_stationuuid (_data_->_tmp52_);
#line 325 "../src/Services/StarStore.vala"
				_data_->_tmp54_ = _data_->_tmp53_;
#line 325 "../src/Services/StarStore.vala"
				_data_->_tmp55_ = gee_map_get (_data_->_tmp51_, _data_->_tmp54_);
#line 325 "../src/Services/StarStore.vala"
				_data_->ss = (TunerModelStation*) _data_->_tmp55_;
#line 326 "../src/Services/StarStore.vala"
				_data_->_tmp56_ = _data_->ss;
#line 326 "../src/Services/StarStore.vala"
				if (_data_->_tmp56_ != NULL) {
#line 326 "../src/Services/StarStore.vala"
					_data_->_tmp57_ = _data_->ss;
#line 326 "../src/Services/StarStore.vala"
					_data_->_tmp58_ = _data_->ss;
#line 326 "../src/Services/StarStore.vala"
					_data_->_tmp59_ = _data_->ps;
#line 326 "../src/Services/StarStore.vala"
					_data_->_tmp57_->is_in_index = tuner_model_station_set_up_to_date_with (_data_->_tmp58_, _data_->_tmp59_);
#line 1711 "StarStore.c"
				}
#line 323 "../src/Services/StarStore.vala"
				_g_object_unref0 (_data_->ss);
#line 323 "../src/Services/StarStore.vala"
				_g_object_unref0 (_data_->ps);
#line 1717 "StarStore.c"
			}
#line 323 "../src/Services/StarStore.vala"
			_g_object_unref0 (_data_->_ps_it);
#line 1721 "StarStore.c"
		}
#line 321 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->provider_station);
#line 1725 "StarStore.c"
	}
	goto __finally2;
	__catch2_tuner_data_provider_data_error:
	{
#line 321 "../src/Services/StarStore.vala"
		_data_->_vala1_e = _data_->_inner_error0_;
#line 321 "../src/Services/StarStore.vala"
		_data_->_inner_error0_ = NULL;
#line 330 "../src/Services/StarStore.vala"
		_data_->_tmp60_ = _data_->_vala1_e;
#line 330 "../src/Services/StarStore.vala"
		_data_->_tmp61_ = _data_->_tmp60_->message;
#line 330 "../src/Services/StarStore.vala"
		_data_->_tmp62_ = string_to_string (_data_->_tmp61_);
#line 330 "../src/Services/StarStore.vala"
		_data_->_tmp63_ = g_strconcat ("Comparing with DataProvider copy of station: ", _data_->_tmp62_, NULL);
#line 330 "../src/Services/StarStore.vala"
		_data_->_tmp64_ = _data_->_tmp63_;
#line 330 "../src/Services/StarStore.vala"
		g_warning ("StarStore.vala:330: %s", _data_->_tmp64_);
#line 330 "../src/Services/StarStore.vala"
		_g_free0 (_data_->_tmp64_);
#line 321 "../src/Services/StarStore.vala"
		_g_error_free0 (_data_->_vala1_e);
#line 1750 "StarStore.c"
	}
	__finally2:
#line 321 "../src/Services/StarStore.vala"
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 321 "../src/Services/StarStore.vala"
		_json_array_unref0 (_data_->jsearches);
#line 321 "../src/Services/StarStore.vala"
		_json_array_unref0 (_data_->jstarred);
#line 321 "../src/Services/StarStore.vala"
		__vala_JsonNode_free0 (_data_->root);
#line 321 "../src/Services/StarStore.vala"
		_g_object_unref0 (_data_->parser);
#line 321 "../src/Services/StarStore.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 321 "../src/Services/StarStore.vala"
		g_clear_error (&_data_->_inner_error0_);
#line 321 "../src/Services/StarStore.vala"
		g_object_unref (_data_->_async_result);
#line 321 "../src/Services/StarStore.vala"
		return FALSE;
#line 1771 "StarStore.c"
	}
#line 334 "../src/Services/StarStore.vala"
	_data_->_tmp65_ = _data_->jsearches;
#line 334 "../src/Services/StarStore.vala"
	json_array_foreach_element (_data_->_tmp65_, ___lambda35__json_array_foreach, _data_->self);
#line 250 "../src/Services/StarStore.vala"
	_json_array_unref0 (_data_->jsearches);
#line 250 "../src/Services/StarStore.vala"
	_json_array_unref0 (_data_->jstarred);
#line 250 "../src/Services/StarStore.vala"
	__vala_JsonNode_free0 (_data_->root);
#line 250 "../src/Services/StarStore.vala"
	_g_object_unref0 (_data_->parser);
#line 250 "../src/Services/StarStore.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 250 "../src/Services/StarStore.vala"
	if (_data_->_state_ != 0) {
#line 250 "../src/Services/StarStore.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 250 "../src/Services/StarStore.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1793 "StarStore.c"
		}
	}
#line 250 "../src/Services/StarStore.vala"
	g_object_unref (_data_->_async_result);
#line 250 "../src/Services/StarStore.vala"
	return FALSE;
#line 1800 "StarStore.c"
}

/**
     * @brief Creates a string of Starred stations in m3u format
     * @return A string representation of the favorites formated as M3U
     */
gchar*
tuner_star_store_export_m3u8 (TunerStarStore* self)
{
	GString* playlist = NULL;
	GString* _tmp0_;
	GString* _tmp47_;
	const gchar* _tmp48_;
	gchar* _tmp49_;
	gchar* result;
#line 346 "../src/Services/StarStore.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 348 "../src/Services/StarStore.vala"
	_tmp0_ = g_string_new (TUNER_STAR_STORE_M3U8);
#line 348 "../src/Services/StarStore.vala"
	playlist = _tmp0_;
#line 1822 "StarStore.c"
	{
		GeeIterator* _station_it = NULL;
		GeeMap* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_;
		GeeIterator* _tmp6_;
#line 349 "../src/Services/StarStore.vala"
		_tmp1_ = self->priv->_starred_station_map;
#line 349 "../src/Services/StarStore.vala"
		_tmp2_ = gee_map_get_values (_tmp1_);
#line 349 "../src/Services/StarStore.vala"
		_tmp3_ = _tmp2_;
#line 349 "../src/Services/StarStore.vala"
		_tmp4_ = _tmp3_;
#line 349 "../src/Services/StarStore.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 349 "../src/Services/StarStore.vala"
		_tmp6_ = _tmp5_;
#line 349 "../src/Services/StarStore.vala"
		_g_object_unref0 (_tmp4_);
#line 349 "../src/Services/StarStore.vala"
		_station_it = _tmp6_;
#line 349 "../src/Services/StarStore.vala"
		while (TRUE) {
#line 1849 "StarStore.c"
			GeeIterator* _tmp7_;
			TunerModelStation* station = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			const gchar* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			TunerModelStation* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
			gchar* url = NULL;
			gchar* _tmp24_;
			GString* _tmp25_;
			TunerModelStation* _tmp26_;
			const gchar* _tmp27_;
			const gchar* _tmp28_;
			const gchar* _tmp29_;
			TunerModelStation* _tmp30_;
			const gchar* _tmp31_;
			const gchar* _tmp32_;
			const gchar* _tmp33_;
			const gchar* _tmp34_;
			TunerModelStation* _tmp35_;
			const gchar* _tmp36_;
			const gchar* _tmp37_;
			const gchar* _tmp38_;
			const gchar* _tmp39_;
			const gchar* _tmp40_;
			TunerModelStation* _tmp41_;
			const gchar* _tmp42_;
			const gchar* _tmp43_;
			const gchar* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
#line 349 "../src/Services/StarStore.vala"
			_tmp7_ = _station_it;
#line 349 "../src/Services/StarStore.vala"
			if (!gee_iterator_next (_tmp7_)) {
#line 349 "../src/Services/StarStore.vala"
				break;
#line 1889 "StarStore.c"
			}
#line 349 "../src/Services/StarStore.vala"
			_tmp8_ = _station_it;
#line 349 "../src/Services/StarStore.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 349 "../src/Services/StarStore.vala"
			station = (TunerModelStation*) _tmp9_;
#line 351 "../src/Services/StarStore.vala"
			_tmp12_ = station;
#line 351 "../src/Services/StarStore.vala"
			_tmp13_ = tuner_model_station_get_urlResolved (_tmp12_);
#line 351 "../src/Services/StarStore.vala"
			_tmp14_ = _tmp13_;
#line 351 "../src/Services/StarStore.vala"
			if (_tmp14_ == NULL) {
#line 351 "../src/Services/StarStore.vala"
				_tmp11_ = TRUE;
#line 1907 "StarStore.c"
			} else {
				TunerModelStation* _tmp15_;
				const gchar* _tmp16_;
				const gchar* _tmp17_;
#line 351 "../src/Services/StarStore.vala"
				_tmp15_ = station;
#line 351 "../src/Services/StarStore.vala"
				_tmp16_ = tuner_model_station_get_urlResolved (_tmp15_);
#line 351 "../src/Services/StarStore.vala"
				_tmp17_ = _tmp16_;
#line 351 "../src/Services/StarStore.vala"
				_tmp11_ = g_strcmp0 (_tmp17_, "") == 0;
#line 1920 "StarStore.c"
			}
#line 351 "../src/Services/StarStore.vala"
			if (_tmp11_) {
#line 1924 "StarStore.c"
				TunerModelStation* _tmp18_;
				const gchar* _tmp19_;
				const gchar* _tmp20_;
#line 351 "../src/Services/StarStore.vala"
				_tmp18_ = station;
#line 351 "../src/Services/StarStore.vala"
				_tmp19_ = tuner_model_station_get_url (_tmp18_);
#line 351 "../src/Services/StarStore.vala"
				_tmp20_ = _tmp19_;
#line 351 "../src/Services/StarStore.vala"
				_tmp10_ = _tmp20_;
#line 1936 "StarStore.c"
			} else {
				TunerModelStation* _tmp21_;
				const gchar* _tmp22_;
				const gchar* _tmp23_;
#line 351 "../src/Services/StarStore.vala"
				_tmp21_ = station;
#line 351 "../src/Services/StarStore.vala"
				_tmp22_ = tuner_model_station_get_urlResolved (_tmp21_);
#line 351 "../src/Services/StarStore.vala"
				_tmp23_ = _tmp22_;
#line 351 "../src/Services/StarStore.vala"
				_tmp10_ = _tmp23_;
#line 1949 "StarStore.c"
			}
#line 351 "../src/Services/StarStore.vala"
			_tmp24_ = g_strdup (_tmp10_);
#line 351 "../src/Services/StarStore.vala"
			url = _tmp24_;
#line 352 "../src/Services/StarStore.vala"
			_tmp25_ = playlist;
#line 352 "../src/Services/StarStore.vala"
			_tmp26_ = station;
#line 352 "../src/Services/StarStore.vala"
			_tmp27_ = tuner_model_station_get_name (_tmp26_);
#line 352 "../src/Services/StarStore.vala"
			_tmp28_ = _tmp27_;
#line 352 "../src/Services/StarStore.vala"
			_tmp29_ = string_to_string (_tmp28_);
#line 352 "../src/Services/StarStore.vala"
			_tmp30_ = station;
#line 352 "../src/Services/StarStore.vala"
			_tmp31_ = tuner_model_favicon_get_favicon ((TunerModelFavicon*) _tmp30_);
#line 352 "../src/Services/StarStore.vala"
			_tmp32_ = _tmp31_;
#line 352 "../src/Services/StarStore.vala"
			_tmp33_ = string_to_string (_tmp32_);
#line 352 "../src/Services/StarStore.vala"
			_tmp34_ = string_to_string (TUNER_STAR_STORE_M3U8_UUID);
#line 352 "../src/Services/StarStore.vala"
			_tmp35_ = station;
#line 352 "../src/Services/StarStore.vala"
			_tmp36_ = tuner_model_station_get_stationuuid (_tmp35_);
#line 352 "../src/Services/StarStore.vala"
			_tmp37_ = _tmp36_;
#line 352 "../src/Services/StarStore.vala"
			_tmp38_ = string_to_string (_tmp37_);
#line 352 "../src/Services/StarStore.vala"
			_tmp39_ = url;
#line 352 "../src/Services/StarStore.vala"
			_tmp40_ = string_to_string (_tmp39_);
#line 352 "../src/Services/StarStore.vala"
			_tmp41_ = station;
#line 352 "../src/Services/StarStore.vala"
			_tmp42_ = tuner_model_favicon_get_favicon ((TunerModelFavicon*) _tmp41_);
#line 352 "../src/Services/StarStore.vala"
			_tmp43_ = _tmp42_;
#line 352 "../src/Services/StarStore.vala"
			_tmp44_ = string_to_string (_tmp43_);
#line 352 "../src/Services/StarStore.vala"
			_tmp45_ = g_strconcat ("#EXTINF:-1,", _tmp29_, " - logo=\"", _tmp33_, "\",", _tmp34_, "=\"", _tmp38_, "\"\n", _tmp40_, "\n#EXTIMG:", _tmp44_, "\n", NULL);
#line 352 "../src/Services/StarStore.vala"
			_tmp46_ = _tmp45_;
#line 352 "../src/Services/StarStore.vala"
			g_string_append (_tmp25_, _tmp46_);
#line 352 "../src/Services/StarStore.vala"
			_g_free0 (_tmp46_);
#line 349 "../src/Services/StarStore.vala"
			_g_free0 (url);
#line 349 "../src/Services/StarStore.vala"
			_g_object_unref0 (station);
#line 2007 "StarStore.c"
		}
#line 349 "../src/Services/StarStore.vala"
		_g_object_unref0 (_station_it);
#line 2011 "StarStore.c"
	}
#line 355 "../src/Services/StarStore.vala"
	_tmp47_ = playlist;
#line 355 "../src/Services/StarStore.vala"
	_tmp48_ = _tmp47_->str;
#line 355 "../src/Services/StarStore.vala"
	_tmp49_ = g_strdup (_tmp48_);
#line 355 "../src/Services/StarStore.vala"
	result = _tmp49_;
#line 355 "../src/Services/StarStore.vala"
	_g_string_free0 (playlist);
#line 355 "../src/Services/StarStore.vala"
	return result;
#line 2025 "StarStore.c"
}

/**
      * @brief Scans data for Station UUIDs which are checked and added as Starred.
      * @param data_stream The data to be scanned
      */
void
tuner_star_store_import_stationuuids (TunerStarStore* self,
                                      GDataInputStream* data_stream,
                                      GError** error)
{
	GeeList* stationuuids = NULL;
	GeeArrayList* _tmp0_;
	gchar* content = NULL;
	GMatchInfo* match_info = NULL;
	GError* _inner_error0_ = NULL;
#line 364 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 364 "../src/Services/StarStore.vala"
	g_return_if_fail (data_stream != NULL);
#line 366 "../src/Services/StarStore.vala"
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 366 "../src/Services/StarStore.vala"
	stationuuids = (GeeList*) _tmp0_;
#line 369 "../src/Services/StarStore.vala"
	while (TRUE) {
#line 2052 "StarStore.c"
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		const gchar* _tmp4_;
		GRegex* _tmp5_;
		const gchar* _tmp6_;
		GMatchInfo* _tmp7_ = NULL;
#line 369 "../src/Services/StarStore.vala"
		_tmp2_ = g_data_input_stream_read_line (data_stream, NULL, NULL, &_inner_error0_);
#line 369 "../src/Services/StarStore.vala"
		_tmp1_ = _tmp2_;
#line 369 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 369 "../src/Services/StarStore.vala"
			if (_inner_error0_->domain == G_IO_ERROR) {
#line 369 "../src/Services/StarStore.vala"
				g_propagate_error (error, _inner_error0_);
#line 369 "../src/Services/StarStore.vala"
				_g_match_info_unref0 (match_info);
#line 369 "../src/Services/StarStore.vala"
				_g_free0 (content);
#line 369 "../src/Services/StarStore.vala"
				_g_object_unref0 (stationuuids);
#line 369 "../src/Services/StarStore.vala"
				return;
#line 2078 "StarStore.c"
			} else {
#line 369 "../src/Services/StarStore.vala"
				_g_match_info_unref0 (match_info);
#line 369 "../src/Services/StarStore.vala"
				_g_free0 (content);
#line 369 "../src/Services/StarStore.vala"
				_g_object_unref0 (stationuuids);
#line 369 "../src/Services/StarStore.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 369 "../src/Services/StarStore.vala"
				g_clear_error (&_inner_error0_);
#line 369 "../src/Services/StarStore.vala"
				return;
#line 2092 "StarStore.c"
			}
		}
#line 369 "../src/Services/StarStore.vala"
		_tmp3_ = _tmp1_;
#line 369 "../src/Services/StarStore.vala"
		_tmp1_ = NULL;
#line 369 "../src/Services/StarStore.vala"
		_g_free0 (content);
#line 369 "../src/Services/StarStore.vala"
		content = _tmp3_;
#line 369 "../src/Services/StarStore.vala"
		_tmp4_ = content;
#line 369 "../src/Services/StarStore.vala"
		if (!(_tmp4_ != NULL)) {
#line 369 "../src/Services/StarStore.vala"
			_g_free0 (_tmp1_);
#line 369 "../src/Services/StarStore.vala"
			break;
#line 2111 "StarStore.c"
		}
#line 371 "../src/Services/StarStore.vala"
		_tmp5_ = self->priv->uuid_regex;
#line 371 "../src/Services/StarStore.vala"
		_tmp6_ = content;
#line 371 "../src/Services/StarStore.vala"
		g_regex_match (_tmp5_, _tmp6_, 0, &_tmp7_);
#line 371 "../src/Services/StarStore.vala"
		_g_match_info_unref0 (match_info);
#line 371 "../src/Services/StarStore.vala"
		match_info = _tmp7_;
#line 372 "../src/Services/StarStore.vala"
		while (TRUE) {
#line 2125 "StarStore.c"
			GMatchInfo* _tmp8_;
			GeeList* _tmp9_;
			GMatchInfo* _tmp10_;
			gchar** _tmp11_;
			gchar** _tmp12_;
			gchar** _tmp13_;
			gint _tmp13__length1;
			const gchar* _tmp14_;
			GMatchInfo* _tmp15_;
			gchar** _tmp16_;
			gchar** _tmp17_;
			gchar** _tmp18_;
			gint _tmp18__length1;
			const gchar* _tmp19_;
			const gchar* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
#line 372 "../src/Services/StarStore.vala"
			_tmp8_ = match_info;
#line 372 "../src/Services/StarStore.vala"
			if (!g_match_info_matches (_tmp8_)) {
#line 372 "../src/Services/StarStore.vala"
				break;
#line 2149 "StarStore.c"
			}
#line 374 "../src/Services/StarStore.vala"
			_tmp9_ = stationuuids;
#line 374 "../src/Services/StarStore.vala"
			_tmp10_ = match_info;
#line 374 "../src/Services/StarStore.vala"
			_tmp12_ = _tmp11_ = g_match_info_fetch_all (_tmp10_);
#line 374 "../src/Services/StarStore.vala"
			_tmp13_ = _tmp12_;
#line 374 "../src/Services/StarStore.vala"
			_tmp13__length1 = _vala_array_length (_tmp11_);
#line 374 "../src/Services/StarStore.vala"
			_tmp14_ = _tmp13_[0];
#line 374 "../src/Services/StarStore.vala"
			gee_collection_add ((GeeCollection*) _tmp9_, _tmp14_);
#line 374 "../src/Services/StarStore.vala"
			_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 375 "../src/Services/StarStore.vala"
			_tmp15_ = match_info;
#line 375 "../src/Services/StarStore.vala"
			_tmp17_ = _tmp16_ = g_match_info_fetch_all (_tmp15_);
#line 375 "../src/Services/StarStore.vala"
			_tmp18_ = _tmp17_;
#line 375 "../src/Services/StarStore.vala"
			_tmp18__length1 = _vala_array_length (_tmp16_);
#line 375 "../src/Services/StarStore.vala"
			_tmp19_ = _tmp18_[0];
#line 375 "../src/Services/StarStore.vala"
			_tmp20_ = string_to_string (_tmp19_);
#line 375 "../src/Services/StarStore.vala"
			_tmp21_ = g_strconcat ("UUID: ", _tmp20_, NULL);
#line 375 "../src/Services/StarStore.vala"
			_tmp22_ = _tmp21_;
#line 375 "../src/Services/StarStore.vala"
			g_debug ("StarStore.vala:375: %s", _tmp22_);
#line 375 "../src/Services/StarStore.vala"
			_g_free0 (_tmp22_);
#line 375 "../src/Services/StarStore.vala"
			_tmp18_ = (_vala_array_free (_tmp18_, _tmp18__length1, (GDestroyNotify) g_free), NULL);
#line 2189 "StarStore.c"
			{
				GMatchInfo* _tmp23_;
#line 378 "../src/Services/StarStore.vala"
				_tmp23_ = match_info;
#line 378 "../src/Services/StarStore.vala"
				g_match_info_next (_tmp23_, &_inner_error0_);
#line 378 "../src/Services/StarStore.vala"
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 378 "../src/Services/StarStore.vala"
					if (_inner_error0_->domain == G_REGEX_ERROR) {
#line 2200 "StarStore.c"
						goto __catch0_g_regex_error;
					}
#line 378 "../src/Services/StarStore.vala"
					_g_free0 (_tmp1_);
#line 378 "../src/Services/StarStore.vala"
					_g_match_info_unref0 (match_info);
#line 378 "../src/Services/StarStore.vala"
					_g_free0 (content);
#line 378 "../src/Services/StarStore.vala"
					_g_object_unref0 (stationuuids);
#line 378 "../src/Services/StarStore.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 378 "../src/Services/StarStore.vala"
					g_clear_error (&_inner_error0_);
#line 378 "../src/Services/StarStore.vala"
					return;
#line 2217 "StarStore.c"
				}
			}
			goto __finally0;
			__catch0_g_regex_error:
			{
				GError* e = NULL;
				const gchar* _tmp24_;
				const gchar* _tmp25_;
				GError* _tmp26_;
				const gchar* _tmp27_;
				const gchar* _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
#line 377 "../src/Services/StarStore.vala"
				e = _inner_error0_;
#line 377 "../src/Services/StarStore.vala"
				_inner_error0_ = NULL;
#line 381 "../src/Services/StarStore.vala"
				_tmp24_ = content;
#line 381 "../src/Services/StarStore.vala"
				_tmp25_ = string_to_string (_tmp24_);
#line 381 "../src/Services/StarStore.vala"
				_tmp26_ = e;
#line 381 "../src/Services/StarStore.vala"
				_tmp27_ = _tmp26_->message;
#line 381 "../src/Services/StarStore.vala"
				_tmp28_ = string_to_string (_tmp27_);
#line 381 "../src/Services/StarStore.vala"
				_tmp29_ = g_strconcat ("Regex error processing line: ", _tmp25_, "\n Error: ", _tmp28_, NULL);
#line 381 "../src/Services/StarStore.vala"
				_tmp30_ = _tmp29_;
#line 381 "../src/Services/StarStore.vala"
				g_warning ("StarStore.vala:381: %s", _tmp30_);
#line 381 "../src/Services/StarStore.vala"
				_g_free0 (_tmp30_);
#line 377 "../src/Services/StarStore.vala"
				_g_error_free0 (e);
#line 2255 "StarStore.c"
			}
			__finally0:
#line 377 "../src/Services/StarStore.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 377 "../src/Services/StarStore.vala"
				if (_inner_error0_->domain == G_IO_ERROR) {
#line 377 "../src/Services/StarStore.vala"
					g_propagate_error (error, _inner_error0_);
#line 377 "../src/Services/StarStore.vala"
					_g_free0 (_tmp1_);
#line 377 "../src/Services/StarStore.vala"
					_g_match_info_unref0 (match_info);
#line 377 "../src/Services/StarStore.vala"
					_g_free0 (content);
#line 377 "../src/Services/StarStore.vala"
					_g_object_unref0 (stationuuids);
#line 377 "../src/Services/StarStore.vala"
					return;
#line 2274 "StarStore.c"
				} else {
#line 377 "../src/Services/StarStore.vala"
					_g_free0 (_tmp1_);
#line 377 "../src/Services/StarStore.vala"
					_g_match_info_unref0 (match_info);
#line 377 "../src/Services/StarStore.vala"
					_g_free0 (content);
#line 377 "../src/Services/StarStore.vala"
					_g_object_unref0 (stationuuids);
#line 377 "../src/Services/StarStore.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 377 "../src/Services/StarStore.vala"
					g_clear_error (&_inner_error0_);
#line 377 "../src/Services/StarStore.vala"
					return;
#line 2290 "StarStore.c"
				}
			}
		}
#line 369 "../src/Services/StarStore.vala"
		_g_free0 (_tmp1_);
#line 2296 "StarStore.c"
	}
	{
		GeeIterator* _station_it = NULL;
		TunerApplication* _tmp31_;
		TunerApplication* _tmp32_;
		TunerDirectoryController* _tmp33_;
		TunerDirectoryController* _tmp34_;
		GeeList* _tmp35_;
		GeeSet* _tmp36_;
		GeeSet* _tmp37_;
		GeeIterator* _tmp38_;
		GeeIterator* _tmp39_;
#line 386 "../src/Services/StarStore.vala"
		_tmp31_ = tuner_app ();
#line 386 "../src/Services/StarStore.vala"
		_tmp32_ = _tmp31_;
#line 386 "../src/Services/StarStore.vala"
		_tmp33_ = tuner_application_get_directory (_tmp32_);
#line 386 "../src/Services/StarStore.vala"
		_tmp34_ = _tmp33_;
#line 386 "../src/Services/StarStore.vala"
		_tmp35_ = stationuuids;
#line 386 "../src/Services/StarStore.vala"
		_tmp36_ = tuner_directory_controller_get_stations_by_uuid (_tmp34_, (GeeCollection*) _tmp35_);
#line 386 "../src/Services/StarStore.vala"
		_tmp37_ = _tmp36_;
#line 386 "../src/Services/StarStore.vala"
		_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
#line 386 "../src/Services/StarStore.vala"
		_tmp39_ = _tmp38_;
#line 386 "../src/Services/StarStore.vala"
		_g_object_unref0 (_tmp37_);
#line 386 "../src/Services/StarStore.vala"
		_g_object_unref0 (_tmp32_);
#line 386 "../src/Services/StarStore.vala"
		_station_it = _tmp39_;
#line 386 "../src/Services/StarStore.vala"
		while (TRUE) {
#line 2335 "StarStore.c"
			GeeIterator* _tmp40_;
			TunerModelStation* station = NULL;
			GeeIterator* _tmp41_;
			gpointer _tmp42_;
			TunerModelStation* _tmp43_;
#line 386 "../src/Services/StarStore.vala"
			_tmp40_ = _station_it;
#line 386 "../src/Services/StarStore.vala"
			if (!gee_iterator_next (_tmp40_)) {
#line 386 "../src/Services/StarStore.vala"
				break;
#line 2347 "StarStore.c"
			}
#line 386 "../src/Services/StarStore.vala"
			_tmp41_ = _station_it;
#line 386 "../src/Services/StarStore.vala"
			_tmp42_ = gee_iterator_get (_tmp41_);
#line 386 "../src/Services/StarStore.vala"
			station = (TunerModelStation*) _tmp42_;
#line 388 "../src/Services/StarStore.vala"
			_tmp43_ = station;
#line 388 "../src/Services/StarStore.vala"
			tuner_star_store_add_station (self, _tmp43_);
#line 386 "../src/Services/StarStore.vala"
			_g_object_unref0 (station);
#line 2361 "StarStore.c"
		}
#line 386 "../src/Services/StarStore.vala"
		_g_object_unref0 (_station_it);
#line 2365 "StarStore.c"
	}
#line 364 "../src/Services/StarStore.vala"
	_g_match_info_unref0 (match_info);
#line 364 "../src/Services/StarStore.vala"
	_g_free0 (content);
#line 364 "../src/Services/StarStore.vala"
	_g_object_unref0 (stationuuids);
#line 2373 "StarStore.c"
}

/**
     * @brief Persists the current state of favorites to the JSON file.
     * 
     * This method serializes the _store and writes it to the favorites file.
     */
static void
tuner_star_store_persist (TunerStarStore* self)
{
	GError* _inner_error0_ = NULL;
#line 405 "../src/Services/StarStore.vala"
	g_return_if_fail (self != NULL);
#line 407 "../src/Services/StarStore.vala"
	g_debug ("StarStore.vala:407: persisting store");
#line 2389 "StarStore.c"
	{
		GFile* _tmp0_;
		GFileOutputStream* stream = NULL;
		GFile* _tmp1_;
		GFileOutputStream* _tmp2_;
		GDataOutputStream* s = NULL;
		GFileOutputStream* _tmp3_;
		GDataOutputStream* _tmp4_;
		GDataOutputStream* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GDataOutputStream* _tmp8_;
		GDataOutputStream* _tmp9_;
#line 410 "../src/Services/StarStore.vala"
		_tmp0_ = self->priv->_starred_file;
#line 410 "../src/Services/StarStore.vala"
		g_file_delete (_tmp0_, NULL, &_inner_error0_);
#line 410 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2409 "StarStore.c"
			goto __catch0_g_error;
		}
#line 411 "../src/Services/StarStore.vala"
		_tmp1_ = self->priv->_starred_file;
#line 411 "../src/Services/StarStore.vala"
		_tmp2_ = g_file_create (_tmp1_, G_FILE_CREATE_REPLACE_DESTINATION | G_FILE_CREATE_PRIVATE, NULL, &_inner_error0_);
#line 411 "../src/Services/StarStore.vala"
		stream = _tmp2_;
#line 411 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2420 "StarStore.c"
			goto __catch0_g_error;
		}
#line 414 "../src/Services/StarStore.vala"
		_tmp3_ = stream;
#line 414 "../src/Services/StarStore.vala"
		_tmp4_ = g_data_output_stream_new ((GOutputStream*) _tmp3_);
#line 414 "../src/Services/StarStore.vala"
		s = _tmp4_;
#line 415 "../src/Services/StarStore.vala"
		_tmp5_ = s;
#line 415 "../src/Services/StarStore.vala"
		_tmp6_ = tuner_star_store_serialize (self);
#line 415 "../src/Services/StarStore.vala"
		_tmp7_ = _tmp6_;
#line 415 "../src/Services/StarStore.vala"
		g_data_output_stream_put_string (_tmp5_, _tmp7_, NULL, &_inner_error0_);
#line 415 "../src/Services/StarStore.vala"
		_g_free0 (_tmp7_);
#line 415 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 415 "../src/Services/StarStore.vala"
			_g_object_unref0 (s);
#line 415 "../src/Services/StarStore.vala"
			_g_object_unref0 (stream);
#line 2445 "StarStore.c"
			goto __catch0_g_error;
		}
#line 416 "../src/Services/StarStore.vala"
		_tmp8_ = s;
#line 416 "../src/Services/StarStore.vala"
		g_output_stream_flush ((GOutputStream*) _tmp8_, NULL, &_inner_error0_);
#line 416 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 416 "../src/Services/StarStore.vala"
			_g_object_unref0 (s);
#line 416 "../src/Services/StarStore.vala"
			_g_object_unref0 (stream);
#line 2458 "StarStore.c"
			goto __catch0_g_error;
		}
#line 417 "../src/Services/StarStore.vala"
		_tmp9_ = s;
#line 417 "../src/Services/StarStore.vala"
		g_output_stream_close ((GOutputStream*) _tmp9_, NULL, &_inner_error0_);
#line 417 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 417 "../src/Services/StarStore.vala"
			_g_object_unref0 (s);
#line 417 "../src/Services/StarStore.vala"
			_g_object_unref0 (stream);
#line 2471 "StarStore.c"
			goto __catch0_g_error;
		}
#line 409 "../src/Services/StarStore.vala"
		_g_object_unref0 (s);
#line 409 "../src/Services/StarStore.vala"
		_g_object_unref0 (stream);
#line 2478 "StarStore.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 409 "../src/Services/StarStore.vala"
		e = _inner_error0_;
#line 409 "../src/Services/StarStore.vala"
		_inner_error0_ = NULL;
#line 419 "../src/Services/StarStore.vala"
		_tmp10_ = e;
#line 419 "../src/Services/StarStore.vala"
		_tmp11_ = _tmp10_->message;
#line 419 "../src/Services/StarStore.vala"
		_tmp12_ = string_to_string (_tmp11_);
#line 419 "../src/Services/StarStore.vala"
		_tmp13_ = g_strconcat ("Persist failed with error: ", _tmp12_, NULL);
#line 419 "../src/Services/StarStore.vala"
		_tmp14_ = _tmp13_;
#line 419 "../src/Services/StarStore.vala"
		g_warning ("StarStore.vala:419: %s", _tmp14_);
#line 419 "../src/Services/StarStore.vala"
		_g_free0 (_tmp14_);
#line 409 "../src/Services/StarStore.vala"
		_g_error_free0 (e);
#line 2509 "StarStore.c"
	}
	__finally0:
#line 409 "../src/Services/StarStore.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 409 "../src/Services/StarStore.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 409 "../src/Services/StarStore.vala"
		g_clear_error (&_inner_error0_);
#line 409 "../src/Services/StarStore.vala"
		return;
#line 2520 "StarStore.c"
	}
}

/**
     * @brief Returns the given property from the JSON node.
     * 
     */
static gpointer
_json_object_ref0 (gpointer self)
{
#line 431 "../src/Services/StarStore.vala"
	return self ? json_object_ref (self) : NULL;
#line 2533 "StarStore.c"
}

static JsonNode*
tuner_star_store_get_member (JsonNode* node,
                             const gchar* property_name)
{
	JsonNode* result;
#line 428 "../src/Services/StarStore.vala"
	g_return_val_if_fail (node != NULL, NULL);
#line 428 "../src/Services/StarStore.vala"
	g_return_val_if_fail (property_name != NULL, NULL);
#line 430 "../src/Services/StarStore.vala"
	if (json_node_get_node_type (node) == JSON_NODE_OBJECT) {
#line 2547 "StarStore.c"
		JsonObject* json_object = NULL;
		JsonObject* _tmp0_;
		JsonObject* _tmp1_;
		JsonObject* _tmp2_;
#line 431 "../src/Services/StarStore.vala"
		_tmp0_ = json_node_get_object (node);
#line 431 "../src/Services/StarStore.vala"
		_tmp1_ = _json_object_ref0 (_tmp0_);
#line 431 "../src/Services/StarStore.vala"
		json_object = _tmp1_;
#line 434 "../src/Services/StarStore.vala"
		_tmp2_ = json_object;
#line 434 "../src/Services/StarStore.vala"
		if (json_object_has_member (_tmp2_, property_name)) {
#line 2562 "StarStore.c"
			JsonObject* _tmp3_;
			JsonNode* _tmp4_;
			JsonNode* _tmp5_;
#line 435 "../src/Services/StarStore.vala"
			_tmp3_ = json_object;
#line 435 "../src/Services/StarStore.vala"
			_tmp4_ = json_object_get_member (_tmp3_, property_name);
#line 435 "../src/Services/StarStore.vala"
			_tmp5_ = __vala_JsonNode_copy0 (_tmp4_);
#line 435 "../src/Services/StarStore.vala"
			result = _tmp5_;
#line 435 "../src/Services/StarStore.vala"
			_json_object_unref0 (json_object);
#line 435 "../src/Services/StarStore.vala"
			return result;
#line 2578 "StarStore.c"
		}
#line 430 "../src/Services/StarStore.vala"
		_json_object_unref0 (json_object);
#line 2582 "StarStore.c"
	}
#line 437 "../src/Services/StarStore.vala"
	result = NULL;
#line 437 "../src/Services/StarStore.vala"
	return result;
#line 2588 "StarStore.c"
}

static GObject *
tuner_star_store_constructor (GType type,
                              guint n_construct_properties,
                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TunerStarStore * self;
	GError* _inner_error0_ = NULL;
#line 51 "../src/Services/StarStore.vala"
	parent_class = G_OBJECT_CLASS (tuner_star_store_parent_class);
#line 51 "../src/Services/StarStore.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 51 "../src/Services/StarStore.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUNER_TYPE_STAR_STORE, TunerStarStore);
#line 2606 "StarStore.c"
	{
		GRegex* _tmp0_ = NULL;
		GRegex* _tmp1_;
		GRegex* _tmp2_;
#line 54 "../src/Services/StarStore.vala"
		_tmp1_ = g_regex_new (TUNER_STAR_STORE_UUID_REGEX, 0, 0, &_inner_error0_);
#line 54 "../src/Services/StarStore.vala"
		_tmp0_ = _tmp1_;
#line 54 "../src/Services/StarStore.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 54 "../src/Services/StarStore.vala"
			if (_inner_error0_->domain == G_REGEX_ERROR) {
#line 2619 "StarStore.c"
				goto __catch0_g_regex_error;
			}
#line 54 "../src/Services/StarStore.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 54 "../src/Services/StarStore.vala"
			g_clear_error (&_inner_error0_);
#line 2626 "StarStore.c"
		}
#line 54 "../src/Services/StarStore.vala"
		_tmp2_ = _tmp0_;
#line 54 "../src/Services/StarStore.vala"
		_tmp0_ = NULL;
#line 54 "../src/Services/StarStore.vala"
		_g_regex_unref0 (self->priv->uuid_regex);
#line 54 "../src/Services/StarStore.vala"
		self->priv->uuid_regex = _tmp2_;
#line 53 "../src/Services/StarStore.vala"
		_g_regex_unref0 (_tmp0_);
#line 2638 "StarStore.c"
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 53 "../src/Services/StarStore.vala"
		e = _inner_error0_;
#line 53 "../src/Services/StarStore.vala"
		_inner_error0_ = NULL;
#line 57 "../src/Services/StarStore.vala"
		_tmp3_ = e;
#line 57 "../src/Services/StarStore.vala"
		_tmp4_ = _tmp3_->message;
#line 57 "../src/Services/StarStore.vala"
		_tmp5_ = string_to_string (_tmp4_);
#line 57 "../src/Services/StarStore.vala"
		_tmp6_ = g_strconcat ("Could not compile regex: ", _tmp5_, NULL);
#line 57 "../src/Services/StarStore.vala"
		_tmp7_ = _tmp6_;
#line 57 "../src/Services/StarStore.vala"
		g_critical ("StarStore.vala:57: %s", _tmp7_);
#line 57 "../src/Services/StarStore.vala"
		_g_free0 (_tmp7_);
#line 53 "../src/Services/StarStore.vala"
		_g_error_free0 (e);
#line 2669 "StarStore.c"
	}
	__finally0:
#line 53 "../src/Services/StarStore.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 53 "../src/Services/StarStore.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 53 "../src/Services/StarStore.vala"
		g_clear_error (&_inner_error0_);
#line 2678 "StarStore.c"
	}
#line 51 "../src/Services/StarStore.vala"
	return obj;
#line 2682 "StarStore.c"
}

static void
tuner_star_store_class_init (TunerStarStoreClass * klass,
                             gpointer klass_data)
{
#line 33 "../src/Services/StarStore.vala"
	tuner_star_store_parent_class = g_type_class_peek_parent (klass);
#line 33 "../src/Services/StarStore.vala"
	g_type_class_adjust_private_offset (klass, &TunerStarStore_private_offset);
#line 33 "../src/Services/StarStore.vala"
	G_OBJECT_CLASS (klass)->constructor = tuner_star_store_constructor;
#line 33 "../src/Services/StarStore.vala"
	G_OBJECT_CLASS (klass)->finalize = tuner_star_store_finalize;
#line 33 "../src/Services/StarStore.vala"
	tuner_star_store_signals[TUNER_STAR_STORE_STARRED_STATIONS_CHANGED_SIG_SIGNAL] = g_signal_new ("starred-stations-changed-sig", TUNER_TYPE_STAR_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUNER_MODEL_TYPE_STATION);
#line 2699 "StarStore.c"
}

static void
tuner_star_store_instance_init (TunerStarStore * self,
                                gpointer klass)
{
	GeeHashMap* _tmp0_;
	GeeHashSet* _tmp1_;
#line 33 "../src/Services/StarStore.vala"
	self->priv = tuner_star_store_get_instance_private (self);
#line 64 "../src/Services/StarStore.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TUNER_MODEL_TYPE_STATION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 64 "../src/Services/StarStore.vala"
	self->priv->_starred_station_map = (GeeMap*) _tmp0_;
#line 65 "../src/Services/StarStore.vala"
	_tmp1_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 65 "../src/Services/StarStore.vala"
	self->priv->_saved_searches = (GeeSet*) _tmp1_;
#line 66 "../src/Services/StarStore.vala"
	self->priv->_loaded = FALSE;
#line 2720 "StarStore.c"
}

static void
tuner_star_store_finalize (GObject * obj)
{
	TunerStarStore * self;
#line 33 "../src/Services/StarStore.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUNER_TYPE_STAR_STORE, TunerStarStore);
#line 49 "../src/Services/StarStore.vala"
	_g_regex_unref0 (self->priv->uuid_regex);
#line 61 "../src/Services/StarStore.vala"
	_g_object_unref0 (self->priv->_starred_file);
#line 64 "../src/Services/StarStore.vala"
	_g_object_unref0 (self->priv->_starred_station_map);
#line 65 "../src/Services/StarStore.vala"
	_g_object_unref0 (self->priv->_saved_searches);
#line 33 "../src/Services/StarStore.vala"
	G_OBJECT_CLASS (tuner_star_store_parent_class)->finalize (obj);
#line 2739 "StarStore.c"
}

/**
 * @class StarStore
 *
 * @brief Manages a collection of starred stations and saved searches
 * 
 * This class allows for storing, retrieving, and persisting a 
 * list of favorite stations in a JSON file. It uses libgee for data structures.
 *
 * DirectoryController uses StationStore to load the starred stations from RadioBrowser
 */
static GType
tuner_star_store_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TunerStarStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuner_star_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TunerStarStore), 0, (GInstanceInitFunc) tuner_star_store_instance_init, NULL };
	GType tuner_star_store_type_id;
	tuner_star_store_type_id = g_type_register_static (G_TYPE_OBJECT, "TunerStarStore", &g_define_type_info, 0);
	TunerStarStore_private_offset = g_type_add_instance_private (tuner_star_store_type_id, sizeof (TunerStarStorePrivate));
	return tuner_star_store_type_id;
}

GType
tuner_star_store_get_type (void)
{
	static volatile gsize tuner_star_store_type_id__once = 0;
	if (g_once_init_enter (&tuner_star_store_type_id__once)) {
		GType tuner_star_store_type_id;
		tuner_star_store_type_id = tuner_star_store_get_type_once ();
		g_once_init_leave (&tuner_star_store_type_id__once, tuner_star_store_type_id);
	}
	return tuner_star_store_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gssize
_vala_array_length (gpointer array)
{
	gssize length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

