/* Display.c generated by valac 0.56.17, the Vala compiler
 * generated from Display.vala, do not modify */

/**
 * SPDX-FileCopyrightText: Copyright © 2020-2024 Louis Brauer <louis@brauer.family>
 * SPDX-FileCopyrightText: Copyright © 2024 technosf <https://github.com/technosf>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @file Display.vala
 *
 * @brief Defines the below-headerbar display of stations in the Tuner application.
 *
 * This file contains the Display class, which implements visual elements for
 * features such as a source list, content stack that display and manage Station
 * settings and handles user actions like station selection.
 *
 * @since 2.0.0
 *
 * @see Tuner.Application
 * @see Tuner.DirectoryController
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <granite.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <pango/pango.h>
#include <gee.h>

#define TUNER_DISPLAY_BACKGROUND_TUNER "/com/github/louis77/tuner/icons/background-tuner"
#define TUNER_DISPLAY_BACKGROUND_JUKEBOX "/com/github/louis77/tuner/icons/background-jukebox"
#define TUNER_DISPLAY_EXPLORE_CATEGORIES 5
#define TUNER_DISPLAY_BACKGROUND_OPACITY 0.15
#define TUNER_DISPLAY_BACKGROUND_TRANSITION_TIME_MS 1500
#define TUNER_DISPLAY_BACKGROUND_TRANSITION_TYPE GTK_REVEALER_TRANSITION_TYPE_CROSSFADE
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUNER_TYPE_STATION_LIST_HOOKUP (tuner_station_list_hookup_get_type ())
#define TUNER_STATION_LIST_HOOKUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STATION_LIST_HOOKUP, TunerStationListHookup))
#define TUNER_IS_STATION_LIST_HOOKUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STATION_LIST_HOOKUP))
#define TUNER_STATION_LIST_HOOKUP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUNER_TYPE_STATION_LIST_HOOKUP, TunerStationListHookupIface))

typedef struct _TunerStationListHookup TunerStationListHookup;
typedef struct _TunerStationListHookupIface TunerStationListHookupIface;

#define TUNER_TYPE_LIST_FLOW_BOX (tuner_list_flow_box_get_type ())
#define TUNER_LIST_FLOW_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_LIST_FLOW_BOX, TunerListFlowBox))
#define TUNER_LIST_FLOW_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_LIST_FLOW_BOX, TunerListFlowBoxClass))
#define TUNER_IS_LIST_FLOW_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_LIST_FLOW_BOX))
#define TUNER_IS_LIST_FLOW_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_LIST_FLOW_BOX))
#define TUNER_LIST_FLOW_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_LIST_FLOW_BOX, TunerListFlowBoxClass))

typedef struct _TunerListFlowBox TunerListFlowBox;
typedef struct _TunerListFlowBoxClass TunerListFlowBoxClass;

#define TUNER_TYPE_STATION_LIST (tuner_station_list_get_type ())
#define TUNER_STATION_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STATION_LIST, TunerStationList))
#define TUNER_STATION_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_STATION_LIST, TunerStationListClass))
#define TUNER_IS_STATION_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STATION_LIST))
#define TUNER_IS_STATION_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_STATION_LIST))
#define TUNER_STATION_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_STATION_LIST, TunerStationListClass))

typedef struct _TunerStationList TunerStationList;
typedef struct _TunerStationListClass TunerStationListClass;

#define TUNER_TYPE_DISPLAY (tuner_display_get_type ())
#define TUNER_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_DISPLAY, TunerDisplay))
#define TUNER_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_DISPLAY, TunerDisplayClass))
#define TUNER_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_DISPLAY))
#define TUNER_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_DISPLAY))
#define TUNER_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_DISPLAY, TunerDisplayClass))

typedef struct _TunerDisplay TunerDisplay;
typedef struct _TunerDisplayClass TunerDisplayClass;
typedef struct _TunerDisplayPrivate TunerDisplayPrivate;

#define TUNER_TYPE_DIRECTORY_CONTROLLER (tuner_directory_controller_get_type ())
#define TUNER_DIRECTORY_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_DIRECTORY_CONTROLLER, TunerDirectoryController))
#define TUNER_DIRECTORY_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_DIRECTORY_CONTROLLER, TunerDirectoryControllerClass))
#define TUNER_IS_DIRECTORY_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_DIRECTORY_CONTROLLER))
#define TUNER_IS_DIRECTORY_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_DIRECTORY_CONTROLLER))
#define TUNER_DIRECTORY_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_DIRECTORY_CONTROLLER, TunerDirectoryControllerClass))

typedef struct _TunerDirectoryController TunerDirectoryController;
typedef struct _TunerDirectoryControllerClass TunerDirectoryControllerClass;

#define TUNER_TYPE_STATION_SET (tuner_station_set_get_type ())
#define TUNER_STATION_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STATION_SET, TunerStationSet))
#define TUNER_STATION_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_STATION_SET, TunerStationSetClass))
#define TUNER_IS_STATION_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STATION_SET))
#define TUNER_IS_STATION_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_STATION_SET))
#define TUNER_STATION_SET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_STATION_SET, TunerStationSetClass))

typedef struct _TunerStationSet TunerStationSet;
typedef struct _TunerStationSetClass TunerStationSetClass;

#define TUNER_TYPE_SEARCH_CONTROLLER (tuner_search_controller_get_type ())
#define TUNER_SEARCH_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_SEARCH_CONTROLLER, TunerSearchController))
#define TUNER_SEARCH_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_SEARCH_CONTROLLER, TunerSearchControllerClass))
#define TUNER_IS_SEARCH_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_SEARCH_CONTROLLER))
#define TUNER_IS_SEARCH_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_SEARCH_CONTROLLER))
#define TUNER_SEARCH_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_SEARCH_CONTROLLER, TunerSearchControllerClass))

typedef struct _TunerSearchController TunerSearchController;
typedef struct _TunerSearchControllerClass TunerSearchControllerClass;

#define TUNER_TYPE_STATION_LIST_BOX (tuner_station_list_box_get_type ())
#define TUNER_STATION_LIST_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STATION_LIST_BOX, TunerStationListBox))
#define TUNER_STATION_LIST_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_STATION_LIST_BOX, TunerStationListBoxClass))
#define TUNER_IS_STATION_LIST_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STATION_LIST_BOX))
#define TUNER_IS_STATION_LIST_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_STATION_LIST_BOX))
#define TUNER_STATION_LIST_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_STATION_LIST_BOX, TunerStationListBoxClass))

typedef struct _TunerStationListBox TunerStationListBox;
typedef struct _TunerStationListBoxClass TunerStationListBoxClass;
enum  {
	TUNER_DISPLAY_0_PROPERTY,
	TUNER_DISPLAY_STACK_PROPERTY,
	TUNER_DISPLAY_SOURCE_LIST_PROPERTY,
	TUNER_DISPLAY_DIRECTORY_PROPERTY,
	TUNER_DISPLAY_NUM_PROPERTIES
};
static GParamSpec* tuner_display_properties[TUNER_DISPLAY_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUNER_TYPE_APPLICATION (tuner_application_get_type ())
#define TUNER_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_APPLICATION, TunerApplication))
#define TUNER_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_APPLICATION, TunerApplicationClass))
#define TUNER_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_APPLICATION))
#define TUNER_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_APPLICATION))
#define TUNER_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_APPLICATION, TunerApplicationClass))

typedef struct _TunerApplication TunerApplication;
typedef struct _TunerApplicationClass TunerApplicationClass;

#define TUNER_TYPE_PLAYER_CONTROLLER (tuner_player_controller_get_type ())
#define TUNER_PLAYER_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_PLAYER_CONTROLLER, TunerPlayerController))
#define TUNER_PLAYER_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_PLAYER_CONTROLLER, TunerPlayerControllerClass))
#define TUNER_IS_PLAYER_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_PLAYER_CONTROLLER))
#define TUNER_IS_PLAYER_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_PLAYER_CONTROLLER))
#define TUNER_PLAYER_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_PLAYER_CONTROLLER, TunerPlayerControllerClass))

typedef struct _TunerPlayerController TunerPlayerController;
typedef struct _TunerPlayerControllerClass TunerPlayerControllerClass;

#define TUNER_TYPE_STATION_LIST_ITEM (tuner_station_list_item_get_type ())
#define TUNER_STATION_LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STATION_LIST_ITEM, TunerStationListItem))
#define TUNER_STATION_LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_STATION_LIST_ITEM, TunerStationListItemClass))
#define TUNER_IS_STATION_LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STATION_LIST_ITEM))
#define TUNER_IS_STATION_LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_STATION_LIST_ITEM))
#define TUNER_STATION_LIST_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_STATION_LIST_ITEM, TunerStationListItemClass))

typedef struct _TunerStationListItem TunerStationListItem;
typedef struct _TunerStationListItemClass TunerStationListItemClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUNER_MODEL_TYPE_FAVICON (tuner_model_favicon_get_type ())
#define TUNER_MODEL_FAVICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_MODEL_TYPE_FAVICON, TunerModelFavicon))
#define TUNER_MODEL_FAVICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_MODEL_TYPE_FAVICON, TunerModelFaviconClass))
#define TUNER_MODEL_IS_FAVICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_MODEL_TYPE_FAVICON))
#define TUNER_MODEL_IS_FAVICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_MODEL_TYPE_FAVICON))
#define TUNER_MODEL_FAVICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_MODEL_TYPE_FAVICON, TunerModelFaviconClass))

typedef struct _TunerModelFavicon TunerModelFavicon;
typedef struct _TunerModelFaviconClass TunerModelFaviconClass;

#define TUNER_MODEL_TYPE_STATION (tuner_model_station_get_type ())
#define TUNER_MODEL_STATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_MODEL_TYPE_STATION, TunerModelStation))
#define TUNER_MODEL_STATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_MODEL_TYPE_STATION, TunerModelStationClass))
#define TUNER_MODEL_IS_STATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_MODEL_TYPE_STATION))
#define TUNER_MODEL_IS_STATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_MODEL_TYPE_STATION))
#define TUNER_MODEL_STATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_MODEL_TYPE_STATION, TunerModelStationClass))

typedef struct _TunerModelStation TunerModelStation;
typedef struct _TunerModelStationClass TunerModelStationClass;

#define TYPE_SOURCE_ERROR (source_error_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TunerDisplayJukeboxShuffleData TunerDisplayJukeboxShuffleData;
typedef struct _Block18Data Block18Data;
typedef struct _Block19Data Block19Data;

#define TUNER_DATA_PROVIDER_TYPE_TAG (tuner_data_provider_tag_get_type ())
#define TUNER_DATA_PROVIDER_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_DATA_PROVIDER_TYPE_TAG, TunerDataProviderTag))
#define TUNER_DATA_PROVIDER_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_DATA_PROVIDER_TYPE_TAG, TunerDataProviderTagClass))
#define TUNER_DATA_PROVIDER_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_DATA_PROVIDER_TYPE_TAG))
#define TUNER_DATA_PROVIDER_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_DATA_PROVIDER_TYPE_TAG))
#define TUNER_DATA_PROVIDER_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_DATA_PROVIDER_TYPE_TAG, TunerDataProviderTagClass))

typedef struct _TunerDataProviderTag TunerDataProviderTag;
typedef struct _TunerDataProviderTagClass TunerDataProviderTagClass;

#define TUNER_TYPE_STAR_STORE (tuner_star_store_get_type ())
#define TUNER_STAR_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_TYPE_STAR_STORE, TunerStarStore))
#define TUNER_STAR_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUNER_TYPE_STAR_STORE, TunerStarStoreClass))
#define TUNER_IS_STAR_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_TYPE_STAR_STORE))
#define TUNER_IS_STAR_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUNER_TYPE_STAR_STORE))
#define TUNER_STAR_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUNER_TYPE_STAR_STORE, TunerStarStoreClass))

typedef struct _TunerStarStore TunerStarStore;
typedef struct _TunerStarStoreClass TunerStarStoreClass;
typedef struct _TunerDisplayInitializeData TunerDisplayInitializeData;

#define TUNER_DATA_PROVIDER_TYPE_API (tuner_data_provider_api_get_type ())
#define TUNER_DATA_PROVIDER_API(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUNER_DATA_PROVIDER_TYPE_API, TunerDataProviderAPI))
#define TUNER_DATA_PROVIDER_IS_API(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUNER_DATA_PROVIDER_TYPE_API))
#define TUNER_DATA_PROVIDER_API_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUNER_DATA_PROVIDER_TYPE_API, TunerDataProviderAPIIface))

typedef struct _TunerDataProviderAPI TunerDataProviderAPI;
typedef struct _TunerDataProviderAPIIface TunerDataProviderAPIIface;

#define TUNER_DATA_PROVIDER_TYPE_DATA_ERROR (tuner_data_provider_data_error_get_type ())

#define TUNER_DATA_PROVIDER_TYPE_SEARCH_PARAMS (tuner_data_provider_search_params_get_type ())
typedef struct _TunerDataProviderSearchParams TunerDataProviderSearchParams;
typedef enum  {
	TUNER_DATA_PROVIDER_SORT_ORDER_NAME,
	TUNER_DATA_PROVIDER_SORT_ORDER_URL,
	TUNER_DATA_PROVIDER_SORT_ORDER_HOMEPAGE,
	TUNER_DATA_PROVIDER_SORT_ORDER_FAVICON,
	TUNER_DATA_PROVIDER_SORT_ORDER_TAGS,
	TUNER_DATA_PROVIDER_SORT_ORDER_COUNTRY,
	TUNER_DATA_PROVIDER_SORT_ORDER_STATE,
	TUNER_DATA_PROVIDER_SORT_ORDER_LANGUAGE,
	TUNER_DATA_PROVIDER_SORT_ORDER_VOTES,
	TUNER_DATA_PROVIDER_SORT_ORDER_CODEC,
	TUNER_DATA_PROVIDER_SORT_ORDER_BITRATE,
	TUNER_DATA_PROVIDER_SORT_ORDER_LASTCHECKOK,
	TUNER_DATA_PROVIDER_SORT_ORDER_LASTCHECKTIME,
	TUNER_DATA_PROVIDER_SORT_ORDER_CLICKTIMESTAMP,
	TUNER_DATA_PROVIDER_SORT_ORDER_CLICKCOUNT,
	TUNER_DATA_PROVIDER_SORT_ORDER_CLICKTREND,
	TUNER_DATA_PROVIDER_SORT_ORDER_RANDOM
} TunerDataProviderSortOrder;

#define TUNER_DATA_PROVIDER_TYPE_SORT_ORDER (tuner_data_provider_sort_order_get_type ())
typedef enum  {
	TUNER_DATA_PROVIDER_API_STATUS_OK,
	TUNER_DATA_PROVIDER_API_STATUS_NO_SERVER_LIST,
	TUNER_DATA_PROVIDER_API_STATUS_NO_SERVERS_PRESENTED,
	TUNER_DATA_PROVIDER_API_STATUS_NOT_AVAILABLE,
	TUNER_DATA_PROVIDER_API_STATUS_UNKNOW_ERROR
} TunerDataProviderAPIStatus;

#define TUNER_DATA_PROVIDER_API_TYPE_STATUS (tuner_data_provider_api_status_get_type ())
typedef struct _Block20Data Block20Data;
enum  {
	TUNER_DISPLAY_STATION_CLICKED_SIG_SIGNAL,
	TUNER_DISPLAY_FAVOURITES_CHANGED_SIG_SIGNAL,
	TUNER_DISPLAY_REFRESH_STARRED_STATIONS_SIG_SIGNAL,
	TUNER_DISPLAY_SEARCHED_FOR_SIG_SIGNAL,
	TUNER_DISPLAY_SEARCH_FOCUSED_SIG_SIGNAL,
	TUNER_DISPLAY_NUM_SIGNALS
};
static guint tuner_display_signals[TUNER_DISPLAY_NUM_SIGNALS] = {0};

struct _TunerStationListHookupIface {
	GTypeInterface parent_iface;
	void (*station_list_hookup) (TunerStationListHookup* self, TunerStationList* station_list);
};

struct _TunerDisplay {
	GtkPaned parent_instance;
	TunerDisplayPrivate * priv;
};

struct _TunerDisplayClass {
	GtkPanedClass parent_class;
};

struct _TunerDisplayPrivate {
	GtkStack* _stack;
	GraniteWidgetsSourceList* _source_list;
	TunerDirectoryController* _directory;
	GraniteWidgetsSourceListExpandableItem* _selections_category;
	GraniteWidgetsSourceListExpandableItem* _library_category;
	GraniteWidgetsSourceListExpandableItem* _saved_searches_category;
	GraniteWidgetsSourceListExpandableItem* _explore_category;
	GraniteWidgetsSourceListExpandableItem* _genres_category;
	GraniteWidgetsSourceListExpandableItem* _subgenres_category;
	GraniteWidgetsSourceListExpandableItem* _eras_category;
	GraniteWidgetsSourceListExpandableItem* _talk_category;
	gboolean _first_activation;
	gboolean _active;
	gboolean _shuffle;
	GtkRevealer* _background_tuner;
	GtkRevealer* _background_jukebox;
	GtkOverlay* _overlay;
	TunerStationSet* jukebox_station_set;
	TunerSearchController* _search_controller;
	TunerStationListBox* _search_results;
};

typedef enum  {
	SOURCE_ERROR_UNAVAILABLE
} SourceError;
#define SOURCE_ERROR source_error_quark ()

struct _TunerDisplayJukeboxShuffleData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TunerDisplay* self;
	GeeSet* _tmp0_;
	TunerStationSet* _tmp1_;
	GeeSet* _tmp2_;
	TunerModelStation* station;
	gint _tmp3_;
	gpointer* _tmp4_;
	TunerModelStation** _tmp5_;
	gint _tmp5__length1;
	TunerModelStation* _tmp6_;
	TunerModelStation* _tmp7_;
	TunerModelStation* _tmp8_;
	TunerModelStation* _tmp9_;
	GError* e;
	GError* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GError* _inner_error0_;
};

struct _Block18Data {
	int _ref_count_;
	TunerDisplay* self;
	gboolean start_on_starred;
};

struct _Block19Data {
	int _ref_count_;
	TunerDisplay* self;
	TunerStationListBox* discover;
	TunerStationListBox* starred;
	gpointer _async_data_;
};

struct _TunerDisplayInitializeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TunerDisplay* self;
	Block19Data* _data19_;
	TunerDirectoryController* _tmp0_;
	GtkStack* _tmp1_;
	GraniteWidgetsSourceList* _tmp2_;
	GraniteWidgetsSourceListExpandableItem* _tmp3_;
	TunerDirectoryController* _tmp4_;
	TunerStationSet* _tmp5_;
	TunerStationSet* _tmp6_;
	TunerStationListBox* _tmp7_;
	TunerStationListBox* _tmp8_;
	TunerStationListBox* _tmp9_;
	GtkStack* _tmp10_;
	GraniteWidgetsSourceList* _tmp11_;
	GraniteWidgetsSourceListExpandableItem* _tmp12_;
	TunerDirectoryController* _tmp13_;
	TunerStationSet* _tmp14_;
	TunerStationSet* _tmp15_;
	TunerStationListBox* _tmp16_;
	TunerStationListBox* _tmp17_;
	GtkStack* _tmp18_;
	GraniteWidgetsSourceList* _tmp19_;
	GraniteWidgetsSourceListExpandableItem* _tmp20_;
	TunerDirectoryController* _tmp21_;
	TunerStationSet* _tmp22_;
	TunerStationSet* _tmp23_;
	TunerStationListBox* _tmp24_;
	TunerStationListBox* _tmp25_;
	GraniteWidgetsSourceListExpandableItem* _tmp26_;
	GtkStack* _tmp27_;
	GraniteWidgetsSourceList* _tmp28_;
	GraniteWidgetsSourceListExpandableItem* _tmp29_;
	TunerDirectoryController* _tmp30_;
	GeeCollection* _tmp31_;
	GeeCollection* _tmp32_;
	TunerStationListBox* _tmp33_;
	TunerStationListBox* _tmp34_;
	TunerStationListBox* _tmp35_;
	TunerStationListBox* _tmp36_;
	guint _tmp37_;
	guint _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	gchar* _tmp42_;
	TunerStationListBox* _tmp43_;
	TunerStationListBox* _tmp44_;
	guint _tmp45_;
	guint _tmp46_;
	gchar* _tmp47_;
	gchar* _tmp48_;
	TunerStationListBox* _tmp49_;
	GtkStack* _tmp50_;
	GraniteWidgetsSourceList* _tmp51_;
	GraniteWidgetsSourceListExpandableItem* _tmp52_;
	TunerStationListBox* _tmp53_;
	TunerStationListBox* _tmp54_;
	GtkButton* _tmp55_;
	GtkButton* _tmp56_;
	TunerDirectoryController* _tmp57_;
	TunerStationListBox* _tmp58_;
	TunerSearchController* _tmp59_;
	TunerStationListBox* _tmp60_;
	TunerStationListBox* _tmp61_;
	GeeMap* saved_searches;
	TunerDirectoryController* _tmp62_;
	GeeMap* _tmp63_;
	GeeIterator* _search_term_it;
	GeeMap* _tmp64_;
	GeeSet* _tmp65_;
	GeeSet* _tmp66_;
	GeeSet* _tmp67_;
	GeeIterator* _tmp68_;
	GeeIterator* _tmp69_;
	GeeIterator* _tmp70_;
	gchar* search_term;
	GeeIterator* _tmp71_;
	gpointer _tmp72_;
	const gchar* _tmp73_;
	GeeMap* _tmp74_;
	const gchar* _tmp75_;
	gpointer _tmp76_;
	TunerStationSet* _tmp77_;
	TunerStationListBox* _tmp78_;
	TunerStationListBox* _tmp79_;
	GraniteWidgetsSourceListExpandableItem* _tmp80_;
	GThemedIcon* _tmp81_;
	GThemedIcon* _tmp82_;
	GraniteWidgetsSourceListExpandableItem* _tmp83_;
	GraniteWidgetsSourceListExpandableItem* _tmp84_;
	TunerApplication* _tmp85_;
	TunerApplication* _tmp86_;
	gboolean _tmp87_;
	gboolean _tmp88_;
	gboolean _tmp89_;
	guint explore;
	GeeIterator* _tag_it;
	TunerDirectoryController* _tmp90_;
	GeeSet* _tmp91_;
	GeeSet* _tmp92_;
	GeeIterator* _tmp93_;
	GeeIterator* _tmp94_;
	GeeIterator* _tmp95_;
	TunerDataProviderTag* tag;
	GeeIterator* _tmp96_;
	gpointer _tmp97_;
	TunerDataProviderTag* _tmp98_;
	const gchar* _tmp99_;
	const gchar* _tmp100_;
	GtkStack* _tmp101_;
	GraniteWidgetsSourceList* _tmp102_;
	GraniteWidgetsSourceListExpandableItem* _tmp103_;
	guint _tmp104_;
	gchar* _tmp105_;
	gchar* _tmp106_;
	TunerDataProviderTag* _tmp107_;
	const gchar* _tmp108_;
	const gchar* _tmp109_;
	TunerDataProviderTag* _tmp110_;
	const gchar* _tmp111_;
	const gchar* _tmp112_;
	TunerDirectoryController* _tmp113_;
	TunerDataProviderTag* _tmp114_;
	const gchar* _tmp115_;
	const gchar* _tmp116_;
	TunerStationSet* _tmp117_;
	TunerStationSet* _tmp118_;
	TunerStationListBox* _tmp119_;
	TunerStationListBox* _tmp120_;
	GtkStack* _tmp121_;
	GraniteWidgetsSourceList* _tmp122_;
	GraniteWidgetsSourceListExpandableItem* _tmp123_;
	TunerDirectoryController* _tmp124_;
	GtkStack* _tmp125_;
	GraniteWidgetsSourceList* _tmp126_;
	GraniteWidgetsSourceListExpandableItem* _tmp127_;
	TunerDirectoryController* _tmp128_;
	GtkStack* _tmp129_;
	GraniteWidgetsSourceList* _tmp130_;
	GraniteWidgetsSourceListExpandableItem* _tmp131_;
	TunerDirectoryController* _tmp132_;
	GtkStack* _tmp133_;
	GraniteWidgetsSourceList* _tmp134_;
	GraniteWidgetsSourceListExpandableItem* _tmp135_;
	TunerDirectoryController* _tmp136_;
	TunerApplication* _tmp137_;
	TunerApplication* _tmp138_;
	TunerStarStore* _tmp139_;
	TunerStarStore* _tmp140_;
	GraniteWidgetsSourceList* _tmp141_;
	GraniteWidgetsSourceList* _tmp142_;
	GraniteWidgetsSourceListExpandableItem* _tmp143_;
	GraniteWidgetsSourceListItem* _tmp144_;
	GraniteWidgetsSourceListItem* _tmp145_;
};

typedef enum  {
	TUNER_DATA_PROVIDER_DATA_ERROR_PARSE_DATA,
	TUNER_DATA_PROVIDER_DATA_ERROR_NO_CONNECTION
} TunerDataProviderDataError;
#define TUNER_DATA_PROVIDER_DATA_ERROR tuner_data_provider_data_error_quark ()

struct _TunerDataProviderSearchParams {
	gchar* text;
	GeeSet* tags;
	GeeSet* uuids;
	gchar* countrycode;
	TunerDataProviderSortOrder order;
	gboolean reverse;
};

struct _TunerDataProviderAPIIface {
	GTypeInterface parent_iface;
	void (*clear_last_error) (TunerDataProviderAPI* self);
	gchar* (*name) (TunerDataProviderAPI* self);
	gint (*available_stations) (TunerDataProviderAPI* self);
	gint (*available_tags) (TunerDataProviderAPI* self);
	gboolean (*initialize) (TunerDataProviderAPI* self);
	void (*click) (TunerDataProviderAPI* self, const gchar* stationuuid);
	void (*vote) (TunerDataProviderAPI* self, const gchar* stationuuid);
	GeeSet* (*get_tags) (TunerDataProviderAPI* self, gint offset, gint limit, GError** error);
	GeeSet* (*by_uuid) (TunerDataProviderAPI* self, const gchar* uuids, GError** error);
	GeeSet* (*by_uuids) (TunerDataProviderAPI* self, GeeCollection* uuids, GError** error);
	GeeSet* (*search) (TunerDataProviderAPI* self, TunerDataProviderSearchParams* params, guint rowcount, guint offset, GError** error);
	void (*search_async) (TunerDataProviderAPI* self, TunerDataProviderSearchParams* params, guint rowcount, guint offset, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GeeSet* (*search_finish) (TunerDataProviderAPI* self, GAsyncResult* _res_, GError** error);
	GError* (*get_last_data_error) (TunerDataProviderAPI* self);
	void (*set_last_data_error) (TunerDataProviderAPI* self, GError* value);
	TunerDataProviderAPIStatus (*get_status) (TunerDataProviderAPI* self);
	void (*set_status) (TunerDataProviderAPI* self, TunerDataProviderAPIStatus value);
};

struct _Block20Data {
	int _ref_count_;
	TunerDisplay* self;
	TunerStationListBox* saved_search;
	gchar* search;
};

static gint TunerDisplay_private_offset;
static gpointer tuner_display_parent_class = NULL;
static TunerStationListHookupIface * tuner_display_tuner_station_list_hookup_parent_iface = NULL;

VALA_EXTERN GType tuner_list_flow_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerListFlowBox, g_object_unref)
VALA_EXTERN GType tuner_station_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStationList, g_object_unref)
VALA_EXTERN GType tuner_station_list_hookup_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStationListHookup, g_object_unref)
VALA_EXTERN GType tuner_display_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDisplay, g_object_unref)
VALA_EXTERN GType tuner_directory_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDirectoryController, g_object_unref)
VALA_EXTERN GType tuner_station_set_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStationSet, g_object_unref)
VALA_EXTERN GType tuner_search_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerSearchController, g_object_unref)
VALA_EXTERN GType tuner_station_list_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStationListBox, g_object_unref)
VALA_EXTERN TunerDisplay* tuner_display_new (TunerDirectoryController* directory);
VALA_EXTERN TunerDisplay* tuner_display_construct (GType object_type,
                                       TunerDirectoryController* directory);
VALA_EXTERN TunerStationSet* tuner_directory_controller_load_random_stations (TunerDirectoryController* self,
                                                                  guint limit);
VALA_EXTERN GType tuner_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerApplication, g_object_unref)
VALA_EXTERN TunerApplication* tuner_app (void);
VALA_EXTERN GType tuner_player_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerPlayerController, g_object_unref)
VALA_EXTERN TunerPlayerController* tuner_application_get_player (TunerApplication* self);
static void __lambda71_ (TunerDisplay* self);
VALA_EXTERN void tuner_display_jukebox_shuffle (TunerDisplay* self,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void tuner_display_jukebox_shuffle_finish (TunerDisplay* self,
                                           GAsyncResult* _res_);
static void ___lambda71__tuner_player_controller_shuffle_requested_sig (TunerPlayerController* _sender,
                                                                 gpointer self);
VALA_EXTERN GtkStack* tuner_display_get_stack (TunerDisplay* self);
VALA_EXTERN GraniteWidgetsSourceList* tuner_display_get_source_list (TunerDisplay* self);
static void __lambda72_ (TunerDisplay* self,
                  GraniteWidgetsSourceListItem* item);
VALA_EXTERN GType tuner_station_list_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStationListItem, g_object_unref)
VALA_EXTERN void tuner_station_list_item_populate (TunerStationListItem* self,
                                       TunerStationListHookup* station_list,
                                       gboolean force);
static void ___lambda72__granite_widgets_source_list_item_selected (GraniteWidgetsSourceList* _sender,
                                                             GraniteWidgetsSourceListItem* item,
                                                             gpointer self);
static void tuner_display_jukebox_shuffle_data_free (gpointer _data);
static gboolean tuner_display_jukebox_shuffle_co (TunerDisplayJukeboxShuffleData* _data_);
VALA_EXTERN GType tuner_model_favicon_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerModelFavicon, g_object_unref)
VALA_EXTERN GType tuner_model_station_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerModelStation, g_object_unref)
VALA_EXTERN GQuark source_error_quark (void);
VALA_EXTERN GType source_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GeeSet* tuner_station_set_next_page (TunerStationSet* self,
                                     GError** error);
VALA_EXTERN void tuner_display_update_state (TunerDisplay* self,
                                 gboolean activate,
                                 gboolean start_on_starred);
static Block18Data* block18_data_ref (Block18Data* _data18_);
static void block18_data_unref (void * _userdata_);
static void tuner_display_initialize (TunerDisplay* self,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
static void tuner_display_initialize_finish (TunerDisplay* self,
                                      GAsyncResult* _res_);
static void ____lambda84_ (Block18Data* _data18_);
VALA_EXTERN void tuner_display_choose_starred_stations (TunerDisplay* self);
static void _____lambda84__gasync_ready_callback (GObject* source_object,
                                           GAsyncResult* res,
                                           gpointer self);
static void tuner_display_initialize_data_free (gpointer _data);
static gboolean tuner_display_initialize_co (TunerDisplayInitializeData* _data_);
static Block19Data* block19_data_ref (Block19Data* _data19_);
static void block19_data_unref (void * _userdata_);
VALA_EXTERN void tuner_directory_controller_load (TunerDirectoryController* self);
VALA_EXTERN TunerStationListBox* tuner_station_list_box_create (GtkStack* stack,
                                                    GraniteWidgetsSourceList* source_list,
                                                    GraniteWidgetsSourceListExpandableItem* category,
                                                    const gchar* name,
                                                    const gchar* icon,
                                                    const gchar* title,
                                                    const gchar* subtitle,
                                                    gboolean prepopulated,
                                                    TunerStationSet* data,
                                                    const gchar* action_tooltip_text,
                                                    const gchar* action_icon_name);
static void __lambda73_ (Block19Data* _data19_);
VALA_EXTERN TunerStationListItem* tuner_station_list_box_get_item (TunerStationListBox* self);
static void ___lambda73__tuner_station_list_box_action_button_activated_sig (TunerStationListBox* _sender,
                                                                      gpointer self);
VALA_EXTERN TunerStationListBox* tuner_station_list_box_create_category_specific (GtkStack* stack,
                                                                      GraniteWidgetsSourceList* source_list,
                                                                      GraniteWidgetsSourceListExpandableItem* category,
                                                                      const gchar* name,
                                                                      const gchar* icon,
                                                                      const gchar* title,
                                                                      const gchar* subtitle,
                                                                      TunerStationSet* station_set,
                                                                      const gchar* action_tooltip_text,
                                                                      const gchar* action_icon_name);
VALA_EXTERN TunerStationSet* tuner_directory_controller_load_trending_stations (TunerDirectoryController* self,
                                                                    guint limit);
VALA_EXTERN TunerStationSet* tuner_directory_controller_load_popular_stations (TunerDirectoryController* self,
                                                                   guint limit);
static void tuner_display_jukebox (TunerDisplay* self,
                            GraniteWidgetsSourceListExpandableItem* category);
VALA_EXTERN TunerStationListBox* tuner_station_list_box_create_category_predefined (TunerStationListHookup* slh,
                                                                        GtkStack* stack,
                                                                        GraniteWidgetsSourceList* source_list,
                                                                        GraniteWidgetsSourceListExpandableItem* category,
                                                                        const gchar* name,
                                                                        const gchar* icon,
                                                                        const gchar* title,
                                                                        const gchar* subtitle,
                                                                        GeeCollection* stations);
VALA_EXTERN GeeCollection* tuner_directory_controller_get_starred (TunerDirectoryController* self);
VALA_EXTERN void tuner_station_list_box_badge (TunerStationListBox* self,
                                   const gchar* badge);
VALA_EXTERN guint tuner_station_list_box_get_item_count (TunerStationListBox* self);
VALA_EXTERN void tuner_station_list_box_set_parameter (TunerStationListBox* self,
                                           const gchar* value);
static void __lambda76_ (Block19Data* _data19_,
                  guint item_count);
static void ___lambda76__tuner_station_list_box_item_count_changed_sig (TunerStationListBox* _sender,
                                                                 guint item_count,
                                                                 const gchar* parameter,
                                                                 gpointer self);
VALA_EXTERN GtkButton* tuner_station_list_box_get_tooltip_button (TunerStationListBox* self);
VALA_EXTERN TunerDirectoryController* tuner_display_get_directory (TunerDisplay* self);
VALA_EXTERN TunerSearchController* tuner_search_controller_new (TunerDirectoryController* dc,
                                                    TunerStationListHookup* slh,
                                                    TunerStationListBox* slb,
                                                    guint max_search_results);
VALA_EXTERN TunerSearchController* tuner_search_controller_construct (GType object_type,
                                                          TunerDirectoryController* dc,
                                                          TunerStationListHookup* slh,
                                                          TunerStationListBox* slb,
                                                          guint max_search_results);
static void __lambda77_ (TunerDisplay* self,
                  guint item_count,
                  const gchar* parameter);
static void ___lambda77__tuner_station_list_box_item_count_changed_sig (TunerStationListBox* _sender,
                                                                 guint item_count,
                                                                 const gchar* parameter,
                                                                 gpointer self);
static void __lambda78_ (TunerDisplay* self);
VALA_EXTERN gboolean tuner_application_get_is_offline (TunerApplication* self);
static TunerStationListBox* tuner_display_add_saved_search (TunerDisplay* self,
                                                     const gchar* search,
                                                     TunerStationSet* station_set);
VALA_EXTERN const gchar* tuner_station_list_box_get_parameter (TunerStationListBox* self);
VALA_EXTERN TunerStationSet* tuner_directory_controller_add_saved_search (TunerDirectoryController* self,
                                                              const gchar* search_term);
VALA_EXTERN void tuner_station_list_box_list (TunerStationListBox* self,
                                  TunerListFlowBox* content);
VALA_EXTERN TunerListFlowBox* tuner_station_list_box_get_content (TunerStationListBox* self);
static void ___lambda78__tuner_station_list_box_action_button_activated_sig (TunerStationListBox* _sender,
                                                                      gpointer self);
VALA_EXTERN GeeMap* tuner_directory_controller_load_saved_searches (TunerDirectoryController* self);
VALA_EXTERN gboolean tuner_application_get_is_online (TunerApplication* self);
VALA_EXTERN GType tuner_data_provider_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDataProviderTag, g_object_unref)
VALA_EXTERN GeeSet* tuner_directory_controller_load_random_genres (TunerDirectoryController* self,
                                                       gint genres);
VALA_EXTERN gboolean tuner_model_genre_in_genre (const gchar* genre);
VALA_EXTERN const gchar* tuner_data_provider_tag_get_name (TunerDataProviderTag* self);
VALA_EXTERN TunerStationSet* tuner_directory_controller_load_by_tag (TunerDirectoryController* self,
                                                         const gchar* utag);
static void tuner_display_create_category_genre (TunerDisplay* self,
                                          GtkStack* stack,
                                          GraniteWidgetsSourceList* source_list,
                                          GraniteWidgetsSourceListExpandableItem* category,
                                          TunerDirectoryController* directory,
                                          gchar** genres,
                                          gint genres_length1);
VALA_EXTERN GType tuner_star_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerStarStore, g_object_unref)
VALA_EXTERN TunerStarStore* tuner_application_get_stars (TunerApplication* self);
static void __lambda80_ (Block19Data* _data19_,
                  TunerModelStation* station);
VALA_EXTERN TunerStationList* tuner_station_list_with_stations (GeeCollection* stations);
VALA_EXTERN void tuner_station_list_hookup_station_list_hookup (TunerStationListHookup* self,
                                                    TunerStationList* station_list);
VALA_EXTERN void tuner_station_list_box_set_content (TunerStationListBox* self,
                                         TunerListFlowBox* value);
static void ___lambda80__tuner_star_store_starred_stations_changed_sig (TunerStarStore* _sender,
                                                                 TunerModelStation* station,
                                                                 gpointer self);
static void __lambda82_ (TunerDisplay* self);
static void ___lambda82__tuner_display_search_focused_sig (TunerDisplay* _sender,
                                                    gpointer self);
static void __lambda83_ (TunerDisplay* self,
                  const gchar* text);
VALA_EXTERN void tuner_search_controller_handle_search_for (TunerSearchController* self,
                                                const gchar* search_term);
static void ___lambda83__tuner_display_searched_for_sig (TunerDisplay* _sender,
                                                  const gchar* text,
                                                  gpointer self);
VALA_EXTERN GQuark tuner_data_provider_data_error_quark (void);
VALA_EXTERN GType tuner_data_provider_data_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuner_data_provider_search_params_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuner_data_provider_sort_order_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TunerDataProviderSearchParams* tuner_data_provider_search_params_dup (const TunerDataProviderSearchParams* self);
VALA_EXTERN void tuner_data_provider_search_params_free (TunerDataProviderSearchParams* self);
VALA_EXTERN void tuner_data_provider_search_params_copy (const TunerDataProviderSearchParams* self,
                                             TunerDataProviderSearchParams* dest);
VALA_EXTERN void tuner_data_provider_search_params_destroy (TunerDataProviderSearchParams* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TunerDataProviderSearchParams, tuner_data_provider_search_params_destroy)
VALA_EXTERN GType tuner_data_provider_api_status_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuner_data_provider_api_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TunerDataProviderAPI, g_object_unref)
VALA_EXTERN TunerDataProviderAPI* tuner_application_get_provider (TunerApplication* self);
VALA_EXTERN gint tuner_data_provider_api_available_stations (TunerDataProviderAPI* self);
static void __lambda74_ (TunerDisplay* self);
static void ___lambda74__granite_widgets_source_list_item_activated (GraniteWidgetsSourceListItem* _sender,
                                                              gpointer self);
static void __lambda75_ (TunerDisplay* self,
                  TunerModelStation* oldstation);
static void ___lambda75__tuner_player_controller_tape_counter_sig (TunerPlayerController* _sender,
                                                            TunerModelStation* station,
                                                            gpointer self);
static void tuner_display_real_station_list_hookup (TunerStationListHookup* base,
                                             TunerStationList* station_list);
static void __lambda81_ (TunerDisplay* self,
                  TunerModelStation* station);
static void ___lambda81__tuner_station_list_station_clicked_sig (TunerStationList* _sender,
                                                          TunerModelStation* station,
                                                          gpointer self);
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
static void __lambda79_ (Block20Data* _data20_);
VALA_EXTERN void tuner_directory_controller_remove_saved_search (TunerDirectoryController* self,
                                                     const gchar* search_text);
VALA_EXTERN void tuner_station_list_box_delist (TunerStationListBox* self);
static void ___lambda79__tuner_station_list_box_action_button_activated_sig (TunerStationListBox* _sender,
                                                                      gpointer self);
static void tuner_display_set_stack (TunerDisplay* self,
                              GtkStack* value);
static void tuner_display_set_source_list (TunerDisplay* self,
                                    GraniteWidgetsSourceList* value);
static void tuner_display_set_directory (TunerDisplay* self,
                                  TunerDirectoryController* value);
static void tuner_display_finalize (GObject * obj);
static GType tuner_display_get_type_once (void);
static void _vala_tuner_display_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_tuner_display_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

VALA_EXTERN const gchar* TUNER_MODEL_GENRE_GENRES[14];
VALA_EXTERN const gchar* TUNER_MODEL_GENRE_SUBGENRES[14];
VALA_EXTERN const gchar* TUNER_MODEL_GENRE_ERAS[9];
VALA_EXTERN const gchar* TUNER_MODEL_GENRE_TALK[12];

static inline gpointer
tuner_display_get_instance_private (TunerDisplay* self)
{
	return G_STRUCT_MEMBER_P (self, TunerDisplay_private_offset);
}

/**
     * @brief Constructs a new Display instance.
     * @param directory The directory controller to use.
     */
static void
__lambda71_ (TunerDisplay* self)
{
#line 141 "../src/Widgets/Display.vala"
	if (self->priv->_shuffle) {
#line 142 "../src/Widgets/Display.vala"
		tuner_display_jukebox_shuffle (self, NULL, NULL);
#line 857 "Display.c"
	}
}

static void
___lambda71__tuner_player_controller_shuffle_requested_sig (TunerPlayerController* _sender,
                                                            gpointer self)
{
#line 139 "../src/Widgets/Display.vala"
	__lambda71_ ((TunerDisplay*) self);
#line 867 "Display.c"
}

static void
__lambda72_ (TunerDisplay* self,
             GraniteWidgetsSourceListItem* item)
{
	gchar* selected_item = NULL;
	gconstpointer _tmp0_;
	gchar* _tmp1_;
	GtkStack* _tmp2_;
#line 211 "../src/Widgets/Display.vala"
	if (TUNER_IS_STATION_LIST_ITEM (item)) {
#line 212 "../src/Widgets/Display.vala"
		tuner_station_list_item_populate (G_TYPE_CHECK_INSTANCE_CAST (item, TUNER_TYPE_STATION_LIST_ITEM, TunerStationListItem), (TunerStationListHookup*) self, FALSE);
#line 882 "Display.c"
	}
#line 213 "../src/Widgets/Display.vala"
	_tmp0_ = g_object_get_data ((GObject*) item, "stack_child");
#line 213 "../src/Widgets/Display.vala"
	_tmp1_ = g_strdup ((const gchar*) _tmp0_);
#line 213 "../src/Widgets/Display.vala"
	selected_item = _tmp1_;
#line 214 "../src/Widgets/Display.vala"
	_tmp2_ = self->priv->_stack;
#line 214 "../src/Widgets/Display.vala"
	gtk_stack_set_visible_child_name (_tmp2_, selected_item);
#line 208 "../src/Widgets/Display.vala"
	_g_free0 (selected_item);
#line 896 "Display.c"
}

static void
___lambda72__granite_widgets_source_list_item_selected (GraniteWidgetsSourceList* _sender,
                                                        GraniteWidgetsSourceListItem* item,
                                                        gpointer self)
{
#line 208 "../src/Widgets/Display.vala"
	__lambda72_ ((TunerDisplay*) self, item);
#line 906 "Display.c"
}

TunerDisplay*
tuner_display_construct (GType object_type,
                         TunerDirectoryController* directory)
{
	TunerDisplay * self = NULL;
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GraniteWidgetsSourceList* _tmp2_;
	GraniteWidgetsSourceList* _tmp3_;
	GtkStack* _tmp4_;
	GtkStack* _tmp5_;
	TunerDirectoryController* _tmp6_;
	TunerStationSet* _tmp7_;
	TunerApplication* _tmp8_;
	TunerApplication* _tmp9_;
	TunerPlayerController* _tmp10_;
	TunerPlayerController* _tmp11_;
	GtkImage* tuner = NULL;
	GtkImage* _tmp12_;
	GtkRevealer* _tmp13_;
	GtkRevealer* _tmp14_;
	GtkRevealer* _tmp15_;
	GtkRevealer* _tmp16_;
	GtkImage* jukebox = NULL;
	GtkImage* _tmp17_;
	GtkRevealer* _tmp18_;
	GtkRevealer* _tmp19_;
	GtkRevealer* _tmp20_;
	GtkRevealer* _tmp21_;
	GtkFixed* background = NULL;
	GtkFixed* _tmp22_;
	GtkRevealer* _tmp23_;
	GtkRevealer* _tmp24_;
	GtkOverlay* _tmp25_;
	GtkStack* _tmp26_;
	GtkOverlay* _tmp27_;
	GtkStack* _tmp28_;
	GraniteWidgetsSourceListExpandableItem* _tmp29_;
	GraniteWidgetsSourceListExpandableItem* _tmp30_;
	GraniteWidgetsSourceListExpandableItem* _tmp31_;
	GraniteWidgetsSourceListExpandableItem* _tmp32_;
	GraniteWidgetsSourceListExpandableItem* _tmp33_;
	GraniteWidgetsSourceListExpandableItem* _tmp34_;
	GraniteWidgetsSourceListExpandableItem* _tmp35_;
	GraniteWidgetsSourceListExpandableItem* _tmp36_;
	GraniteWidgetsSourceListExpandableItem* _tmp37_;
	GraniteWidgetsSourceListExpandableItem* _tmp38_;
	GraniteWidgetsSourceListExpandableItem* _tmp39_;
	GraniteWidgetsSourceListExpandableItem* _tmp40_;
	GraniteWidgetsSourceListExpandableItem* _tmp41_;
	GraniteWidgetsSourceListExpandableItem* _tmp42_;
	GraniteWidgetsSourceListExpandableItem* _tmp43_;
	GraniteWidgetsSourceListExpandableItem* _tmp44_;
	GraniteWidgetsSourceList* _tmp45_;
	GraniteWidgetsSourceListExpandableItem* _tmp46_;
	GraniteWidgetsSourceListExpandableItem* _tmp47_;
	GraniteWidgetsSourceListExpandableItem* _tmp48_;
	GraniteWidgetsSourceList* _tmp49_;
	GraniteWidgetsSourceListExpandableItem* _tmp50_;
	GraniteWidgetsSourceListExpandableItem* _tmp51_;
	GraniteWidgetsSourceListExpandableItem* _tmp52_;
	GraniteWidgetsSourceList* _tmp53_;
	GraniteWidgetsSourceListExpandableItem* _tmp54_;
	GraniteWidgetsSourceListExpandableItem* _tmp55_;
	GraniteWidgetsSourceListExpandableItem* _tmp56_;
	GraniteWidgetsSourceList* _tmp57_;
	GraniteWidgetsSourceListExpandableItem* _tmp58_;
	GraniteWidgetsSourceListExpandableItem* _tmp59_;
	GraniteWidgetsSourceListExpandableItem* _tmp60_;
	GraniteWidgetsSourceList* _tmp61_;
	GraniteWidgetsSourceListExpandableItem* _tmp62_;
	GraniteWidgetsSourceListExpandableItem* _tmp63_;
	GraniteWidgetsSourceListExpandableItem* _tmp64_;
	GraniteWidgetsSourceList* _tmp65_;
	GraniteWidgetsSourceListExpandableItem* _tmp66_;
	GraniteWidgetsSourceListExpandableItem* _tmp67_;
	GraniteWidgetsSourceListExpandableItem* _tmp68_;
	GraniteWidgetsSourceList* _tmp69_;
	GraniteWidgetsSourceListExpandableItem* _tmp70_;
	GraniteWidgetsSourceListExpandableItem* _tmp71_;
	GraniteWidgetsSourceListExpandableItem* _tmp72_;
	GraniteWidgetsSourceList* _tmp73_;
	GraniteWidgetsSourceList* _tmp74_;
	GraniteWidgetsSourceList* _tmp75_;
	GtkOverlay* _tmp76_;
#line 130 "../src/Widgets/Display.vala"
	g_return_val_if_fail (directory != NULL, NULL);
#line 132 "../src/Widgets/Display.vala"
	_tmp0_ = granite_widgets_source_list_expandable_item_new ("");
#line 132 "../src/Widgets/Display.vala"
	_tmp1_ = _tmp0_;
#line 132 "../src/Widgets/Display.vala"
	_tmp2_ = granite_widgets_source_list_new (_tmp1_);
#line 132 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp2_);
#line 132 "../src/Widgets/Display.vala"
	_tmp3_ = _tmp2_;
#line 132 "../src/Widgets/Display.vala"
	_tmp4_ = (GtkStack*) gtk_stack_new ();
#line 132 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp4_);
#line 132 "../src/Widgets/Display.vala"
	_tmp5_ = _tmp4_;
#line 132 "../src/Widgets/Display.vala"
	self = (TunerDisplay*) g_object_new (object_type, "directory", directory, "source-list", _tmp3_, "stack", _tmp5_, NULL);
#line 132 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp5_);
#line 132 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp3_);
#line 132 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp1_);
#line 138 "../src/Widgets/Display.vala"
	_tmp6_ = self->priv->_directory;
#line 138 "../src/Widgets/Display.vala"
	_tmp7_ = tuner_directory_controller_load_random_stations (_tmp6_, (guint) 1);
#line 138 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->jukebox_station_set);
#line 138 "../src/Widgets/Display.vala"
	self->priv->jukebox_station_set = _tmp7_;
#line 139 "../src/Widgets/Display.vala"
	_tmp8_ = tuner_app ();
#line 139 "../src/Widgets/Display.vala"
	_tmp9_ = _tmp8_;
#line 139 "../src/Widgets/Display.vala"
	_tmp10_ = tuner_application_get_player (_tmp9_);
#line 139 "../src/Widgets/Display.vala"
	_tmp11_ = _tmp10_;
#line 139 "../src/Widgets/Display.vala"
	g_signal_connect_object (_tmp11_, "shuffle-requested-sig", (GCallback) ___lambda71__tuner_player_controller_shuffle_requested_sig, self, 0);
#line 139 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp9_);
#line 145 "../src/Widgets/Display.vala"
	_tmp12_ = (GtkImage*) gtk_image_new_from_resource (TUNER_DISPLAY_BACKGROUND_TUNER);
#line 145 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp12_);
#line 145 "../src/Widgets/Display.vala"
	tuner = _tmp12_;
#line 146 "../src/Widgets/Display.vala"
	gtk_widget_set_opacity ((GtkWidget*) tuner, TUNER_DISPLAY_BACKGROUND_OPACITY);
#line 147 "../src/Widgets/Display.vala"
	_tmp13_ = self->priv->_background_tuner;
#line 147 "../src/Widgets/Display.vala"
	gtk_revealer_set_transition_duration (_tmp13_, (guint) TUNER_DISPLAY_BACKGROUND_TRANSITION_TIME_MS);
#line 148 "../src/Widgets/Display.vala"
	_tmp14_ = self->priv->_background_tuner;
#line 148 "../src/Widgets/Display.vala"
	gtk_revealer_set_transition_type (_tmp14_, TUNER_DISPLAY_BACKGROUND_TRANSITION_TYPE);
#line 149 "../src/Widgets/Display.vala"
	_tmp15_ = self->priv->_background_tuner;
#line 149 "../src/Widgets/Display.vala"
	gtk_revealer_set_reveal_child (_tmp15_, TRUE);
#line 150 "../src/Widgets/Display.vala"
	_tmp16_ = self->priv->_background_tuner;
#line 150 "../src/Widgets/Display.vala"
	g_object_set ((GtkContainer*) _tmp16_, "child", (GtkWidget*) tuner, NULL);
#line 152 "../src/Widgets/Display.vala"
	_tmp17_ = (GtkImage*) gtk_image_new_from_resource (TUNER_DISPLAY_BACKGROUND_JUKEBOX);
#line 152 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp17_);
#line 152 "../src/Widgets/Display.vala"
	jukebox = _tmp17_;
#line 153 "../src/Widgets/Display.vala"
	gtk_widget_set_opacity ((GtkWidget*) jukebox, TUNER_DISPLAY_BACKGROUND_OPACITY);
#line 154 "../src/Widgets/Display.vala"
	_tmp18_ = self->priv->_background_jukebox;
#line 154 "../src/Widgets/Display.vala"
	gtk_revealer_set_transition_duration (_tmp18_, (guint) TUNER_DISPLAY_BACKGROUND_TRANSITION_TIME_MS);
#line 155 "../src/Widgets/Display.vala"
	_tmp19_ = self->priv->_background_jukebox;
#line 155 "../src/Widgets/Display.vala"
	gtk_revealer_set_transition_type (_tmp19_, TUNER_DISPLAY_BACKGROUND_TRANSITION_TYPE);
#line 156 "../src/Widgets/Display.vala"
	_tmp20_ = self->priv->_background_jukebox;
#line 156 "../src/Widgets/Display.vala"
	gtk_revealer_set_reveal_child (_tmp20_, FALSE);
#line 157 "../src/Widgets/Display.vala"
	_tmp21_ = self->priv->_background_jukebox;
#line 157 "../src/Widgets/Display.vala"
	g_object_set ((GtkContainer*) _tmp21_, "child", (GtkWidget*) jukebox, NULL);
#line 159 "../src/Widgets/Display.vala"
	_tmp22_ = (GtkFixed*) gtk_fixed_new ();
#line 159 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp22_);
#line 159 "../src/Widgets/Display.vala"
	background = _tmp22_;
#line 160 "../src/Widgets/Display.vala"
	_tmp23_ = self->priv->_background_tuner;
#line 160 "../src/Widgets/Display.vala"
	gtk_container_add ((GtkContainer*) background, (GtkWidget*) _tmp23_);
#line 161 "../src/Widgets/Display.vala"
	_tmp24_ = self->priv->_background_jukebox;
#line 161 "../src/Widgets/Display.vala"
	gtk_container_add ((GtkContainer*) background, (GtkWidget*) _tmp24_);
#line 162 "../src/Widgets/Display.vala"
	gtk_widget_set_halign ((GtkWidget*) background, GTK_ALIGN_CENTER);
#line 163 "../src/Widgets/Display.vala"
	gtk_widget_set_valign ((GtkWidget*) background, GTK_ALIGN_CENTER);
#line 164 "../src/Widgets/Display.vala"
	_tmp25_ = self->priv->_overlay;
#line 164 "../src/Widgets/Display.vala"
	gtk_container_add ((GtkContainer*) _tmp25_, (GtkWidget*) background);
#line 167 "../src/Widgets/Display.vala"
	_tmp26_ = self->priv->_stack;
#line 167 "../src/Widgets/Display.vala"
	gtk_stack_set_transition_type (_tmp26_, GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 168 "../src/Widgets/Display.vala"
	_tmp27_ = self->priv->_overlay;
#line 168 "../src/Widgets/Display.vala"
	_tmp28_ = self->priv->_stack;
#line 168 "../src/Widgets/Display.vala"
	gtk_overlay_add_overlay (_tmp27_, (GtkWidget*) _tmp28_);
#line 174 "../src/Widgets/Display.vala"
	_tmp29_ = self->priv->_selections_category;
#line 174 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp29_, FALSE);
#line 175 "../src/Widgets/Display.vala"
	_tmp30_ = self->priv->_selections_category;
#line 175 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp30_, TRUE);
#line 177 "../src/Widgets/Display.vala"
	_tmp31_ = self->priv->_library_category;
#line 177 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp31_, FALSE);
#line 178 "../src/Widgets/Display.vala"
	_tmp32_ = self->priv->_library_category;
#line 178 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp32_, FALSE);
#line 180 "../src/Widgets/Display.vala"
	_tmp33_ = self->priv->_saved_searches_category;
#line 180 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp33_, TRUE);
#line 181 "../src/Widgets/Display.vala"
	_tmp34_ = self->priv->_saved_searches_category;
#line 181 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp34_, FALSE);
#line 183 "../src/Widgets/Display.vala"
	_tmp35_ = self->priv->_explore_category;
#line 183 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp35_, TRUE);
#line 184 "../src/Widgets/Display.vala"
	_tmp36_ = self->priv->_explore_category;
#line 184 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp36_, TRUE);
#line 186 "../src/Widgets/Display.vala"
	_tmp37_ = self->priv->_genres_category;
#line 186 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp37_, TRUE);
#line 187 "../src/Widgets/Display.vala"
	_tmp38_ = self->priv->_genres_category;
#line 187 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp38_, FALSE);
#line 189 "../src/Widgets/Display.vala"
	_tmp39_ = self->priv->_subgenres_category;
#line 189 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp39_, TRUE);
#line 190 "../src/Widgets/Display.vala"
	_tmp40_ = self->priv->_subgenres_category;
#line 190 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp40_, FALSE);
#line 192 "../src/Widgets/Display.vala"
	_tmp41_ = self->priv->_eras_category;
#line 192 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp41_, TRUE);
#line 193 "../src/Widgets/Display.vala"
	_tmp42_ = self->priv->_eras_category;
#line 193 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp42_, FALSE);
#line 195 "../src/Widgets/Display.vala"
	_tmp43_ = self->priv->_talk_category;
#line 195 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_collapsible (_tmp43_, TRUE);
#line 196 "../src/Widgets/Display.vala"
	_tmp44_ = self->priv->_talk_category;
#line 196 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_set_expanded (_tmp44_, FALSE);
#line 199 "../src/Widgets/Display.vala"
	_tmp45_ = self->priv->_source_list;
#line 199 "../src/Widgets/Display.vala"
	_tmp46_ = granite_widgets_source_list_get_root (_tmp45_);
#line 199 "../src/Widgets/Display.vala"
	_tmp47_ = _tmp46_;
#line 199 "../src/Widgets/Display.vala"
	_tmp48_ = self->priv->_selections_category;
#line 199 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp47_, (GraniteWidgetsSourceListItem*) _tmp48_);
#line 200 "../src/Widgets/Display.vala"
	_tmp49_ = self->priv->_source_list;
#line 200 "../src/Widgets/Display.vala"
	_tmp50_ = granite_widgets_source_list_get_root (_tmp49_);
#line 200 "../src/Widgets/Display.vala"
	_tmp51_ = _tmp50_;
#line 200 "../src/Widgets/Display.vala"
	_tmp52_ = self->priv->_library_category;
#line 200 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp51_, (GraniteWidgetsSourceListItem*) _tmp52_);
#line 201 "../src/Widgets/Display.vala"
	_tmp53_ = self->priv->_source_list;
#line 201 "../src/Widgets/Display.vala"
	_tmp54_ = granite_widgets_source_list_get_root (_tmp53_);
#line 201 "../src/Widgets/Display.vala"
	_tmp55_ = _tmp54_;
#line 201 "../src/Widgets/Display.vala"
	_tmp56_ = self->priv->_explore_category;
#line 201 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp55_, (GraniteWidgetsSourceListItem*) _tmp56_);
#line 202 "../src/Widgets/Display.vala"
	_tmp57_ = self->priv->_source_list;
#line 202 "../src/Widgets/Display.vala"
	_tmp58_ = granite_widgets_source_list_get_root (_tmp57_);
#line 202 "../src/Widgets/Display.vala"
	_tmp59_ = _tmp58_;
#line 202 "../src/Widgets/Display.vala"
	_tmp60_ = self->priv->_genres_category;
#line 202 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp59_, (GraniteWidgetsSourceListItem*) _tmp60_);
#line 203 "../src/Widgets/Display.vala"
	_tmp61_ = self->priv->_source_list;
#line 203 "../src/Widgets/Display.vala"
	_tmp62_ = granite_widgets_source_list_get_root (_tmp61_);
#line 203 "../src/Widgets/Display.vala"
	_tmp63_ = _tmp62_;
#line 203 "../src/Widgets/Display.vala"
	_tmp64_ = self->priv->_subgenres_category;
#line 203 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp63_, (GraniteWidgetsSourceListItem*) _tmp64_);
#line 204 "../src/Widgets/Display.vala"
	_tmp65_ = self->priv->_source_list;
#line 204 "../src/Widgets/Display.vala"
	_tmp66_ = granite_widgets_source_list_get_root (_tmp65_);
#line 204 "../src/Widgets/Display.vala"
	_tmp67_ = _tmp66_;
#line 204 "../src/Widgets/Display.vala"
	_tmp68_ = self->priv->_eras_category;
#line 204 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp67_, (GraniteWidgetsSourceListItem*) _tmp68_);
#line 205 "../src/Widgets/Display.vala"
	_tmp69_ = self->priv->_source_list;
#line 205 "../src/Widgets/Display.vala"
	_tmp70_ = granite_widgets_source_list_get_root (_tmp69_);
#line 205 "../src/Widgets/Display.vala"
	_tmp71_ = _tmp70_;
#line 205 "../src/Widgets/Display.vala"
	_tmp72_ = self->priv->_talk_category;
#line 205 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_tmp71_, (GraniteWidgetsSourceListItem*) _tmp72_);
#line 207 "../src/Widgets/Display.vala"
	_tmp73_ = self->priv->_source_list;
#line 207 "../src/Widgets/Display.vala"
	granite_widgets_source_list_set_ellipsize_mode (_tmp73_, PANGO_ELLIPSIZE_NONE);
#line 208 "../src/Widgets/Display.vala"
	_tmp74_ = self->priv->_source_list;
#line 208 "../src/Widgets/Display.vala"
	g_signal_connect_object (_tmp74_, "item-selected", (GCallback) ___lambda72__granite_widgets_source_list_item_selected, self, 0);
#line 217 "../src/Widgets/Display.vala"
	_tmp75_ = self->priv->_source_list;
#line 217 "../src/Widgets/Display.vala"
	gtk_paned_pack1 ((GtkPaned*) self, (GtkWidget*) _tmp75_, FALSE, FALSE);
#line 218 "../src/Widgets/Display.vala"
	_tmp76_ = self->priv->_overlay;
#line 218 "../src/Widgets/Display.vala"
	gtk_paned_pack2 ((GtkPaned*) self, (GtkWidget*) _tmp76_, TRUE, FALSE);
#line 219 "../src/Widgets/Display.vala"
	gtk_paned_set_position ((GtkPaned*) self, 200);
#line 130 "../src/Widgets/Display.vala"
	_g_object_unref0 (background);
#line 130 "../src/Widgets/Display.vala"
	_g_object_unref0 (jukebox);
#line 130 "../src/Widgets/Display.vala"
	_g_object_unref0 (tuner);
#line 130 "../src/Widgets/Display.vala"
	return self;
#line 1280 "Display.c"
}

TunerDisplay*
tuner_display_new (TunerDirectoryController* directory)
{
#line 130 "../src/Widgets/Display.vala"
	return tuner_display_construct (TUNER_TYPE_DISPLAY, directory);
#line 1288 "Display.c"
}

static void
tuner_display_jukebox_shuffle_data_free (gpointer _data)
{
	TunerDisplayJukeboxShuffleData* _data_;
	_data_ = _data;
#line 31 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->self);
#line 31 "../src/Widgets/Display.vala"
	g_slice_free (TunerDisplayJukeboxShuffleData, _data_);
#line 1300 "Display.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 31 "../src/Widgets/Display.vala"
	return self ? g_object_ref (self) : NULL;
#line 1308 "Display.c"
}

void
tuner_display_jukebox_shuffle (TunerDisplay* self,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_)
{
	TunerDisplayJukeboxShuffleData* _data_;
	TunerDisplay* _tmp0_;
#line 31 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 31 "../src/Widgets/Display.vala"
	_data_ = g_slice_new0 (TunerDisplayJukeboxShuffleData);
#line 31 "../src/Widgets/Display.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 31 "../src/Widgets/Display.vala"
	g_task_set_task_data (_data_->_async_result, _data_, tuner_display_jukebox_shuffle_data_free);
#line 31 "../src/Widgets/Display.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 31 "../src/Widgets/Display.vala"
	_data_->self = _tmp0_;
#line 31 "../src/Widgets/Display.vala"
	tuner_display_jukebox_shuffle_co (_data_);
#line 1332 "Display.c"
}

void
tuner_display_jukebox_shuffle_finish (TunerDisplay* self,
                                      GAsyncResult* _res_)
{
	TunerDisplayJukeboxShuffleData* _data_;
#line 31 "../src/Widgets/Display.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 1342 "Display.c"
}

/**
    * @brief Asynchronously shuffles to a new random station in jukebox mode
    *
    * If shuffle mode is active, selects and plays a new random station
    * from the jukebox station set.
    */
static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
#line 1624 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1625 "glib-2.0.vapi"
	result = self;
#line 1625 "glib-2.0.vapi"
	return result;
#line 1361 "Display.c"
}

static gboolean
tuner_display_jukebox_shuffle_co (TunerDisplayJukeboxShuffleData* _data_)
{
#line 237 "../src/Widgets/Display.vala"
	switch (_data_->_state_) {
#line 237 "../src/Widgets/Display.vala"
		case 0:
#line 1371 "Display.c"
		goto _state_0;
		default:
#line 237 "../src/Widgets/Display.vala"
		g_assert_not_reached ();
#line 1376 "Display.c"
	}
	_state_0:
#line 238 "../src/Widgets/Display.vala"
	if (!_data_->self->priv->_shuffle) {
#line 239 "../src/Widgets/Display.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 239 "../src/Widgets/Display.vala"
		if (_data_->_state_ != 0) {
#line 239 "../src/Widgets/Display.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 239 "../src/Widgets/Display.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1389 "Display.c"
			}
		}
#line 239 "../src/Widgets/Display.vala"
		g_object_unref (_data_->_async_result);
#line 239 "../src/Widgets/Display.vala"
		return FALSE;
#line 1396 "Display.c"
	}
	{
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp1_ = _data_->self->priv->jukebox_station_set;
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp2_ = tuner_station_set_next_page (_data_->_tmp1_, &_data_->_inner_error0_);
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp0_ = _data_->_tmp2_;
#line 242 "../src/Widgets/Display.vala"
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 242 "../src/Widgets/Display.vala"
			if (_data_->_inner_error0_->domain == SOURCE_ERROR) {
#line 1409 "Display.c"
				goto __catch0_source_error;
			}
#line 242 "../src/Widgets/Display.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 242 "../src/Widgets/Display.vala"
			g_clear_error (&_data_->_inner_error0_);
#line 242 "../src/Widgets/Display.vala"
			g_object_unref (_data_->_async_result);
#line 242 "../src/Widgets/Display.vala"
			return FALSE;
#line 1420 "Display.c"
		}
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp3_ = 0;
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp4_ = gee_collection_to_array ((GeeCollection*) _data_->_tmp0_, &_data_->_tmp3_);
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp5__length1 = _data_->_tmp3_;
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp6_ = _data_->_tmp5_[0];
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp7_ = _g_object_ref0 (_data_->_tmp6_);
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp8_ = _data_->_tmp7_;
#line 242 "../src/Widgets/Display.vala"
		_data_->_tmp5_ = (_vala_array_free (_data_->_tmp5_, _data_->_tmp5__length1, (GDestroyNotify) g_object_unref), NULL);
#line 242 "../src/Widgets/Display.vala"
		_data_->station = _data_->_tmp8_;
#line 243 "../src/Widgets/Display.vala"
		_data_->_tmp9_ = _data_->station;
#line 243 "../src/Widgets/Display.vala"
		g_signal_emit (_data_->self, tuner_display_signals[TUNER_DISPLAY_STATION_CLICKED_SIG_SIGNAL], 0, _data_->_tmp9_);
#line 240 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data_->station);
#line 240 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data_->_tmp0_);
#line 1448 "Display.c"
	}
	goto __finally0;
	__catch0_source_error:
	{
#line 240 "../src/Widgets/Display.vala"
		_data_->e = _data_->_inner_error0_;
#line 240 "../src/Widgets/Display.vala"
		_data_->_inner_error0_ = NULL;
#line 247 "../src/Widgets/Display.vala"
		_data_->_tmp10_ = _data_->e;
#line 247 "../src/Widgets/Display.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 247 "../src/Widgets/Display.vala"
		_data_->_tmp12_ = string_to_string (_data_->_tmp11_);
#line 247 "../src/Widgets/Display.vala"
		_data_->_tmp13_ = g_strconcat ("Could not get random station: ", _data_->_tmp12_, NULL);
#line 247 "../src/Widgets/Display.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 247 "../src/Widgets/Display.vala"
		g_warning ("Display.vala:247: %s", _ (_data_->_tmp14_));
#line 247 "../src/Widgets/Display.vala"
		_g_free0 (_data_->_tmp14_);
#line 240 "../src/Widgets/Display.vala"
		_g_error_free0 (_data_->e);
#line 1473 "Display.c"
	}
	__finally0:
#line 240 "../src/Widgets/Display.vala"
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 240 "../src/Widgets/Display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 240 "../src/Widgets/Display.vala"
		g_clear_error (&_data_->_inner_error0_);
#line 240 "../src/Widgets/Display.vala"
		g_object_unref (_data_->_async_result);
#line 240 "../src/Widgets/Display.vala"
		return FALSE;
#line 1486 "Display.c"
	}
#line 237 "../src/Widgets/Display.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 237 "../src/Widgets/Display.vala"
	if (_data_->_state_ != 0) {
#line 237 "../src/Widgets/Display.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 237 "../src/Widgets/Display.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1496 "Display.c"
		}
	}
#line 237 "../src/Widgets/Display.vala"
	g_object_unref (_data_->_async_result);
#line 237 "../src/Widgets/Display.vala"
	return FALSE;
#line 1503 "Display.c"
}

/**
    * @brief Updates the display state based on activation status
    * @param activate Whether to activate (true) or deactivate (false) the display
    * 
    * Manages the display's active state and performs first-time initialization
    * when needed.
    */
static Block18Data*
block18_data_ref (Block18Data* _data18_)
{
#line 259 "../src/Widgets/Display.vala"
	g_atomic_int_inc (&_data18_->_ref_count_);
#line 259 "../src/Widgets/Display.vala"
	return _data18_;
#line 1520 "Display.c"
}

static void
block18_data_unref (void * _userdata_)
{
	Block18Data* _data18_;
	_data18_ = (Block18Data*) _userdata_;
#line 259 "../src/Widgets/Display.vala"
	if (g_atomic_int_dec_and_test (&_data18_->_ref_count_)) {
#line 1530 "Display.c"
		TunerDisplay* self;
#line 259 "../src/Widgets/Display.vala"
		self = _data18_->self;
#line 259 "../src/Widgets/Display.vala"
		_g_object_unref0 (self);
#line 259 "../src/Widgets/Display.vala"
		g_slice_free (Block18Data, _data18_);
#line 1538 "Display.c"
	}
}

static void
____lambda84_ (Block18Data* _data18_)
{
	TunerDisplay* self;
#line 275 "../src/Widgets/Display.vala"
	self = _data18_->self;
#line 277 "../src/Widgets/Display.vala"
	if (_data18_->start_on_starred) {
#line 277 "../src/Widgets/Display.vala"
		tuner_display_choose_starred_stations (self);
#line 1552 "Display.c"
	}
}

static void
_____lambda84__gasync_ready_callback (GObject* source_object,
                                      GAsyncResult* res,
                                      gpointer self)
{
#line 275 "../src/Widgets/Display.vala"
	____lambda84_ (self);
#line 275 "../src/Widgets/Display.vala"
	block18_data_unref (self);
#line 1565 "Display.c"
}

void
tuner_display_update_state (TunerDisplay* self,
                            gboolean activate,
                            gboolean start_on_starred)
{
	Block18Data* _data18_;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 259 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 259 "../src/Widgets/Display.vala"
	_data18_ = g_slice_new0 (Block18Data);
#line 259 "../src/Widgets/Display.vala"
	_data18_->_ref_count_ = 1;
#line 259 "../src/Widgets/Display.vala"
	_data18_->self = g_object_ref (self);
#line 259 "../src/Widgets/Display.vala"
	_data18_->start_on_starred = start_on_starred;
#line 261 "../src/Widgets/Display.vala"
	if (self->priv->_active) {
#line 261 "../src/Widgets/Display.vala"
		_tmp0_ = !activate;
#line 1590 "Display.c"
	} else {
#line 261 "../src/Widgets/Display.vala"
		_tmp0_ = FALSE;
#line 1594 "Display.c"
	}
#line 261 "../src/Widgets/Display.vala"
	if (_tmp0_) {
#line 264 "../src/Widgets/Display.vala"
		self->priv->_active = FALSE;
#line 265 "../src/Widgets/Display.vala"
		block18_data_unref (_data18_);
#line 265 "../src/Widgets/Display.vala"
		_data18_ = NULL;
#line 265 "../src/Widgets/Display.vala"
		return;
#line 1606 "Display.c"
	}
#line 268 "../src/Widgets/Display.vala"
	if (!self->priv->_active) {
#line 268 "../src/Widgets/Display.vala"
		_tmp1_ = activate;
#line 1612 "Display.c"
	} else {
#line 268 "../src/Widgets/Display.vala"
		_tmp1_ = FALSE;
#line 1616 "Display.c"
	}
#line 268 "../src/Widgets/Display.vala"
	if (_tmp1_) {
#line 271 "../src/Widgets/Display.vala"
		if (self->priv->_first_activation) {
#line 274 "../src/Widgets/Display.vala"
			self->priv->_first_activation = FALSE;
#line 275 "../src/Widgets/Display.vala"
			tuner_display_initialize (self, _____lambda84__gasync_ready_callback, block18_data_ref (_data18_));
#line 1626 "Display.c"
		}
#line 280 "../src/Widgets/Display.vala"
		self->priv->_active = TRUE;
#line 281 "../src/Widgets/Display.vala"
		gtk_widget_show_all ((GtkWidget*) self);
#line 1632 "Display.c"
	}
#line 259 "../src/Widgets/Display.vala"
	block18_data_unref (_data18_);
#line 259 "../src/Widgets/Display.vala"
	_data18_ = NULL;
#line 1638 "Display.c"
}

/**
     * @brief Selects the starred stations view in the source list
     * 
     * Changes the current view to show the user's starred stations by selecting
     * the first child of the library category.
     */
void
tuner_display_choose_starred_stations (TunerDisplay* self)
{
	GraniteWidgetsSourceList* _tmp0_;
	GraniteWidgetsSourceList* _tmp1_;
	GraniteWidgetsSourceListExpandableItem* _tmp2_;
	GraniteWidgetsSourceListItem* _tmp3_;
	GraniteWidgetsSourceListItem* _tmp4_;
#line 292 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 294 "../src/Widgets/Display.vala"
	_tmp0_ = self->priv->_source_list;
#line 294 "../src/Widgets/Display.vala"
	_tmp1_ = self->priv->_source_list;
#line 294 "../src/Widgets/Display.vala"
	_tmp2_ = self->priv->_library_category;
#line 294 "../src/Widgets/Display.vala"
	_tmp3_ = granite_widgets_source_list_get_first_child (_tmp1_, _tmp2_);
#line 294 "../src/Widgets/Display.vala"
	_tmp4_ = _tmp3_;
#line 294 "../src/Widgets/Display.vala"
	granite_widgets_source_list_set_selected (_tmp0_, _tmp4_);
#line 294 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp4_);
#line 1671 "Display.c"
}

static void
tuner_display_initialize_data_free (gpointer _data)
{
	TunerDisplayInitializeData* _data_;
	_data_ = _data;
#line 31 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->self);
#line 31 "../src/Widgets/Display.vala"
	g_slice_free (TunerDisplayInitializeData, _data_);
#line 1683 "Display.c"
}

static void
tuner_display_initialize (TunerDisplay* self,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_)
{
	TunerDisplayInitializeData* _data_;
	TunerDisplay* _tmp0_;
#line 31 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 31 "../src/Widgets/Display.vala"
	_data_ = g_slice_new0 (TunerDisplayInitializeData);
#line 31 "../src/Widgets/Display.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 31 "../src/Widgets/Display.vala"
	g_task_set_task_data (_data_->_async_result, _data_, tuner_display_initialize_data_free);
#line 31 "../src/Widgets/Display.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 31 "../src/Widgets/Display.vala"
	_data_->self = _tmp0_;
#line 31 "../src/Widgets/Display.vala"
	tuner_display_initialize_co (_data_);
#line 1707 "Display.c"
}

static void
tuner_display_initialize_finish (TunerDisplay* self,
                                 GAsyncResult* _res_)
{
	TunerDisplayInitializeData* _data_;
#line 31 "../src/Widgets/Display.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 1717 "Display.c"
}

/**
    * @brief Asynchronously initializes the display components
    *
    * Sets up all categories, loads initial station data, and configures
    * signal handlers for various display components.
    */
static Block19Data*
block19_data_ref (Block19Data* _data19_)
{
#line 311 "../src/Widgets/Display.vala"
	g_atomic_int_inc (&_data19_->_ref_count_);
#line 311 "../src/Widgets/Display.vala"
	return _data19_;
#line 1733 "Display.c"
}

static void
block19_data_unref (void * _userdata_)
{
	Block19Data* _data19_;
	_data19_ = (Block19Data*) _userdata_;
#line 311 "../src/Widgets/Display.vala"
	if (g_atomic_int_dec_and_test (&_data19_->_ref_count_)) {
#line 1743 "Display.c"
		TunerDisplay* self;
#line 311 "../src/Widgets/Display.vala"
		self = _data19_->self;
#line 311 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data19_->starred);
#line 311 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data19_->discover);
#line 311 "../src/Widgets/Display.vala"
		_g_object_unref0 (self);
#line 311 "../src/Widgets/Display.vala"
		g_slice_free (Block19Data, _data19_);
#line 1755 "Display.c"
	}
}

static void
__lambda73_ (Block19Data* _data19_)
{
	TunerDisplay* self;
	TunerStationListBox* _tmp0_;
	TunerStationListItem* _tmp1_;
	TunerStationListItem* _tmp2_;
#line 332 "../src/Widgets/Display.vala"
	self = _data19_->self;
#line 333 "../src/Widgets/Display.vala"
	_tmp0_ = _data19_->discover;
#line 333 "../src/Widgets/Display.vala"
	_tmp1_ = tuner_station_list_box_get_item (_tmp0_);
#line 333 "../src/Widgets/Display.vala"
	_tmp2_ = _tmp1_;
#line 333 "../src/Widgets/Display.vala"
	tuner_station_list_item_populate (_tmp2_, (TunerStationListHookup*) self, TRUE);
#line 1776 "Display.c"
}

static void
___lambda73__tuner_station_list_box_action_button_activated_sig (TunerStationListBox* _sender,
                                                                 gpointer self)
{
#line 332 "../src/Widgets/Display.vala"
	__lambda73_ (self);
#line 1785 "Display.c"
}

static void
__lambda76_ (Block19Data* _data19_,
             guint item_count)
{
	TunerDisplay* self;
	TunerStationListBox* _tmp0_;
	TunerStationListBox* _tmp1_;
	guint _tmp2_;
	guint _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	TunerStationListBox* _tmp8_;
	TunerStationListBox* _tmp9_;
	guint _tmp10_;
	guint _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
#line 405 "../src/Widgets/Display.vala"
	self = _data19_->self;
#line 407 "../src/Widgets/Display.vala"
	_tmp0_ = _data19_->starred;
#line 407 "../src/Widgets/Display.vala"
	_tmp1_ = _data19_->starred;
#line 407 "../src/Widgets/Display.vala"
	_tmp2_ = tuner_station_list_box_get_item_count (_tmp1_);
#line 407 "../src/Widgets/Display.vala"
	_tmp3_ = _tmp2_;
#line 407 "../src/Widgets/Display.vala"
	_tmp4_ = g_strdup_printf ("%u", _tmp3_);
#line 407 "../src/Widgets/Display.vala"
	_tmp5_ = _tmp4_;
#line 407 "../src/Widgets/Display.vala"
	_tmp6_ = g_strconcat (_tmp5_, "\t", NULL);
#line 407 "../src/Widgets/Display.vala"
	_tmp7_ = _tmp6_;
#line 407 "../src/Widgets/Display.vala"
	tuner_station_list_box_badge (_tmp0_, _tmp7_);
#line 407 "../src/Widgets/Display.vala"
	_g_free0 (_tmp7_);
#line 407 "../src/Widgets/Display.vala"
	_g_free0 (_tmp5_);
#line 408 "../src/Widgets/Display.vala"
	_tmp8_ = _data19_->starred;
#line 408 "../src/Widgets/Display.vala"
	_tmp9_ = _data19_->starred;
#line 408 "../src/Widgets/Display.vala"
	_tmp10_ = tuner_station_list_box_get_item_count (_tmp9_);
#line 408 "../src/Widgets/Display.vala"
	_tmp11_ = _tmp10_;
#line 408 "../src/Widgets/Display.vala"
	_tmp12_ = g_strdup_printf ("%u", _tmp11_);
#line 408 "../src/Widgets/Display.vala"
	_tmp13_ = _tmp12_;
#line 408 "../src/Widgets/Display.vala"
	tuner_station_list_box_set_parameter (_tmp8_, _tmp13_);
#line 408 "../src/Widgets/Display.vala"
	_g_free0 (_tmp13_);
#line 1847 "Display.c"
}

static void
___lambda76__tuner_station_list_box_item_count_changed_sig (TunerStationListBox* _sender,
                                                            guint item_count,
                                                            const gchar* parameter,
                                                            gpointer self)
{
#line 405 "../src/Widgets/Display.vala"
	__lambda76_ (self, item_count);
#line 1858 "Display.c"
}

static void
__lambda77_ (TunerDisplay* self,
             guint item_count,
             const gchar* parameter)
{
	gboolean _tmp0_ = FALSE;
	gint _tmp1_;
	gint _tmp2_;
	TunerStationListBox* _tmp8_;
	GtkButton* _tmp9_;
	GtkButton* _tmp10_;
#line 434 "../src/Widgets/Display.vala"
	_tmp1_ = strlen (parameter);
#line 434 "../src/Widgets/Display.vala"
	_tmp2_ = _tmp1_;
#line 434 "../src/Widgets/Display.vala"
	if (_tmp2_ > 0) {
#line 1878 "Display.c"
		GtkStack* _tmp3_;
		GtkWidget* _tmp4_;
#line 434 "../src/Widgets/Display.vala"
		_tmp3_ = self->priv->_stack;
#line 434 "../src/Widgets/Display.vala"
		_tmp4_ = gtk_stack_get_child_by_name (_tmp3_, parameter);
#line 434 "../src/Widgets/Display.vala"
		_tmp0_ = _tmp4_ == NULL;
#line 1887 "Display.c"
	} else {
#line 434 "../src/Widgets/Display.vala"
		_tmp0_ = FALSE;
#line 1891 "Display.c"
	}
#line 434 "../src/Widgets/Display.vala"
	if (_tmp0_) {
#line 1895 "Display.c"
		TunerStationListBox* _tmp5_;
		GtkButton* _tmp6_;
		GtkButton* _tmp7_;
#line 436 "../src/Widgets/Display.vala"
		_tmp5_ = self->priv->_search_results;
#line 436 "../src/Widgets/Display.vala"
		_tmp6_ = tuner_station_list_box_get_tooltip_button (_tmp5_);
#line 436 "../src/Widgets/Display.vala"
		_tmp7_ = _tmp6_;
#line 436 "../src/Widgets/Display.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp7_, TRUE);
#line 437 "../src/Widgets/Display.vala"
		return;
#line 1909 "Display.c"
	}
#line 439 "../src/Widgets/Display.vala"
	_tmp8_ = self->priv->_search_results;
#line 439 "../src/Widgets/Display.vala"
	_tmp9_ = tuner_station_list_box_get_tooltip_button (_tmp8_);
#line 439 "../src/Widgets/Display.vala"
	_tmp10_ = _tmp9_;
#line 439 "../src/Widgets/Display.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, FALSE);
#line 1919 "Display.c"
}

static void
___lambda77__tuner_station_list_box_item_count_changed_sig (TunerStationListBox* _sender,
                                                            guint item_count,
                                                            const gchar* parameter,
                                                            gpointer self)
{
#line 432 "../src/Widgets/Display.vala"
	__lambda77_ ((TunerDisplay*) self, item_count, parameter);
#line 1930 "Display.c"
}

static void
__lambda78_ (TunerDisplay* self)
{
	TunerApplication* _tmp0_;
	TunerApplication* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	TunerStationListBox* _tmp5_;
	GtkButton* _tmp6_;
	GtkButton* _tmp7_;
	TunerStationListBox* new_saved_search = NULL;
	TunerStationListBox* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	TunerDirectoryController* _tmp11_;
	TunerStationListBox* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	TunerStationSet* _tmp15_;
	TunerStationSet* _tmp16_;
	TunerStationListBox* _tmp17_;
	TunerStationListBox* _tmp18_;
	TunerStationListBox* _tmp19_;
	TunerStationListBox* _tmp20_;
	TunerListFlowBox* _tmp21_;
	TunerListFlowBox* _tmp22_;
	GraniteWidgetsSourceList* _tmp23_;
	GraniteWidgetsSourceList* _tmp24_;
	GraniteWidgetsSourceListExpandableItem* _tmp25_;
	GraniteWidgetsSourceListItem* _tmp26_;
	GraniteWidgetsSourceListItem* _tmp27_;
#line 447 "../src/Widgets/Display.vala"
	_tmp0_ = tuner_app ();
#line 447 "../src/Widgets/Display.vala"
	_tmp1_ = _tmp0_;
#line 447 "../src/Widgets/Display.vala"
	_tmp2_ = tuner_application_get_is_offline (_tmp1_);
#line 447 "../src/Widgets/Display.vala"
	_tmp3_ = _tmp2_;
#line 447 "../src/Widgets/Display.vala"
	_tmp4_ = _tmp3_;
#line 447 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp1_);
#line 447 "../src/Widgets/Display.vala"
	if (_tmp4_) {
#line 448 "../src/Widgets/Display.vala"
		return;
#line 1981 "Display.c"
	}
#line 449 "../src/Widgets/Display.vala"
	_tmp5_ = self->priv->_search_results;
#line 449 "../src/Widgets/Display.vala"
	_tmp6_ = tuner_station_list_box_get_tooltip_button (_tmp5_);
#line 449 "../src/Widgets/Display.vala"
	_tmp7_ = _tmp6_;
#line 449 "../src/Widgets/Display.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp7_, FALSE);
#line 450 "../src/Widgets/Display.vala"
	_tmp8_ = self->priv->_search_results;
#line 450 "../src/Widgets/Display.vala"
	_tmp9_ = tuner_station_list_box_get_parameter (_tmp8_);
#line 450 "../src/Widgets/Display.vala"
	_tmp10_ = _tmp9_;
#line 450 "../src/Widgets/Display.vala"
	_tmp11_ = self->priv->_directory;
#line 450 "../src/Widgets/Display.vala"
	_tmp12_ = self->priv->_search_results;
#line 450 "../src/Widgets/Display.vala"
	_tmp13_ = tuner_station_list_box_get_parameter (_tmp12_);
#line 450 "../src/Widgets/Display.vala"
	_tmp14_ = _tmp13_;
#line 450 "../src/Widgets/Display.vala"
	_tmp15_ = tuner_directory_controller_add_saved_search (_tmp11_, _tmp14_);
#line 450 "../src/Widgets/Display.vala"
	_tmp16_ = _tmp15_;
#line 450 "../src/Widgets/Display.vala"
	_tmp17_ = tuner_display_add_saved_search (self, _tmp10_, _tmp16_);
#line 450 "../src/Widgets/Display.vala"
	_tmp18_ = _tmp17_;
#line 450 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp16_);
#line 450 "../src/Widgets/Display.vala"
	new_saved_search = _tmp18_;
#line 452 "../src/Widgets/Display.vala"
	_tmp19_ = new_saved_search;
#line 452 "../src/Widgets/Display.vala"
	_tmp20_ = self->priv->_search_results;
#line 452 "../src/Widgets/Display.vala"
	_tmp21_ = tuner_station_list_box_get_content (_tmp20_);
#line 452 "../src/Widgets/Display.vala"
	_tmp22_ = _tmp21_;
#line 452 "../src/Widgets/Display.vala"
	tuner_station_list_box_list (_tmp19_, _tmp22_);
#line 453 "../src/Widgets/Display.vala"
	_tmp23_ = self->priv->_source_list;
#line 453 "../src/Widgets/Display.vala"
	_tmp24_ = self->priv->_source_list;
#line 453 "../src/Widgets/Display.vala"
	_tmp25_ = self->priv->_saved_searches_category;
#line 453 "../src/Widgets/Display.vala"
	_tmp26_ = granite_widgets_source_list_get_last_child (_tmp24_, _tmp25_);
#line 453 "../src/Widgets/Display.vala"
	_tmp27_ = _tmp26_;
#line 453 "../src/Widgets/Display.vala"
	granite_widgets_source_list_set_selected (_tmp23_, _tmp27_);
#line 453 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp27_);
#line 444 "../src/Widgets/Display.vala"
	_g_object_unref0 (new_saved_search);
#line 2043 "Display.c"
}

static void
___lambda78__tuner_station_list_box_action_button_activated_sig (TunerStationListBox* _sender,
                                                                 gpointer self)
{
#line 444 "../src/Widgets/Display.vala"
	__lambda78_ ((TunerDisplay*) self);
#line 2052 "Display.c"
}

static void
__lambda80_ (Block19Data* _data19_,
             TunerModelStation* station)
{
	TunerDisplay* self;
	gboolean _tmp0_ = FALSE;
	TunerApplication* _tmp1_;
	TunerApplication* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	TunerStationList* _slist = NULL;
	TunerDirectoryController* _tmp11_;
	GeeCollection* _tmp12_;
	GeeCollection* _tmp13_;
	TunerStationList* _tmp14_;
	TunerStationList* _tmp15_;
	TunerStationList* _tmp16_;
	TunerStationListBox* _tmp17_;
	TunerStationList* _tmp18_;
	TunerStationListBox* _tmp19_;
	TunerStationListBox* _tmp20_;
	guint _tmp21_;
	guint _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	TunerStationListBox* _tmp25_;
#line 506 "../src/Widgets/Display.vala"
	self = _data19_->self;
#line 506 "../src/Widgets/Display.vala"
	g_return_if_fail (station != NULL);
#line 511 "../src/Widgets/Display.vala"
	_tmp1_ = tuner_app ();
#line 511 "../src/Widgets/Display.vala"
	_tmp2_ = _tmp1_;
#line 511 "../src/Widgets/Display.vala"
	_tmp3_ = tuner_application_get_is_offline (_tmp2_);
#line 511 "../src/Widgets/Display.vala"
	_tmp4_ = _tmp3_;
#line 511 "../src/Widgets/Display.vala"
	_tmp5_ = _tmp4_;
#line 511 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp2_);
#line 511 "../src/Widgets/Display.vala"
	if (_tmp5_) {
#line 2100 "Display.c"
		TunerDirectoryController* _tmp6_;
		GeeCollection* _tmp7_;
		GeeCollection* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
#line 511 "../src/Widgets/Display.vala"
		_tmp6_ = self->priv->_directory;
#line 511 "../src/Widgets/Display.vala"
		_tmp7_ = tuner_directory_controller_get_starred (_tmp6_);
#line 511 "../src/Widgets/Display.vala"
		_tmp8_ = _tmp7_;
#line 511 "../src/Widgets/Display.vala"
		_tmp9_ = gee_collection_get_size (_tmp8_);
#line 511 "../src/Widgets/Display.vala"
		_tmp10_ = _tmp9_;
#line 511 "../src/Widgets/Display.vala"
		_tmp0_ = _tmp10_ > 0;
#line 511 "../src/Widgets/Display.vala"
		_g_object_unref0 (_tmp8_);
#line 2120 "Display.c"
	} else {
#line 511 "../src/Widgets/Display.vala"
		_tmp0_ = FALSE;
#line 2124 "Display.c"
	}
#line 511 "../src/Widgets/Display.vala"
	if (_tmp0_) {
#line 512 "../src/Widgets/Display.vala"
		return;
#line 2130 "Display.c"
	}
#line 513 "../src/Widgets/Display.vala"
	_tmp11_ = self->priv->_directory;
#line 513 "../src/Widgets/Display.vala"
	_tmp12_ = tuner_directory_controller_get_starred (_tmp11_);
#line 513 "../src/Widgets/Display.vala"
	_tmp13_ = _tmp12_;
#line 513 "../src/Widgets/Display.vala"
	_tmp14_ = tuner_station_list_with_stations (_tmp13_);
#line 513 "../src/Widgets/Display.vala"
	_tmp15_ = _tmp14_;
#line 513 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp13_);
#line 513 "../src/Widgets/Display.vala"
	_slist = _tmp15_;
#line 514 "../src/Widgets/Display.vala"
	_tmp16_ = _slist;
#line 514 "../src/Widgets/Display.vala"
	tuner_station_list_hookup_station_list_hookup ((TunerStationListHookup*) self, _tmp16_);
#line 515 "../src/Widgets/Display.vala"
	_tmp17_ = _data19_->starred;
#line 515 "../src/Widgets/Display.vala"
	_tmp18_ = _slist;
#line 515 "../src/Widgets/Display.vala"
	tuner_station_list_box_set_content (_tmp17_, (TunerListFlowBox*) _tmp18_);
#line 516 "../src/Widgets/Display.vala"
	_tmp19_ = _data19_->starred;
#line 516 "../src/Widgets/Display.vala"
	_tmp20_ = _data19_->starred;
#line 516 "../src/Widgets/Display.vala"
	_tmp21_ = tuner_station_list_box_get_item_count (_tmp20_);
#line 516 "../src/Widgets/Display.vala"
	_tmp22_ = _tmp21_;
#line 516 "../src/Widgets/Display.vala"
	_tmp23_ = g_strdup_printf ("%u", _tmp22_);
#line 516 "../src/Widgets/Display.vala"
	_tmp24_ = _tmp23_;
#line 516 "../src/Widgets/Display.vala"
	tuner_station_list_box_set_parameter (_tmp19_, _tmp24_);
#line 516 "../src/Widgets/Display.vala"
	_g_free0 (_tmp24_);
#line 517 "../src/Widgets/Display.vala"
	_tmp25_ = _data19_->starred;
#line 517 "../src/Widgets/Display.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp25_);
#line 506 "../src/Widgets/Display.vala"
	_g_object_unref0 (_slist);
#line 2178 "Display.c"
}

static void
___lambda80__tuner_star_store_starred_stations_changed_sig (TunerStarStore* _sender,
                                                            TunerModelStation* station,
                                                            gpointer self)
{
#line 506 "../src/Widgets/Display.vala"
	__lambda80_ (self, station);
#line 2188 "Display.c"
}

static void
__lambda82_ (TunerDisplay* self)
{
	GtkStack* _tmp0_;
#line 524 "../src/Widgets/Display.vala"
	_tmp0_ = self->priv->_stack;
#line 524 "../src/Widgets/Display.vala"
	gtk_stack_set_visible_child_name (_tmp0_, "searched");
#line 2199 "Display.c"
}

static void
___lambda82__tuner_display_search_focused_sig (TunerDisplay* _sender,
                                               gpointer self)
{
#line 521 "../src/Widgets/Display.vala"
	__lambda82_ ((TunerDisplay*) self);
#line 2208 "Display.c"
}

static void
__lambda83_ (TunerDisplay* self,
             const gchar* text)
{
	TunerStationListBox* _tmp0_;
	GtkButton* _tmp1_;
	GtkButton* _tmp2_;
	TunerSearchController* _tmp3_;
#line 528 "../src/Widgets/Display.vala"
	g_return_if_fail (text != NULL);
#line 532 "../src/Widgets/Display.vala"
	_tmp0_ = self->priv->_search_results;
#line 532 "../src/Widgets/Display.vala"
	_tmp1_ = tuner_station_list_box_get_tooltip_button (_tmp0_);
#line 532 "../src/Widgets/Display.vala"
	_tmp2_ = _tmp1_;
#line 532 "../src/Widgets/Display.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 533 "../src/Widgets/Display.vala"
	_tmp3_ = self->priv->_search_controller;
#line 533 "../src/Widgets/Display.vala"
	tuner_search_controller_handle_search_for (_tmp3_, text);
#line 2233 "Display.c"
}

static void
___lambda83__tuner_display_searched_for_sig (TunerDisplay* _sender,
                                             const gchar* text,
                                             gpointer self)
{
#line 528 "../src/Widgets/Display.vala"
	__lambda83_ ((TunerDisplay*) self, text);
#line 2243 "Display.c"
}

static gboolean
tuner_display_initialize_co (TunerDisplayInitializeData* _data_)
{
#line 311 "../src/Widgets/Display.vala"
	switch (_data_->_state_) {
#line 311 "../src/Widgets/Display.vala"
		case 0:
#line 2253 "Display.c"
		goto _state_0;
		default:
#line 311 "../src/Widgets/Display.vala"
		g_assert_not_reached ();
#line 2258 "Display.c"
	}
	_state_0:
#line 311 "../src/Widgets/Display.vala"
	_data_->_data19_ = g_slice_new0 (Block19Data);
#line 311 "../src/Widgets/Display.vala"
	_data_->_data19_->_ref_count_ = 1;
#line 311 "../src/Widgets/Display.vala"
	_data_->_data19_->self = g_object_ref (_data_->self);
#line 311 "../src/Widgets/Display.vala"
	_data_->_data19_->_async_data_ = _data_;
#line 312 "../src/Widgets/Display.vala"
	_data_->_tmp0_ = _data_->self->priv->_directory;
#line 312 "../src/Widgets/Display.vala"
	tuner_directory_controller_load (_data_->_tmp0_);
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp1_ = _data_->self->priv->_stack;
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp2_ = _data_->self->priv->_source_list;
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp3_ = _data_->self->priv->_selections_category;
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp4_ = _data_->self->priv->_directory;
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp5_ = tuner_directory_controller_load_random_stations (_data_->_tmp4_, (guint) 20);
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp7_ = tuner_station_list_box_create (_data_->_tmp1_, _data_->_tmp2_, _data_->_tmp3_, "discover", "face-smile", _ ("Discover"), _ ("Stations to Discover"), FALSE, _data_->_tmp6_, _ ("Discover more stations"), "media-playlist-shuffle-symbolic");
#line 320 "../src/Widgets/Display.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 320 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 320 "../src/Widgets/Display.vala"
	_data_->_data19_->discover = _data_->_tmp8_;
#line 332 "../src/Widgets/Display.vala"
	_data_->_tmp9_ = _data_->_data19_->discover;
#line 332 "../src/Widgets/Display.vala"
	g_signal_connect_data (_data_->_tmp9_, "action-button-activated-sig", (GCallback) ___lambda73__tuner_station_list_box_action_button_activated_sig, block19_data_ref (_data_->_data19_), (GClosureNotify) block19_data_unref, 0);
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp10_ = _data_->self->priv->_stack;
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp11_ = _data_->self->priv->_source_list;
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp12_ = _data_->self->priv->_selections_category;
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp13_ = _data_->self->priv->_directory;
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp14_ = tuner_directory_controller_load_trending_stations (_data_->_tmp13_, (guint) 40);
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp16_ = tuner_station_list_box_create_category_specific (_data_->_tmp10_, _data_->_tmp11_, _data_->_tmp12_, "trending", "playlist-queue", _ ("Trending"), _ ("Trending Stations in the last 24 hours"), _data_->_tmp15_, NULL, NULL);
#line 340 "../src/Widgets/Display.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 340 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp17_);
#line 340 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp15_);
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp18_ = _data_->self->priv->_stack;
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp19_ = _data_->self->priv->_source_list;
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp20_ = _data_->self->priv->_selections_category;
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp21_ = _data_->self->priv->_directory;
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp22_ = tuner_directory_controller_load_popular_stations (_data_->_tmp21_, (guint) 40);
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp23_ = _data_->_tmp22_;
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp24_ = tuner_station_list_box_create_category_specific (_data_->_tmp18_, _data_->_tmp19_, _data_->_tmp20_, "popular", "playlist-similar", _ ("Popular"), _ ("Most listened to Stations in the last 24 hours"), _data_->_tmp23_, NULL, NULL);
#line 355 "../src/Widgets/Display.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 355 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp25_);
#line 355 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp23_);
#line 369 "../src/Widgets/Display.vala"
	_data_->_tmp26_ = _data_->self->priv->_selections_category;
#line 369 "../src/Widgets/Display.vala"
	tuner_display_jukebox (_data_->self, _data_->_tmp26_);
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp27_ = _data_->self->priv->_stack;
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp28_ = _data_->self->priv->_source_list;
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp29_ = _data_->self->priv->_library_category;
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp30_ = _data_->self->priv->_directory;
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp31_ = tuner_directory_controller_get_starred (_data_->_tmp30_);
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp33_ = tuner_station_list_box_create_category_predefined ((TunerStationListHookup*) _data_->self, _data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_, "starred", "starred", _ ("Starred by You"), _ ("Starred by You :"), _data_->_tmp32_);
#line 390 "../src/Widgets/Display.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 390 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp32_);
#line 390 "../src/Widgets/Display.vala"
	_data_->_data19_->starred = _data_->_tmp34_;
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp35_ = _data_->_data19_->starred;
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp36_ = _data_->_data19_->starred;
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp37_ = tuner_station_list_box_get_item_count (_data_->_tmp36_);
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp39_ = g_strdup_printf ("%u", _data_->_tmp38_);
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp40_ = _data_->_tmp39_;
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp41_ = g_strconcat (_data_->_tmp40_, "\t", NULL);
#line 402 "../src/Widgets/Display.vala"
	_data_->_tmp42_ = _data_->_tmp41_;
#line 402 "../src/Widgets/Display.vala"
	tuner_station_list_box_badge (_data_->_tmp35_, _data_->_tmp42_);
#line 402 "../src/Widgets/Display.vala"
	_g_free0 (_data_->_tmp42_);
#line 402 "../src/Widgets/Display.vala"
	_g_free0 (_data_->_tmp40_);
#line 403 "../src/Widgets/Display.vala"
	_data_->_tmp43_ = _data_->_data19_->starred;
#line 403 "../src/Widgets/Display.vala"
	_data_->_tmp44_ = _data_->_data19_->starred;
#line 403 "../src/Widgets/Display.vala"
	_data_->_tmp45_ = tuner_station_list_box_get_item_count (_data_->_tmp44_);
#line 403 "../src/Widgets/Display.vala"
	_data_->_tmp46_ = _data_->_tmp45_;
#line 403 "../src/Widgets/Display.vala"
	_data_->_tmp47_ = g_strdup_printf ("%u", _data_->_tmp46_);
#line 403 "../src/Widgets/Display.vala"
	_data_->_tmp48_ = _data_->_tmp47_;
#line 403 "../src/Widgets/Display.vala"
	tuner_station_list_box_set_parameter (_data_->_tmp43_, _data_->_tmp48_);
#line 403 "../src/Widgets/Display.vala"
	_g_free0 (_data_->_tmp48_);
#line 405 "../src/Widgets/Display.vala"
	_data_->_tmp49_ = _data_->_data19_->starred;
#line 405 "../src/Widgets/Display.vala"
	g_signal_connect_data (_data_->_tmp49_, "item-count-changed-sig", (GCallback) ___lambda76__tuner_station_list_box_item_count_changed_sig, block19_data_ref (_data_->_data19_), (GClosureNotify) block19_data_unref, 0);
#line 416 "../src/Widgets/Display.vala"
	_data_->_tmp50_ = _data_->self->priv->_stack;
#line 416 "../src/Widgets/Display.vala"
	_data_->_tmp51_ = _data_->self->priv->_source_list;
#line 416 "../src/Widgets/Display.vala"
	_data_->_tmp52_ = _data_->self->priv->_library_category;
#line 416 "../src/Widgets/Display.vala"
	_data_->_tmp53_ = tuner_station_list_box_create (_data_->_tmp50_, _data_->_tmp51_, _data_->_tmp52_, "searched", "folder-saved-search", _ ("Recent Search"), _ ("Search Results"), FALSE, NULL, _ ("Save this search"), "non-starred-symbolic");
#line 416 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->self->priv->_search_results);
#line 416 "../src/Widgets/Display.vala"
	_data_->self->priv->_search_results = _data_->_tmp53_;
#line 429 "../src/Widgets/Display.vala"
	_data_->_tmp54_ = _data_->self->priv->_search_results;
#line 429 "../src/Widgets/Display.vala"
	_data_->_tmp55_ = tuner_station_list_box_get_tooltip_button (_data_->_tmp54_);
#line 429 "../src/Widgets/Display.vala"
	_data_->_tmp56_ = _data_->_tmp55_;
#line 429 "../src/Widgets/Display.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp56_, FALSE);
#line 430 "../src/Widgets/Display.vala"
	_data_->_tmp57_ = _data_->self->priv->_directory;
#line 430 "../src/Widgets/Display.vala"
	_data_->_tmp58_ = _data_->self->priv->_search_results;
#line 430 "../src/Widgets/Display.vala"
	_data_->_tmp59_ = tuner_search_controller_new (_data_->_tmp57_, (TunerStationListHookup*) _data_->self, _data_->_tmp58_, (guint) 100);
#line 430 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->self->priv->_search_controller);
#line 430 "../src/Widgets/Display.vala"
	_data_->self->priv->_search_controller = _data_->_tmp59_;
#line 432 "../src/Widgets/Display.vala"
	_data_->_tmp60_ = _data_->self->priv->_search_results;
#line 432 "../src/Widgets/Display.vala"
	g_signal_connect_object (_data_->_tmp60_, "item-count-changed-sig", (GCallback) ___lambda77__tuner_station_list_box_item_count_changed_sig, _data_->self, 0);
#line 444 "../src/Widgets/Display.vala"
	_data_->_tmp61_ = _data_->self->priv->_search_results;
#line 444 "../src/Widgets/Display.vala"
	g_signal_connect_object (_data_->_tmp61_, "action-button-activated-sig", (GCallback) ___lambda78__tuner_station_list_box_action_button_activated_sig, _data_->self, 0);
#line 462 "../src/Widgets/Display.vala"
	_data_->_tmp62_ = _data_->self->priv->_directory;
#line 462 "../src/Widgets/Display.vala"
	_data_->_tmp63_ = tuner_directory_controller_load_saved_searches (_data_->_tmp62_);
#line 462 "../src/Widgets/Display.vala"
	_data_->saved_searches = _data_->_tmp63_;
#line 2447 "Display.c"
	{
#line 463 "../src/Widgets/Display.vala"
		_data_->_tmp64_ = _data_->saved_searches;
#line 463 "../src/Widgets/Display.vala"
		_data_->_tmp65_ = gee_map_get_keys (_data_->_tmp64_);
#line 463 "../src/Widgets/Display.vala"
		_data_->_tmp66_ = _data_->_tmp65_;
#line 463 "../src/Widgets/Display.vala"
		_data_->_tmp67_ = _data_->_tmp66_;
#line 463 "../src/Widgets/Display.vala"
		_data_->_tmp68_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp67_);
#line 463 "../src/Widgets/Display.vala"
		_data_->_tmp69_ = _data_->_tmp68_;
#line 463 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data_->_tmp67_);
#line 463 "../src/Widgets/Display.vala"
		_data_->_search_term_it = _data_->_tmp69_;
#line 463 "../src/Widgets/Display.vala"
		while (TRUE) {
#line 463 "../src/Widgets/Display.vala"
			_data_->_tmp70_ = _data_->_search_term_it;
#line 463 "../src/Widgets/Display.vala"
			if (!gee_iterator_next (_data_->_tmp70_)) {
#line 463 "../src/Widgets/Display.vala"
				break;
#line 2473 "Display.c"
			}
#line 463 "../src/Widgets/Display.vala"
			_data_->_tmp71_ = _data_->_search_term_it;
#line 463 "../src/Widgets/Display.vala"
			_data_->_tmp72_ = gee_iterator_get (_data_->_tmp71_);
#line 463 "../src/Widgets/Display.vala"
			_data_->search_term = (gchar*) _data_->_tmp72_;
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp73_ = _data_->search_term;
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp74_ = _data_->saved_searches;
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp75_ = _data_->search_term;
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp76_ = gee_map_get (_data_->_tmp74_, _data_->_tmp75_);
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp77_ = (TunerStationSet*) _data_->_tmp76_;
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp78_ = tuner_display_add_saved_search (_data_->self, _data_->_tmp73_, _data_->_tmp77_);
#line 465 "../src/Widgets/Display.vala"
			_data_->_tmp79_ = _data_->_tmp78_;
#line 465 "../src/Widgets/Display.vala"
			_g_object_unref0 (_data_->_tmp79_);
#line 465 "../src/Widgets/Display.vala"
			_g_object_unref0 (_data_->_tmp77_);
#line 463 "../src/Widgets/Display.vala"
			_g_free0 (_data_->search_term);
#line 2501 "Display.c"
		}
#line 463 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data_->_search_term_it);
#line 2505 "Display.c"
	}
#line 467 "../src/Widgets/Display.vala"
	_data_->_tmp80_ = _data_->self->priv->_saved_searches_category;
#line 467 "../src/Widgets/Display.vala"
	_data_->_tmp81_ = (GThemedIcon*) g_themed_icon_new ("library-music");
#line 467 "../src/Widgets/Display.vala"
	_data_->_tmp82_ = _data_->_tmp81_;
#line 467 "../src/Widgets/Display.vala"
	granite_widgets_source_list_item_set_icon ((GraniteWidgetsSourceListItem*) _data_->_tmp80_, (GIcon*) _data_->_tmp82_);
#line 467 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp82_);
#line 468 "../src/Widgets/Display.vala"
	_data_->_tmp83_ = _data_->self->priv->_library_category;
#line 468 "../src/Widgets/Display.vala"
	_data_->_tmp84_ = _data_->self->priv->_saved_searches_category;
#line 468 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (_data_->_tmp83_, (GraniteWidgetsSourceListItem*) _data_->_tmp84_);
#line 474 "../src/Widgets/Display.vala"
	_data_->_tmp85_ = tuner_app ();
#line 474 "../src/Widgets/Display.vala"
	_data_->_tmp86_ = _data_->_tmp85_;
#line 474 "../src/Widgets/Display.vala"
	_data_->_tmp87_ = tuner_application_get_is_online (_data_->_tmp86_);
#line 474 "../src/Widgets/Display.vala"
	_data_->_tmp88_ = _data_->_tmp87_;
#line 474 "../src/Widgets/Display.vala"
	_data_->_tmp89_ = _data_->_tmp88_;
#line 474 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp86_);
#line 474 "../src/Widgets/Display.vala"
	if (_data_->_tmp89_) {
#line 476 "../src/Widgets/Display.vala"
		_data_->explore = (guint) 0;
#line 2539 "Display.c"
		{
#line 477 "../src/Widgets/Display.vala"
			_data_->_tmp90_ = _data_->self->priv->_directory;
#line 477 "../src/Widgets/Display.vala"
			_data_->_tmp91_ = tuner_directory_controller_load_random_genres (_data_->_tmp90_, TUNER_DISPLAY_EXPLORE_CATEGORIES);
#line 477 "../src/Widgets/Display.vala"
			_data_->_tmp92_ = _data_->_tmp91_;
#line 477 "../src/Widgets/Display.vala"
			_data_->_tmp93_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp92_);
#line 477 "../src/Widgets/Display.vala"
			_data_->_tmp94_ = _data_->_tmp93_;
#line 477 "../src/Widgets/Display.vala"
			_g_object_unref0 (_data_->_tmp92_);
#line 477 "../src/Widgets/Display.vala"
			_data_->_tag_it = _data_->_tmp94_;
#line 477 "../src/Widgets/Display.vala"
			while (TRUE) {
#line 477 "../src/Widgets/Display.vala"
				_data_->_tmp95_ = _data_->_tag_it;
#line 477 "../src/Widgets/Display.vala"
				if (!gee_iterator_next (_data_->_tmp95_)) {
#line 477 "../src/Widgets/Display.vala"
					break;
#line 2563 "Display.c"
				}
#line 477 "../src/Widgets/Display.vala"
				_data_->_tmp96_ = _data_->_tag_it;
#line 477 "../src/Widgets/Display.vala"
				_data_->_tmp97_ = gee_iterator_get (_data_->_tmp96_);
#line 477 "../src/Widgets/Display.vala"
				_data_->tag = (TunerDataProviderTag*) _data_->_tmp97_;
#line 479 "../src/Widgets/Display.vala"
				_data_->_tmp98_ = _data_->tag;
#line 479 "../src/Widgets/Display.vala"
				_data_->_tmp99_ = tuner_data_provider_tag_get_name (_data_->_tmp98_);
#line 479 "../src/Widgets/Display.vala"
				_data_->_tmp100_ = _data_->_tmp99_;
#line 479 "../src/Widgets/Display.vala"
				if (tuner_model_genre_in_genre (_data_->_tmp100_)) {
#line 479 "../src/Widgets/Display.vala"
					_g_object_unref0 (_data_->tag);
#line 479 "../src/Widgets/Display.vala"
					break;
#line 2583 "Display.c"
				}
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp101_ = _data_->self->priv->_stack;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp102_ = _data_->self->priv->_source_list;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp103_ = _data_->self->priv->_explore_category;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp104_ = _data_->explore;
#line 480 "../src/Widgets/Display.vala"
				_data_->explore = _data_->_tmp104_ + 1;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp105_ = g_strdup_printf ("%u", _data_->_tmp104_);
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp106_ = _data_->_tmp105_;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp107_ = _data_->tag;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp108_ = tuner_data_provider_tag_get_name (_data_->_tmp107_);
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp109_ = _data_->_tmp108_;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp110_ = _data_->tag;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp111_ = tuner_data_provider_tag_get_name (_data_->_tmp110_);
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp112_ = _data_->_tmp111_;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp113_ = _data_->self->priv->_directory;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp114_ = _data_->tag;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp115_ = tuner_data_provider_tag_get_name (_data_->_tmp114_);
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp116_ = _data_->_tmp115_;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp117_ = tuner_directory_controller_load_by_tag (_data_->_tmp113_, _data_->_tmp116_);
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp118_ = _data_->_tmp117_;
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp119_ = tuner_station_list_box_create_category_specific (_data_->_tmp101_, _data_->_tmp102_, _data_->_tmp103_, _data_->_tmp106_, "playlist-symbolic", _data_->_tmp109_, _data_->_tmp112_, _data_->_tmp118_, NULL, NULL);
#line 480 "../src/Widgets/Display.vala"
				_data_->_tmp120_ = _data_->_tmp119_;
#line 480 "../src/Widgets/Display.vala"
				_g_object_unref0 (_data_->_tmp120_);
#line 480 "../src/Widgets/Display.vala"
				_g_object_unref0 (_data_->_tmp118_);
#line 480 "../src/Widgets/Display.vala"
				_g_free0 (_data_->_tmp106_);
#line 477 "../src/Widgets/Display.vala"
				_g_object_unref0 (_data_->tag);
#line 2635 "Display.c"
			}
#line 477 "../src/Widgets/Display.vala"
			_g_object_unref0 (_data_->_tag_it);
#line 2639 "Display.c"
		}
	}
#line 492 "../src/Widgets/Display.vala"
	_data_->_tmp121_ = _data_->self->priv->_stack;
#line 492 "../src/Widgets/Display.vala"
	_data_->_tmp122_ = _data_->self->priv->_source_list;
#line 492 "../src/Widgets/Display.vala"
	_data_->_tmp123_ = _data_->self->priv->_genres_category;
#line 492 "../src/Widgets/Display.vala"
	_data_->_tmp124_ = _data_->self->priv->_directory;
#line 492 "../src/Widgets/Display.vala"
	tuner_display_create_category_genre (_data_->self, _data_->_tmp121_, _data_->_tmp122_, _data_->_tmp123_, _data_->_tmp124_, TUNER_MODEL_GENRE_GENRES, (gint) G_N_ELEMENTS (TUNER_MODEL_GENRE_GENRES));
#line 495 "../src/Widgets/Display.vala"
	_data_->_tmp125_ = _data_->self->priv->_stack;
#line 495 "../src/Widgets/Display.vala"
	_data_->_tmp126_ = _data_->self->priv->_source_list;
#line 495 "../src/Widgets/Display.vala"
	_data_->_tmp127_ = _data_->self->priv->_subgenres_category;
#line 495 "../src/Widgets/Display.vala"
	_data_->_tmp128_ = _data_->self->priv->_directory;
#line 495 "../src/Widgets/Display.vala"
	tuner_display_create_category_genre (_data_->self, _data_->_tmp125_, _data_->_tmp126_, _data_->_tmp127_, _data_->_tmp128_, TUNER_MODEL_GENRE_SUBGENRES, (gint) G_N_ELEMENTS (TUNER_MODEL_GENRE_SUBGENRES));
#line 498 "../src/Widgets/Display.vala"
	_data_->_tmp129_ = _data_->self->priv->_stack;
#line 498 "../src/Widgets/Display.vala"
	_data_->_tmp130_ = _data_->self->priv->_source_list;
#line 498 "../src/Widgets/Display.vala"
	_data_->_tmp131_ = _data_->self->priv->_eras_category;
#line 498 "../src/Widgets/Display.vala"
	_data_->_tmp132_ = _data_->self->priv->_directory;
#line 498 "../src/Widgets/Display.vala"
	tuner_display_create_category_genre (_data_->self, _data_->_tmp129_, _data_->_tmp130_, _data_->_tmp131_, _data_->_tmp132_, TUNER_MODEL_GENRE_ERAS, (gint) G_N_ELEMENTS (TUNER_MODEL_GENRE_ERAS));
#line 501 "../src/Widgets/Display.vala"
	_data_->_tmp133_ = _data_->self->priv->_stack;
#line 501 "../src/Widgets/Display.vala"
	_data_->_tmp134_ = _data_->self->priv->_source_list;
#line 501 "../src/Widgets/Display.vala"
	_data_->_tmp135_ = _data_->self->priv->_talk_category;
#line 501 "../src/Widgets/Display.vala"
	_data_->_tmp136_ = _data_->self->priv->_directory;
#line 501 "../src/Widgets/Display.vala"
	tuner_display_create_category_genre (_data_->self, _data_->_tmp133_, _data_->_tmp134_, _data_->_tmp135_, _data_->_tmp136_, TUNER_MODEL_GENRE_TALK, (gint) G_N_ELEMENTS (TUNER_MODEL_GENRE_TALK));
#line 506 "../src/Widgets/Display.vala"
	_data_->_tmp137_ = tuner_app ();
#line 506 "../src/Widgets/Display.vala"
	_data_->_tmp138_ = _data_->_tmp137_;
#line 506 "../src/Widgets/Display.vala"
	_data_->_tmp139_ = tuner_application_get_stars (_data_->_tmp138_);
#line 506 "../src/Widgets/Display.vala"
	_data_->_tmp140_ = _data_->_tmp139_;
#line 506 "../src/Widgets/Display.vala"
	g_signal_connect_data (_data_->_tmp140_, "starred-stations-changed-sig", (GCallback) ___lambda80__tuner_star_store_starred_stations_changed_sig, block19_data_ref (_data_->_data19_), (GClosureNotify) block19_data_unref, 0);
#line 506 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp138_);
#line 521 "../src/Widgets/Display.vala"
	g_signal_connect_object (_data_->self, "search-focused-sig", (GCallback) ___lambda82__tuner_display_search_focused_sig, _data_->self, 0);
#line 528 "../src/Widgets/Display.vala"
	g_signal_connect_object (_data_->self, "searched-for-sig", (GCallback) ___lambda83__tuner_display_searched_for_sig, _data_->self, 0);
#line 536 "../src/Widgets/Display.vala"
	_data_->_tmp141_ = _data_->self->priv->_source_list;
#line 536 "../src/Widgets/Display.vala"
	_data_->_tmp142_ = _data_->self->priv->_source_list;
#line 536 "../src/Widgets/Display.vala"
	_data_->_tmp143_ = _data_->self->priv->_selections_category;
#line 536 "../src/Widgets/Display.vala"
	_data_->_tmp144_ = granite_widgets_source_list_get_first_child (_data_->_tmp142_, _data_->_tmp143_);
#line 536 "../src/Widgets/Display.vala"
	_data_->_tmp145_ = _data_->_tmp144_;
#line 536 "../src/Widgets/Display.vala"
	granite_widgets_source_list_set_selected (_data_->_tmp141_, _data_->_tmp145_);
#line 536 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->_tmp145_);
#line 538 "../src/Widgets/Display.vala"
	gtk_widget_show ((GtkWidget*) _data_->self);
#line 311 "../src/Widgets/Display.vala"
	_g_object_unref0 (_data_->saved_searches);
#line 311 "../src/Widgets/Display.vala"
	block19_data_unref (_data_->_data19_);
#line 311 "../src/Widgets/Display.vala"
	_data_->_data19_ = NULL;
#line 311 "../src/Widgets/Display.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 311 "../src/Widgets/Display.vala"
	if (_data_->_state_ != 0) {
#line 311 "../src/Widgets/Display.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 311 "../src/Widgets/Display.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2728 "Display.c"
		}
	}
#line 311 "../src/Widgets/Display.vala"
	g_object_unref (_data_->_async_result);
#line 311 "../src/Widgets/Display.vala"
	return FALSE;
#line 2735 "Display.c"
}

/**
     * @brief Configures the jukebox mode for a category.
     * @param category The category to configure.
     */
static void
__lambda74_ (TunerDisplay* self)
{
	TunerApplication* _tmp0_;
	TunerApplication* _tmp1_;
	GtkRevealer* _tmp2_;
	GtkRevealer* _tmp3_;
#line 562 "../src/Widgets/Display.vala"
	self->priv->_shuffle = TRUE;
#line 563 "../src/Widgets/Display.vala"
	tuner_display_jukebox_shuffle (self, NULL, NULL);
#line 564 "../src/Widgets/Display.vala"
	_tmp0_ = tuner_app ();
#line 564 "../src/Widgets/Display.vala"
	_tmp1_ = _tmp0_;
#line 564 "../src/Widgets/Display.vala"
	g_signal_emit_by_name (_tmp1_, "shuffle-mode-sig", TRUE);
#line 564 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp1_);
#line 565 "../src/Widgets/Display.vala"
	_tmp2_ = self->priv->_background_tuner;
#line 565 "../src/Widgets/Display.vala"
	gtk_revealer_set_reveal_child (_tmp2_, FALSE);
#line 566 "../src/Widgets/Display.vala"
	_tmp3_ = self->priv->_background_jukebox;
#line 566 "../src/Widgets/Display.vala"
	gtk_revealer_set_reveal_child (_tmp3_, TRUE);
#line 2769 "Display.c"
}

static void
___lambda74__granite_widgets_source_list_item_activated (GraniteWidgetsSourceListItem* _sender,
                                                         gpointer self)
{
#line 560 "../src/Widgets/Display.vala"
	__lambda74_ ((TunerDisplay*) self);
#line 2778 "Display.c"
}

static void
__lambda75_ (TunerDisplay* self,
             TunerModelStation* oldstation)
{
#line 569 "../src/Widgets/Display.vala"
	g_return_if_fail (oldstation != NULL);
#line 571 "../src/Widgets/Display.vala"
	if (self->priv->_shuffle) {
#line 572 "../src/Widgets/Display.vala"
		tuner_display_jukebox_shuffle (self, NULL, NULL);
#line 2791 "Display.c"
	}
}

static void
___lambda75__tuner_player_controller_tape_counter_sig (TunerPlayerController* _sender,
                                                       TunerModelStation* station,
                                                       gpointer self)
{
#line 569 "../src/Widgets/Display.vala"
	__lambda75_ ((TunerDisplay*) self, station);
#line 2802 "Display.c"
}

static void
tuner_display_jukebox (TunerDisplay* self,
                       GraniteWidgetsSourceListExpandableItem* category)
{
	GraniteWidgetsSourceListItem* item = NULL;
	GraniteWidgetsSourceListItem* _tmp0_;
	GThemedIcon* _tmp1_;
	GThemedIcon* _tmp2_;
	TunerApplication* _tmp3_;
	TunerApplication* _tmp4_;
	TunerDataProviderAPI* _tmp5_;
	TunerDataProviderAPI* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	TunerApplication* _tmp9_;
	TunerApplication* _tmp10_;
	TunerDataProviderAPI* _tmp11_;
	TunerDataProviderAPI* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	TunerApplication* _tmp17_;
	TunerApplication* _tmp18_;
	TunerPlayerController* _tmp19_;
	TunerPlayerController* _tmp20_;
#line 555 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 555 "../src/Widgets/Display.vala"
	g_return_if_fail (category != NULL);
#line 557 "../src/Widgets/Display.vala"
	_tmp0_ = granite_widgets_source_list_item_new (_ ("Jukebox"));
#line 557 "../src/Widgets/Display.vala"
	item = _tmp0_;
#line 558 "../src/Widgets/Display.vala"
	_tmp1_ = (GThemedIcon*) g_themed_icon_new ("jukebox");
#line 558 "../src/Widgets/Display.vala"
	_tmp2_ = _tmp1_;
#line 558 "../src/Widgets/Display.vala"
	granite_widgets_source_list_item_set_icon (item, (GIcon*) _tmp2_);
#line 558 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp2_);
#line 559 "../src/Widgets/Display.vala"
	_tmp3_ = tuner_app ();
#line 559 "../src/Widgets/Display.vala"
	_tmp4_ = _tmp3_;
#line 559 "../src/Widgets/Display.vala"
	_tmp5_ = tuner_application_get_provider (_tmp4_);
#line 559 "../src/Widgets/Display.vala"
	_tmp6_ = _tmp5_;
#line 559 "../src/Widgets/Display.vala"
	_tmp7_ = g_strdup_printf ("%i", tuner_data_provider_api_available_stations (_tmp6_));
#line 559 "../src/Widgets/Display.vala"
	_tmp8_ = _tmp7_;
#line 559 "../src/Widgets/Display.vala"
	_tmp9_ = tuner_app ();
#line 559 "../src/Widgets/Display.vala"
	_tmp10_ = _tmp9_;
#line 559 "../src/Widgets/Display.vala"
	_tmp11_ = tuner_application_get_provider (_tmp10_);
#line 559 "../src/Widgets/Display.vala"
	_tmp12_ = _tmp11_;
#line 559 "../src/Widgets/Display.vala"
	_tmp13_ = g_strdup_printf ("%i", tuner_data_provider_api_available_stations (_tmp12_) / (6 * 24));
#line 559 "../src/Widgets/Display.vala"
	_tmp14_ = _tmp13_;
#line 559 "../src/Widgets/Display.vala"
	_tmp15_ = g_strconcat ("Double click to shuffle through ", _tmp8_, " stations,\none, every ten minutes, for ", _tmp14_, " days", NULL);
#line 559 "../src/Widgets/Display.vala"
	_tmp16_ = _tmp15_;
#line 559 "../src/Widgets/Display.vala"
	granite_widgets_source_list_item_set_tooltip (item, _ (_tmp16_));
#line 559 "../src/Widgets/Display.vala"
	_g_free0 (_tmp16_);
#line 559 "../src/Widgets/Display.vala"
	_g_free0 (_tmp14_);
#line 559 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp10_);
#line 559 "../src/Widgets/Display.vala"
	_g_free0 (_tmp8_);
#line 559 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp4_);
#line 560 "../src/Widgets/Display.vala"
	g_signal_connect_object (item, "activated", (GCallback) ___lambda74__granite_widgets_source_list_item_activated, self, 0);
#line 569 "../src/Widgets/Display.vala"
	_tmp17_ = tuner_app ();
#line 569 "../src/Widgets/Display.vala"
	_tmp18_ = _tmp17_;
#line 569 "../src/Widgets/Display.vala"
	_tmp19_ = tuner_application_get_player (_tmp18_);
#line 569 "../src/Widgets/Display.vala"
	_tmp20_ = _tmp19_;
#line 569 "../src/Widgets/Display.vala"
	g_signal_connect_object (_tmp20_, "tape-counter-sig", (GCallback) ___lambda75__tuner_player_controller_tape_counter_sig, self, 0);
#line 569 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp18_);
#line 574 "../src/Widgets/Display.vala"
	granite_widgets_source_list_expandable_item_add (category, item);
#line 555 "../src/Widgets/Display.vala"
	_g_object_unref0 (item);
#line 2905 "Display.c"
}

/**
    * @brief Hooks up signals for a StationList.
    * @param station_list The StationList to hook up.
    *
    * Configures signal handlers for station clicks and favorites changes.
    */
static void
__lambda81_ (TunerDisplay* self,
             TunerModelStation* station)
{
#line 586 "../src/Widgets/Display.vala"
	g_return_if_fail (station != NULL);
#line 588 "../src/Widgets/Display.vala"
	g_signal_emit (self, tuner_display_signals[TUNER_DISPLAY_STATION_CLICKED_SIG_SIGNAL], 0, station);
#line 589 "../src/Widgets/Display.vala"
	if (self->priv->_shuffle) {
#line 2924 "Display.c"
		TunerApplication* _tmp0_;
		TunerApplication* _tmp1_;
		GtkRevealer* _tmp2_;
		GtkRevealer* _tmp3_;
#line 591 "../src/Widgets/Display.vala"
		self->priv->_shuffle = FALSE;
#line 592 "../src/Widgets/Display.vala"
		_tmp0_ = tuner_app ();
#line 592 "../src/Widgets/Display.vala"
		_tmp1_ = _tmp0_;
#line 592 "../src/Widgets/Display.vala"
		g_signal_emit_by_name (_tmp1_, "shuffle-mode-sig", FALSE);
#line 592 "../src/Widgets/Display.vala"
		_g_object_unref0 (_tmp1_);
#line 593 "../src/Widgets/Display.vala"
		_tmp2_ = self->priv->_background_jukebox;
#line 593 "../src/Widgets/Display.vala"
		gtk_revealer_set_reveal_child (_tmp2_, FALSE);
#line 594 "../src/Widgets/Display.vala"
		_tmp3_ = self->priv->_background_tuner;
#line 594 "../src/Widgets/Display.vala"
		gtk_revealer_set_reveal_child (_tmp3_, TRUE);
#line 2947 "Display.c"
	}
}

static void
___lambda81__tuner_station_list_station_clicked_sig (TunerStationList* _sender,
                                                     TunerModelStation* station,
                                                     gpointer self)
{
#line 586 "../src/Widgets/Display.vala"
	__lambda81_ ((TunerDisplay*) self, station);
#line 2958 "Display.c"
}

static void
tuner_display_real_station_list_hookup (TunerStationListHookup* base,
                                        TunerStationList* station_list)
{
	TunerDisplay * self;
#line 584 "../src/Widgets/Display.vala"
	self = (TunerDisplay*) base;
#line 584 "../src/Widgets/Display.vala"
	g_return_if_fail (station_list != NULL);
#line 586 "../src/Widgets/Display.vala"
	g_signal_connect_object (station_list, "station-clicked-sig", (GCallback) ___lambda81__tuner_station_list_station_clicked_sig, self, 0);
#line 2972 "Display.c"
}

/**
     * Adds a saved search to the display with the specified search term and station set.
     * 
     * @param search      The search term to be saved
     * @param station_set The set of stations to associate with this search
     * @param content    Optional station list to be used as content. If null, a new list will be created
     * 
     * @return Returns a StationListBox widget containing the search results
     */
static Block20Data*
block20_data_ref (Block20Data* _data20_)
{
#line 610 "../src/Widgets/Display.vala"
	g_atomic_int_inc (&_data20_->_ref_count_);
#line 610 "../src/Widgets/Display.vala"
	return _data20_;
#line 2991 "Display.c"
}

static void
block20_data_unref (void * _userdata_)
{
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
#line 610 "../src/Widgets/Display.vala"
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
#line 3001 "Display.c"
		TunerDisplay* self;
#line 610 "../src/Widgets/Display.vala"
		self = _data20_->self;
#line 610 "../src/Widgets/Display.vala"
		_g_object_unref0 (_data20_->saved_search);
#line 610 "../src/Widgets/Display.vala"
		_g_free0 (_data20_->search);
#line 610 "../src/Widgets/Display.vala"
		_g_object_unref0 (self);
#line 610 "../src/Widgets/Display.vala"
		g_slice_free (Block20Data, _data20_);
#line 3013 "Display.c"
	}
}

static void
__lambda79_ (Block20Data* _data20_)
{
	TunerDisplay* self;
	TunerApplication* _tmp0_;
	TunerApplication* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	TunerDirectoryController* _tmp5_;
	TunerStationListBox* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
#line 629 "../src/Widgets/Display.vala"
	self = _data20_->self;
#line 630 "../src/Widgets/Display.vala"
	_tmp0_ = tuner_app ();
#line 630 "../src/Widgets/Display.vala"
	_tmp1_ = _tmp0_;
#line 630 "../src/Widgets/Display.vala"
	_tmp2_ = tuner_application_get_is_offline (_tmp1_);
#line 630 "../src/Widgets/Display.vala"
	_tmp3_ = _tmp2_;
#line 630 "../src/Widgets/Display.vala"
	_tmp4_ = _tmp3_;
#line 630 "../src/Widgets/Display.vala"
	_g_object_unref0 (_tmp1_);
#line 630 "../src/Widgets/Display.vala"
	if (_tmp4_) {
#line 630 "../src/Widgets/Display.vala"
		return;
#line 3048 "Display.c"
	}
#line 631 "../src/Widgets/Display.vala"
	_tmp5_ = self->priv->_directory;
#line 631 "../src/Widgets/Display.vala"
	tuner_directory_controller_remove_saved_search (_tmp5_, _data20_->search);
#line 632 "../src/Widgets/Display.vala"
	_tmp6_ = self->priv->_search_results;
#line 632 "../src/Widgets/Display.vala"
	_tmp7_ = tuner_station_list_box_get_parameter (_tmp6_);
#line 632 "../src/Widgets/Display.vala"
	_tmp8_ = _tmp7_;
#line 632 "../src/Widgets/Display.vala"
	if (g_strcmp0 (_tmp8_, _data20_->search) == 0) {
#line 3062 "Display.c"
		TunerStationListBox* _tmp9_;
		GtkButton* _tmp10_;
		GtkButton* _tmp11_;
#line 633 "../src/Widgets/Display.vala"
		_tmp9_ = self->priv->_search_results;
#line 633 "../src/Widgets/Display.vala"
		_tmp10_ = tuner_station_list_box_get_tooltip_button (_tmp9_);
#line 633 "../src/Widgets/Display.vala"
		_tmp11_ = _tmp10_;
#line 633 "../src/Widgets/Display.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp11_, TRUE);
#line 3074 "Display.c"
	}
#line 634 "../src/Widgets/Display.vala"
	tuner_station_list_box_delist (_data20_->saved_search);
#line 3078 "Display.c"
}

static void
___lambda79__tuner_station_list_box_action_button_activated_sig (TunerStationListBox* _sender,
                                                                 gpointer self)
{
#line 629 "../src/Widgets/Display.vala"
	__lambda79_ (self);
#line 3087 "Display.c"
}

static TunerStationListBox*
tuner_display_add_saved_search (TunerDisplay* self,
                                const gchar* search,
                                TunerStationSet* station_set)
{
	Block20Data* _data20_;
	gchar* _tmp0_;
	GtkStack* _tmp1_;
	GraniteWidgetsSourceList* _tmp2_;
	GraniteWidgetsSourceListExpandableItem* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	TunerStationListBox* _tmp7_;
	TunerStationListBox* _tmp8_;
	TunerStationListBox* _tmp9_;
	TunerStationListBox* result;
#line 610 "../src/Widgets/Display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 610 "../src/Widgets/Display.vala"
	g_return_val_if_fail (search != NULL, NULL);
#line 610 "../src/Widgets/Display.vala"
	g_return_val_if_fail (station_set != NULL, NULL);
#line 610 "../src/Widgets/Display.vala"
	_data20_ = g_slice_new0 (Block20Data);
#line 610 "../src/Widgets/Display.vala"
	_data20_->_ref_count_ = 1;
#line 610 "../src/Widgets/Display.vala"
	_data20_->self = g_object_ref (self);
#line 610 "../src/Widgets/Display.vala"
	_tmp0_ = g_strdup (search);
#line 610 "../src/Widgets/Display.vala"
	_g_free0 (_data20_->search);
#line 610 "../src/Widgets/Display.vala"
	_data20_->search = _tmp0_;
#line 612 "../src/Widgets/Display.vala"
	_tmp1_ = self->priv->_stack;
#line 612 "../src/Widgets/Display.vala"
	_tmp2_ = self->priv->_source_list;
#line 612 "../src/Widgets/Display.vala"
	_tmp3_ = self->priv->_saved_searches_category;
#line 612 "../src/Widgets/Display.vala"
	_tmp4_ = string_to_string (_data20_->search);
#line 612 "../src/Widgets/Display.vala"
	_tmp5_ = g_strconcat ("Saved Search :  ", _tmp4_, NULL);
#line 612 "../src/Widgets/Display.vala"
	_tmp6_ = _tmp5_;
#line 612 "../src/Widgets/Display.vala"
	_tmp7_ = tuner_station_list_box_create_category_specific (_tmp1_, _tmp2_, _tmp3_, _data20_->search, "playlist-symbolic", _data20_->search, _ (_tmp6_), station_set, _ ("Remove this saved search"), "starred-symbolic");
#line 612 "../src/Widgets/Display.vala"
	_tmp8_ = _tmp7_;
#line 612 "../src/Widgets/Display.vala"
	_g_free0 (_tmp6_);
#line 612 "../src/Widgets/Display.vala"
	_data20_->saved_search = _tmp8_;
#line 629 "../src/Widgets/Display.vala"
	g_signal_connect_data (_data20_->saved_search, "action-button-activated-sig", (GCallback) ___lambda79__tuner_station_list_box_action_button_activated_sig, block20_data_ref (_data20_), (GClosureNotify) block20_data_unref, 0);
#line 637 "../src/Widgets/Display.vala"
	_tmp9_ = _g_object_ref0 (_data20_->saved_search);
#line 637 "../src/Widgets/Display.vala"
	result = _tmp9_;
#line 637 "../src/Widgets/Display.vala"
	block20_data_unref (_data20_);
#line 637 "../src/Widgets/Display.vala"
	_data20_ = NULL;
#line 637 "../src/Widgets/Display.vala"
	return result;
#line 3157 "Display.c"
}

/**
* @brief Creates genre-specific categories in the source list.
* @param stack The stack widget.
* @param source_list The source list widget.
* @param category The category to add to.
* @param directory The directory controller.
* @param genres The array of genres.
*/
static void
tuner_display_create_category_genre (TunerDisplay* self,
                                     GtkStack* stack,
                                     GraniteWidgetsSourceList* source_list,
                                     GraniteWidgetsSourceListExpandableItem* category,
                                     TunerDirectoryController* directory,
                                     gchar** genres,
                                     gint genres_length1)
{
#line 649 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 649 "../src/Widgets/Display.vala"
	g_return_if_fail (stack != NULL);
#line 649 "../src/Widgets/Display.vala"
	g_return_if_fail (source_list != NULL);
#line 649 "../src/Widgets/Display.vala"
	g_return_if_fail (category != NULL);
#line 649 "../src/Widgets/Display.vala"
	g_return_if_fail (directory != NULL);
#line 3187 "Display.c"
	{
		gchar** genre_collection = NULL;
		gint genre_collection_length1 = 0;
		gint _genre_collection_size_ = 0;
		gint genre_it = 0;
#line 656 "../src/Widgets/Display.vala"
		genre_collection = genres;
#line 656 "../src/Widgets/Display.vala"
		genre_collection_length1 = genres_length1;
#line 656 "../src/Widgets/Display.vala"
		for (genre_it = 0; genre_it < genre_collection_length1; genre_it = genre_it + 1) {
#line 3199 "Display.c"
			gchar* _tmp0_;
			gchar* genre = NULL;
#line 656 "../src/Widgets/Display.vala"
			_tmp0_ = g_strdup (genre_collection[genre_it]);
#line 656 "../src/Widgets/Display.vala"
			genre = _tmp0_;
#line 3206 "Display.c"
			{
				const gchar* _tmp1_;
				const gchar* _tmp2_;
				const gchar* _tmp3_;
				const gchar* _tmp4_;
				gchar* _tmp5_;
				gchar* _tmp6_;
				TunerStationSet* _tmp7_;
				TunerStationSet* _tmp8_;
				TunerStationListBox* _tmp9_;
				TunerStationListBox* _tmp10_;
#line 658 "../src/Widgets/Display.vala"
				_tmp1_ = genre;
#line 658 "../src/Widgets/Display.vala"
				_tmp2_ = genre;
#line 658 "../src/Widgets/Display.vala"
				_tmp3_ = genre;
#line 658 "../src/Widgets/Display.vala"
				_tmp4_ = genre;
#line 658 "../src/Widgets/Display.vala"
				_tmp5_ = g_utf8_strdown (_tmp4_, (gssize) -1);
#line 658 "../src/Widgets/Display.vala"
				_tmp6_ = _tmp5_;
#line 658 "../src/Widgets/Display.vala"
				_tmp7_ = tuner_directory_controller_load_by_tag (directory, _tmp6_);
#line 658 "../src/Widgets/Display.vala"
				_tmp8_ = _tmp7_;
#line 658 "../src/Widgets/Display.vala"
				_tmp9_ = tuner_station_list_box_create_category_specific (stack, source_list, category, _tmp1_, "playlist-symbolic", _tmp2_, _tmp3_, _tmp8_, NULL, NULL);
#line 658 "../src/Widgets/Display.vala"
				_tmp10_ = _tmp9_;
#line 658 "../src/Widgets/Display.vala"
				_g_object_unref0 (_tmp10_);
#line 658 "../src/Widgets/Display.vala"
				_g_object_unref0 (_tmp8_);
#line 658 "../src/Widgets/Display.vala"
				_g_free0 (_tmp6_);
#line 656 "../src/Widgets/Display.vala"
				_g_free0 (genre);
#line 3246 "Display.c"
			}
		}
	}
}

GtkStack*
tuner_display_get_stack (TunerDisplay* self)
{
	GtkStack* result;
	GtkStack* _tmp0_;
#line 77 "../src/Widgets/Display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 77 "../src/Widgets/Display.vala"
	_tmp0_ = self->priv->_stack;
#line 77 "../src/Widgets/Display.vala"
	result = _tmp0_;
#line 77 "../src/Widgets/Display.vala"
	return result;
#line 3265 "Display.c"
}

static void
tuner_display_set_stack (TunerDisplay* self,
                         GtkStack* value)
{
	GtkStack* old_value;
#line 77 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 77 "../src/Widgets/Display.vala"
	old_value = tuner_display_get_stack (self);
#line 77 "../src/Widgets/Display.vala"
	if (old_value != value) {
#line 3279 "Display.c"
		GtkStack* _tmp0_;
#line 77 "../src/Widgets/Display.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 77 "../src/Widgets/Display.vala"
		_g_object_unref0 (self->priv->_stack);
#line 77 "../src/Widgets/Display.vala"
		self->priv->_stack = _tmp0_;
#line 77 "../src/Widgets/Display.vala"
		g_object_notify_by_pspec ((GObject *) self, tuner_display_properties[TUNER_DISPLAY_STACK_PROPERTY]);
#line 3289 "Display.c"
	}
}

GraniteWidgetsSourceList*
tuner_display_get_source_list (TunerDisplay* self)
{
	GraniteWidgetsSourceList* result;
	GraniteWidgetsSourceList* _tmp0_;
#line 84 "../src/Widgets/Display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 84 "../src/Widgets/Display.vala"
	_tmp0_ = self->priv->_source_list;
#line 84 "../src/Widgets/Display.vala"
	result = _tmp0_;
#line 84 "../src/Widgets/Display.vala"
	return result;
#line 3306 "Display.c"
}

static void
tuner_display_set_source_list (TunerDisplay* self,
                               GraniteWidgetsSourceList* value)
{
	GraniteWidgetsSourceList* old_value;
#line 84 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 84 "../src/Widgets/Display.vala"
	old_value = tuner_display_get_source_list (self);
#line 84 "../src/Widgets/Display.vala"
	if (old_value != value) {
#line 3320 "Display.c"
		GraniteWidgetsSourceList* _tmp0_;
#line 84 "../src/Widgets/Display.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 84 "../src/Widgets/Display.vala"
		_g_object_unref0 (self->priv->_source_list);
#line 84 "../src/Widgets/Display.vala"
		self->priv->_source_list = _tmp0_;
#line 84 "../src/Widgets/Display.vala"
		g_object_notify_by_pspec ((GObject *) self, tuner_display_properties[TUNER_DISPLAY_SOURCE_LIST_PROPERTY]);
#line 3330 "Display.c"
	}
}

TunerDirectoryController*
tuner_display_get_directory (TunerDisplay* self)
{
	TunerDirectoryController* result;
	TunerDirectoryController* _tmp0_;
#line 91 "../src/Widgets/Display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 91 "../src/Widgets/Display.vala"
	_tmp0_ = self->priv->_directory;
#line 91 "../src/Widgets/Display.vala"
	result = _tmp0_;
#line 91 "../src/Widgets/Display.vala"
	return result;
#line 3347 "Display.c"
}

static void
tuner_display_set_directory (TunerDisplay* self,
                             TunerDirectoryController* value)
{
	TunerDirectoryController* old_value;
#line 91 "../src/Widgets/Display.vala"
	g_return_if_fail (self != NULL);
#line 91 "../src/Widgets/Display.vala"
	old_value = tuner_display_get_directory (self);
#line 91 "../src/Widgets/Display.vala"
	if (old_value != value) {
#line 3361 "Display.c"
		TunerDirectoryController* _tmp0_;
#line 91 "../src/Widgets/Display.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 91 "../src/Widgets/Display.vala"
		_g_object_unref0 (self->priv->_directory);
#line 91 "../src/Widgets/Display.vala"
		self->priv->_directory = _tmp0_;
#line 91 "../src/Widgets/Display.vala"
		g_object_notify_by_pspec ((GObject *) self, tuner_display_properties[TUNER_DISPLAY_DIRECTORY_PROPERTY]);
#line 3371 "Display.c"
	}
}

static void
tuner_display_class_init (TunerDisplayClass * klass,
                          gpointer klass_data)
{
#line 31 "../src/Widgets/Display.vala"
	tuner_display_parent_class = g_type_class_peek_parent (klass);
#line 31 "../src/Widgets/Display.vala"
	g_type_class_adjust_private_offset (klass, &TunerDisplay_private_offset);
#line 31 "../src/Widgets/Display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_tuner_display_get_property;
#line 31 "../src/Widgets/Display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_tuner_display_set_property;
#line 31 "../src/Widgets/Display.vala"
	G_OBJECT_CLASS (klass)->finalize = tuner_display_finalize;
#line 3389 "Display.c"
	/**
	     * @property stack
	     * @brief The stack widget for managing different views.
	     */
#line 31 "../src/Widgets/Display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUNER_DISPLAY_STACK_PROPERTY, tuner_display_properties[TUNER_DISPLAY_STACK_PROPERTY] = g_param_spec_object ("stack", "stack", "stack", gtk_stack_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 3396 "Display.c"
	/**
	     * @property source_list
	     * @brief The source list widget for displaying categories.
	     */
#line 31 "../src/Widgets/Display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUNER_DISPLAY_SOURCE_LIST_PROPERTY, tuner_display_properties[TUNER_DISPLAY_SOURCE_LIST_PROPERTY] = g_param_spec_object ("source-list", "source-list", "source-list", GRANITE_WIDGETS_TYPE_SOURCE_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 3403 "Display.c"
	/**
	     * @property directory
	     * @brief The directory controller for managing station data.
	     */
#line 31 "../src/Widgets/Display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUNER_DISPLAY_DIRECTORY_PROPERTY, tuner_display_properties[TUNER_DISPLAY_DIRECTORY_PROPERTY] = g_param_spec_object ("directory", "directory", "directory", TUNER_TYPE_DIRECTORY_CONTROLLER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 3410 "Display.c"
	/**
	     * @brief Signal emitted when a station is clicked.
	     * @param station The clicked station.
	     */
#line 31 "../src/Widgets/Display.vala"
	tuner_display_signals[TUNER_DISPLAY_STATION_CLICKED_SIG_SIGNAL] = g_signal_new ("station-clicked-sig", TUNER_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUNER_MODEL_TYPE_STATION);
#line 3417 "Display.c"
	/**
	     * @brief Signal emitted when the favourites list changes.
	     */
#line 31 "../src/Widgets/Display.vala"
	tuner_display_signals[TUNER_DISPLAY_FAVOURITES_CHANGED_SIG_SIGNAL] = g_signal_new ("favourites-changed-sig", TUNER_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3423 "Display.c"
	/**
	     * @brief Signal emitted to refresh starred stations.
	     */
#line 31 "../src/Widgets/Display.vala"
	tuner_display_signals[TUNER_DISPLAY_REFRESH_STARRED_STATIONS_SIG_SIGNAL] = g_signal_new ("refresh-starred-stations-sig", TUNER_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3429 "Display.c"
	/**
	     * @brief Signal emitted when a search is performed.
	     * @param text The search text.
	     */
#line 31 "../src/Widgets/Display.vala"
	tuner_display_signals[TUNER_DISPLAY_SEARCHED_FOR_SIG_SIGNAL] = g_signal_new ("searched-for-sig", TUNER_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 3436 "Display.c"
	/**
	     * @brief Signal emitted when the search is focused.
	     */
#line 31 "../src/Widgets/Display.vala"
	tuner_display_signals[TUNER_DISPLAY_SEARCH_FOCUSED_SIG_SIGNAL] = g_signal_new ("search-focused-sig", TUNER_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3442 "Display.c"
}

static void
tuner_display_tuner_station_list_hookup_interface_init (TunerStationListHookupIface * iface,
                                                        gpointer iface_data)
{
#line 31 "../src/Widgets/Display.vala"
	tuner_display_tuner_station_list_hookup_parent_iface = g_type_interface_peek_parent (iface);
#line 31 "../src/Widgets/Display.vala"
	iface->station_list_hookup = (void (*) (TunerStationListHookup*, TunerStationList*)) tuner_display_real_station_list_hookup;
#line 3453 "Display.c"
}

static void
tuner_display_instance_init (TunerDisplay * self,
                             gpointer klass)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GraniteWidgetsSourceListExpandableItem* _tmp2_;
	GraniteWidgetsSourceListExpandableItem* _tmp3_;
	GraniteWidgetsSourceListExpandableItem* _tmp4_;
	GraniteWidgetsSourceListExpandableItem* _tmp5_;
	GraniteWidgetsSourceListExpandableItem* _tmp6_;
	GraniteWidgetsSourceListExpandableItem* _tmp7_;
	GtkRevealer* _tmp8_;
	GtkRevealer* _tmp9_;
	GtkOverlay* _tmp10_;
#line 31 "../src/Widgets/Display.vala"
	self->priv = tuner_display_get_instance_private (self);
#line 98 "../src/Widgets/Display.vala"
	_tmp0_ = granite_widgets_source_list_expandable_item_new (_ ("Selections"));
#line 98 "../src/Widgets/Display.vala"
	self->priv->_selections_category = _tmp0_;
#line 99 "../src/Widgets/Display.vala"
	_tmp1_ = granite_widgets_source_list_expandable_item_new (_ ("Library"));
#line 99 "../src/Widgets/Display.vala"
	self->priv->_library_category = _tmp1_;
#line 100 "../src/Widgets/Display.vala"
	_tmp2_ = granite_widgets_source_list_expandable_item_new (_ ("Saved Searches"));
#line 100 "../src/Widgets/Display.vala"
	self->priv->_saved_searches_category = _tmp2_;
#line 101 "../src/Widgets/Display.vala"
	_tmp3_ = granite_widgets_source_list_expandable_item_new (_ ("Explore"));
#line 101 "../src/Widgets/Display.vala"
	self->priv->_explore_category = _tmp3_;
#line 102 "../src/Widgets/Display.vala"
	_tmp4_ = granite_widgets_source_list_expandable_item_new (_ ("Genres"));
#line 102 "../src/Widgets/Display.vala"
	self->priv->_genres_category = _tmp4_;
#line 103 "../src/Widgets/Display.vala"
	_tmp5_ = granite_widgets_source_list_expandable_item_new (_ ("Sub Genres"));
#line 103 "../src/Widgets/Display.vala"
	self->priv->_subgenres_category = _tmp5_;
#line 104 "../src/Widgets/Display.vala"
	_tmp6_ = granite_widgets_source_list_expandable_item_new (_ ("Eras"));
#line 104 "../src/Widgets/Display.vala"
	self->priv->_eras_category = _tmp6_;
#line 105 "../src/Widgets/Display.vala"
	_tmp7_ = granite_widgets_source_list_expandable_item_new (_ ("Talk, News, Sport"));
#line 105 "../src/Widgets/Display.vala"
	self->priv->_talk_category = _tmp7_;
#line 108 "../src/Widgets/Display.vala"
	self->priv->_first_activation = TRUE;
#line 109 "../src/Widgets/Display.vala"
	self->priv->_active = FALSE;
#line 110 "../src/Widgets/Display.vala"
	self->priv->_shuffle = FALSE;
#line 111 "../src/Widgets/Display.vala"
	_tmp8_ = (GtkRevealer*) gtk_revealer_new ();
#line 111 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp8_);
#line 111 "../src/Widgets/Display.vala"
	self->priv->_background_tuner = _tmp8_;
#line 112 "../src/Widgets/Display.vala"
	_tmp9_ = (GtkRevealer*) gtk_revealer_new ();
#line 112 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp9_);
#line 112 "../src/Widgets/Display.vala"
	self->priv->_background_jukebox = _tmp9_;
#line 113 "../src/Widgets/Display.vala"
	_tmp10_ = (GtkOverlay*) gtk_overlay_new ();
#line 113 "../src/Widgets/Display.vala"
	g_object_ref_sink (_tmp10_);
#line 113 "../src/Widgets/Display.vala"
	self->priv->_overlay = _tmp10_;
#line 3529 "Display.c"
}

static void
tuner_display_finalize (GObject * obj)
{
	TunerDisplay * self;
#line 31 "../src/Widgets/Display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUNER_TYPE_DISPLAY, TunerDisplay);
#line 77 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_stack);
#line 84 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_source_list);
#line 91 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_directory);
#line 98 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_selections_category);
#line 99 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_library_category);
#line 100 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_saved_searches_category);
#line 101 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_explore_category);
#line 102 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_genres_category);
#line 103 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_subgenres_category);
#line 104 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_eras_category);
#line 105 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_talk_category);
#line 111 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_background_tuner);
#line 112 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_background_jukebox);
#line 113 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_overlay);
#line 114 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->jukebox_station_set);
#line 115 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_search_controller);
#line 116 "../src/Widgets/Display.vala"
	_g_object_unref0 (self->priv->_search_results);
#line 31 "../src/Widgets/Display.vala"
	G_OBJECT_CLASS (tuner_display_parent_class)->finalize (obj);
#line 3574 "Display.c"
}

/**
 * @brief Display class for managing organization and presentation of genres and thier stations
 *
 * Display should be initialized and re-initialized by its owning class
 */
static GType
tuner_display_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TunerDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuner_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TunerDisplay), 0, (GInstanceInitFunc) tuner_display_instance_init, NULL };
	static const GInterfaceInfo tuner_station_list_hookup_info = { (GInterfaceInitFunc) tuner_display_tuner_station_list_hookup_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuner_display_type_id;
	tuner_display_type_id = g_type_register_static (gtk_paned_get_type (), "TunerDisplay", &g_define_type_info, 0);
	g_type_add_interface_static (tuner_display_type_id, TUNER_TYPE_STATION_LIST_HOOKUP, &tuner_station_list_hookup_info);
	TunerDisplay_private_offset = g_type_add_instance_private (tuner_display_type_id, sizeof (TunerDisplayPrivate));
	return tuner_display_type_id;
}

GType
tuner_display_get_type (void)
{
	static volatile gsize tuner_display_type_id__once = 0;
	if (g_once_init_enter (&tuner_display_type_id__once)) {
		GType tuner_display_type_id;
		tuner_display_type_id = tuner_display_get_type_once ();
		g_once_init_leave (&tuner_display_type_id__once, tuner_display_type_id);
	}
	return tuner_display_type_id__once;
}

static void
_vala_tuner_display_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	TunerDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUNER_TYPE_DISPLAY, TunerDisplay);
#line 31 "../src/Widgets/Display.vala"
	switch (property_id) {
#line 31 "../src/Widgets/Display.vala"
		case TUNER_DISPLAY_STACK_PROPERTY:
#line 31 "../src/Widgets/Display.vala"
		g_value_set_object (value, tuner_display_get_stack (self));
#line 31 "../src/Widgets/Display.vala"
		break;
#line 31 "../src/Widgets/Display.vala"
		case TUNER_DISPLAY_SOURCE_LIST_PROPERTY:
#line 31 "../src/Widgets/Display.vala"
		g_value_set_object (value, tuner_display_get_source_list (self));
#line 31 "../src/Widgets/Display.vala"
		break;
#line 31 "../src/Widgets/Display.vala"
		case TUNER_DISPLAY_DIRECTORY_PROPERTY:
#line 31 "../src/Widgets/Display.vala"
		g_value_set_object (value, tuner_display_get_directory (self));
#line 31 "../src/Widgets/Display.vala"
		break;
#line 3634 "Display.c"
		default:
#line 31 "../src/Widgets/Display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "../src/Widgets/Display.vala"
		break;
#line 3640 "Display.c"
	}
}

static void
_vala_tuner_display_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	TunerDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUNER_TYPE_DISPLAY, TunerDisplay);
#line 31 "../src/Widgets/Display.vala"
	switch (property_id) {
#line 31 "../src/Widgets/Display.vala"
		case TUNER_DISPLAY_STACK_PROPERTY:
#line 31 "../src/Widgets/Display.vala"
		tuner_display_set_stack (self, g_value_get_object (value));
#line 31 "../src/Widgets/Display.vala"
		break;
#line 31 "../src/Widgets/Display.vala"
		case TUNER_DISPLAY_SOURCE_LIST_PROPERTY:
#line 31 "../src/Widgets/Display.vala"
		tuner_display_set_source_list (self, g_value_get_object (value));
#line 31 "../src/Widgets/Display.vala"
		break;
#line 31 "../src/Widgets/Display.vala"
		case TUNER_DISPLAY_DIRECTORY_PROPERTY:
#line 31 "../src/Widgets/Display.vala"
		tuner_display_set_directory (self, g_value_get_object (value));
#line 31 "../src/Widgets/Display.vala"
		break;
#line 3672 "Display.c"
		default:
#line 31 "../src/Widgets/Display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "../src/Widgets/Display.vala"
		break;
#line 3678 "Display.c"
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

